/*
** 2000-05-29
**
** The author disclaims copyright to this source code.  In place of
** a legal notice, here is a blessing:
**
**    May you do good and not evil.
**    May you find forgiveness for yourself and forgive others.
**    May you share freely, never taking more than you give.
**
*************************************************************************
** Driver template for the LEMON parser generator.
**
** The "lemon" program processes an LALR(1) input grammar file, then uses
** this template to construct a parser.  The "lemon" program inserts text
** at each "%%" line.  Also, any "P-a-r-s-e" identifer prefix (without the
** interstitial "-" characters) contained in this template is changed into
** the value of the %name directive from the grammar.  Otherwise, the content
** of this template is copied straight through into the generate parser
** source file.
**
** The following is the concatenation of all %include directives from the
** input grammar file:
*/
#include <stdio.h>
#include <string.h>
#include <assert.h>

#ifdef _MSC_VER
#define CDECL __cdecl
#else
#define CDECL
#endif

/************ Begin %include sections from the grammar ************************/
#line 40 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"

// Allocates a new AST node off the parse state's arena.
#define NEW_AST_NODE(type,name,tok) \
	ZCC_##type *name = static_cast<ZCC_##type *>(stat->InitNode(sizeof(ZCC_##type), AST_##type)); \
	SetNodeLine(name, tok)

static void SetNodeLine(ZCC_TreeNode *name, ZCCToken &tok)
{
	name->SourceLoc = tok.SourceLoc;
}

static void SetNodeLine(ZCC_TreeNode *name, ZCC_TreeNode *node)
{
	if (name == nullptr || node == nullptr)
	{
		I_Error("Fatal parse error");
	}
	name->SourceLoc = node->SourceLoc;
}

static void SetNodeLine(ZCC_TreeNode *name, int line)
{
	name->SourceLoc = line;
}

// If a is non-null, appends b to a. Otherwise, sets a to b.
#define SAFE_APPEND(a,b) \
	if (a == NULL) a = b; else AppendTreeNodeSibling(a, b);

#define UNARY_EXPR(X,T) NEW_AST_NODE(ExprUnary, expr1, X); expr1->Operation = T; expr1->Operand = X; expr1->Type = NULL
#define BINARY_EXPR(X,Y,T) NEW_AST_NODE(ExprBinary, expr2, X); expr2->Operation = T; expr2->Type = NULL; expr2->Left = X; expr2->Right = Y

#define NEW_INTCONST_NODE(name,type,val,tok) \
	NEW_AST_NODE(ExprConstant, name, tok); \
	name->Operation = PEX_ConstValue; \
	name->Type = type; \
	name->IntVal = val

	struct ClassFlagsBlock {
		VM_UWORD Flags;
		ZCC_Identifier *Replaces;
		VersionInfo Version;
	};

	struct StateOpts {
		ZCC_Expression *Offset;
		ZCC_ExprConstant *Lights;
		bool Bright;
		bool Fast;
		bool Slow;
		bool NoDelay;
		bool CanRaise;

		void Zero() {
			Offset = nullptr;
			Lights = nullptr;
			Bright = false;
			Fast = false;
			Slow = false;
			NoDelay = false;
			CanRaise = false;
		}
	};

	struct VarOrFun
	{
		ZCC_VarName *VarNames;
		ZCC_FuncParamDecl *FuncParams;
		ZCC_CompoundStmt *FuncBody;
		ENamedName FuncName;
		int FuncFlags;
		int SourceLoc;
	};
#line 111 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
/**************** End of %include directives **********************************/
/* These constants specify the various numeric values for terminal symbols
** in a format understandable to "makeheaders".  This section is blank unless
** "lemon" is run with the "-m" command-line option.
***************** Begin makeheaders token definitions *************************/
/**************** End makeheaders token definitions ***************************/

/* The next section is a series of control #defines.
** various aspects of the generated parser.
**    YYCODETYPE         is the data type used to store the integer codes
**                       that represent terminal and non-terminal symbols.
**                       "unsigned char" is used if there are fewer than
**                       256 symbols.  Larger types otherwise.
**    YYNOCODE           is a number of type YYCODETYPE that is not used for
**                       any terminal or nonterminal symbol.
**    YYFALLBACK         If defined, this indicates that one or more tokens
**                       (also known as: "terminal symbols") have fall-back
**                       values which should be used if the original symbol
**                       would not parse.  This permits keywords to sometimes
**                       be used as identifiers, for example.
**    YYACTIONTYPE       is the data type used for "action codes" - numbers
**                       that indicate what to do in response to the next
**                       token.
**    ZCCParseTOKENTYPE     is the data type used for minor type for terminal
**                       symbols.  Background: A "minor type" is a semantic
**                       value associated with a terminal or non-terminal
**                       symbols.  For example, for an "ID" terminal symbol,
**                       the minor type might be the name of the identifier.
**                       Each non-terminal can have a different minor type.
**                       Terminal symbols all have the same minor type, though.
**                       This macros defines the minor type for terminal 
**                       symbols.
**    YYMINORTYPE        is the data type used for all minor types.
**                       This is typically a union of many types, one of
**                       which is ZCCParseTOKENTYPE.  The entry in the union
**                       for terminal symbols is called "yy0".
**    YYSTACKDEPTH       is the maximum depth of the parser's stack.  If
**                       zero the stack is dynamically sized using realloc()
**    ZCCParseARG_SDECL     A static variable declaration for the %extra_argument
**    ZCCParseARG_PDECL     A parameter declaration for the %extra_argument
**    ZCCParseARG_STORE     Code to store %extra_argument into yypParser
**    ZCCParseARG_FETCH     Code to extract %extra_argument from yypParser
**    YYERRORSYMBOL      is the code number of the error symbol.  If not
**                       defined, then do no error processing.
**    YYNSTATE           the combined number of states.
**    YYNRULE            the number of rules in the grammar
**    YY_MAX_SHIFT       Maximum value for shift actions
**    YY_MIN_SHIFTREDUCE Minimum value for shift-reduce actions
**    YY_MAX_SHIFTREDUCE Maximum value for shift-reduce actions
**    YY_MIN_REDUCE      Maximum value for reduce actions
**    YY_ERROR_ACTION    The yy_action[] code for syntax error
**    YY_ACCEPT_ACTION   The yy_action[] code for accept
**    YY_NO_ACTION       The yy_action[] code for no-op
*/
#ifndef INTERFACE
# define INTERFACE 1
#endif
/************* Begin control #defines *****************************************/
#define YYCODETYPE unsigned short int
#define YYNOCODE 264
#define YYACTIONTYPE unsigned short int
#define ZCCParseTOKENTYPE  ZCCToken 
typedef union {
  int yyinit;
  ZCCParseTOKENTYPE yy0;
  ZCC_Type * yy6;
  ZCC_FuncParm * yy28;
  VarOrFun yy34;
  ZCC_Identifier * yy35;
  ClassFlagsBlock yy37;
  ZCC_TreeNode * yy38;
  ZCC_BasicType * yy42;
  ZCC_MixinDef * yy48;
  ZCC_FlagDef * yy73;
  ZCC_Expression * yy138;
  ZCC_DeclFlags * yy139;
  ZCC_StaticArrayStatement * yy152;
  ZCC_CaseStmt * yy164;
  ZCC_IfStmt * yy167;
  ZCC_Statement * yy181;
  ZCC_Default * yy205;
  ZCC_PropertyStmt * yy213;
  ZCC_ExprConstant * yy237;
  ZCC_Declarator * yy243;
  ZCC_Enum * yy245;
  ZCC_CompoundStmt * yy261;
  ZCC_Struct * yy262;
  ZCC_StatePart * yy272;
  ZCC_VarName * yy273;
  ZCC_States * yy276;
  ZCC_VarInit * yy299;
  ZCC_ConstantDef * yy307;
  ZCC_FlagStmt * yy380;
  ZCC_Property * yy387;
  ZCC_LocalVarStmt * yy388;
  ZCC_Class * yy414;
  ZCC_ExpressionStmt * yy420;
  StateOpts yy424;
  ZCC_FuncParamDecl * yy433;
  ZCC_AssignStmt * yy453;
  ZCC_ExprFuncCall * yy519;
  ZCC_MixinStmt * yy523;
  int yy527;
} YYMINORTYPE;
#ifndef YYSTACKDEPTH
#define YYSTACKDEPTH 0
#endif
#define ZCCParseARG_SDECL  ZCCParseState *stat ;
#define ZCCParseARG_PDECL , ZCCParseState *stat 
#define ZCCParseARG_FETCH  ZCCParseState *stat  = yypParser->stat 
#define ZCCParseARG_STORE yypParser->stat  = stat 
#define YYERRORSYMBOL 156
#define YYERRSYMDT yy527
#define YYFALLBACK 1
#define YYNSTATE             377
#define YYNRULE              365
#define YY_MAX_SHIFT         376
#define YY_MIN_SHIFTREDUCE   637
#define YY_MAX_SHIFTREDUCE   1001
#define YY_MIN_REDUCE        1002
#define YY_MAX_REDUCE        1366
#define YY_ERROR_ACTION      1367
#define YY_ACCEPT_ACTION     1368
#define YY_NO_ACTION         1369
/************* End control #defines *******************************************/

/* Define the yytestcase() macro to be a no-op if is not already defined
** otherwise.
**
** Applications can choose to define yytestcase() in the %include section
** to a macro that can assist in verifying code coverage.  For production
** code the yytestcase() macro should be turned off.  But it is useful
** for testing.
*/
#ifndef yytestcase
# define yytestcase(X)
#endif


/* Next are the tables used to determine what action to take based on the
** current state and lookahead token.  These tables are used to implement
** functions that take a state number and lookahead value and return an
** action integer.  
**
** Suppose the action integer is N.  Then the action is determined as
** follows
**
**   0 <= N <= YY_MAX_SHIFT             Shift N.  That is, push the lookahead
**                                      token onto the stack and goto state N.
**
**   N between YY_MIN_SHIFTREDUCE       Shift to an arbitrary state then
**     and YY_MAX_SHIFTREDUCE           reduce by rule N-YY_MIN_SHIFTREDUCE.
**
**   N between YY_MIN_REDUCE            Reduce by rule N-YY_MIN_REDUCE
**     and YY_MAX_REDUCE
**
**   N == YY_ERROR_ACTION               A syntax error has occurred.
**
**   N == YY_ACCEPT_ACTION              The parser accepts its input.
**
**   N == YY_NO_ACTION                  No such action.  Denotes unused
**                                      slots in the yy_action[] table.
**
** The action table is constructed as a single large table named yy_action[].
** Given state S and lookahead X, the action is computed as either:
**
**    (A)   N = yy_action[ yy_shift_ofst[S] + X ]
**    (B)   N = yy_default[S]
**
** The (A) formula is preferred.  The B formula is used instead if:
**    (1)  The yy_shift_ofst[S]+X value is out of range, or
**    (2)  yy_lookahead[yy_shift_ofst[S]+X] is not equal to X, or
**    (3)  yy_shift_ofst[S] equal YY_SHIFT_USE_DFLT.
** (Implementation note: YY_SHIFT_USE_DFLT is chosen so that
** YY_SHIFT_USE_DFLT+X will be out of range for all possible lookaheads X.
** Hence only tests (1) and (2) need to be evaluated.)
**
** The formulas above are for computing the action when the lookahead is
** a terminal symbol.  If the lookahead is a non-terminal (as occurs after
** a reduce action) then the yy_reduce_ofst[] array is used in place of
** the yy_shift_ofst[] array and YY_REDUCE_USE_DFLT is used in place of
** YY_SHIFT_USE_DFLT.
**
** The following are the tables generated in this section:
**
**  yy_action[]        A single table containing all actions.
**  yy_lookahead[]     A table containing the lookahead for each entry in
**                     yy_action.  Used to detect hash collisions.
**  yy_shift_ofst[]    For each state, the offset into yy_action for
**                     shifting terminals.
**  yy_reduce_ofst[]   For each state, the offset into yy_action for
**                     shifting non-terminals after a reduce.
**  yy_default[]       Default action for each state.
**
*********** Begin parsing tables **********************************************/
#define YY_ACTTAB_COUNT (2667)
static const YYACTIONTYPE yy_action[] = {
 /*     0 */   110,  109,  639,  641,  642,  643,  644,  645,  646,  107,
 /*    10 */   108,  155,   30,   33,  133,  789,  925,  741,  166,  840,
 /*    20 */   154,  327,  728,  729,  730,  165,  789,  272,  916,  118,
 /*    30 */   302,  787,    2,  939,  155,    2,   23,  918,  707,  800,
 /*    40 */   789,  801,  122,  154,  790,  803,  131,  131,  759,  852,
 /*    50 */   800,  789,  801,  122,  787,  271,  331,  773,  774,  775,
 /*    60 */   776,  777,  778,  779,  780,  781,  782,  783,  784,  785,
 /*    70 */   786,  788,  342,  335,  727,  336,  332,  112,   37,  343,
 /*    80 */   773,  774,  775,  776,  777,  778,  779,  780,  781,  782,
 /*    90 */   783,  784,  785,  786,  788,  342,  335,   54,  336,  332,
 /*   100 */   702,  106,  105,  104,  103,  919,  920,  921,  922,  923,
 /*   110 */   924,   41,  313,  312,   29,    9,  308,  948,  949,  304,
 /*   120 */   111,  303,   49,   76,   89,   88,   87,   97,  100,   95,
 /*   130 */    94,   93,   91,   90,   92,  110,  109,  640,  157,  344,
 /*   140 */   157,   59, 1368,   16,  107,  108,  155,   30,   33,   37,
 /*   150 */   669,  925,  151,  151,  766,  154,  327,  192,  355,  672,
 /*   160 */   671,  675,  301,  916,  662,  302,  787,    2,  940,  843,
 /*   170 */   668,  762,  918,  663,  664,  670,  676,  677,  673,  674,
 /*   180 */   678,  844,   40,  318,  852,  773,  774,  775,  776,  777,
 /*   190 */   778,  323,  773,  774,  775,  776,  777,  778,  779,  780,
 /*   200 */   781,  782,  783,  784,  785,  786,  788,  342,  335,  117,
 /*   210 */   336,  332,   74,   75,   76,   89,   88,   87,   97,  100,
 /*   220 */    95,   94,   93,   91,   90,   92,   15,  229,  192,  853,
 /*   230 */   912,  912,   59,  306,  190,  355,  106,  105,  104,  103,
 /*   240 */   919,  920,  921,  922,  923,  924,   41,  313,  312,   29,
 /*   250 */     9,  308,  948,  949,  304, 1206,  303,   49,   97,  100,
 /*   260 */    95,   94,   93,   91,   90,   92,  300,  300,  299,  789,
 /*   270 */   110,  109,   59,   95,   94,   93,   91,   90,   92,  107,
 /*   280 */   108,  155,   30,   33,  789,   59,  925,  152,  152,  116,
 /*   290 */   154,  327,  738,  800,  789,  801,  122,  370,  916,  333,
 /*   300 */   302,  787,    2,  842,  229,  190,  853,  918,  800,  789,
 /*   310 */   801,  122,  270,   37,  334,  666,  375,  373,  366,  852,
 /*   320 */   360,  799,  358,  346,  144,   42,  701,  773,  774,  775,
 /*   330 */   776,  777,  778,  779,  780,  781,  782,  783,  784,  785,
 /*   340 */   786,  788,  342,  335,  230,  336,  332,  731,   75,   76,
 /*   350 */    89,   88,   87,   97,  100,   95,   94,   93,   91,   90,
 /*   360 */    92,  655,  656,  657,  658,  135,  262,   59,  371,  369,
 /*   370 */    37,  106,  105,  104,  103,  919,  920,  921,  922,  923,
 /*   380 */   924,   41,  313,  312,   29,    9,  308,  948,  949,  304,
 /*   390 */   155,  303,   49,   41,  736,  789,  737,  141,   92,  154,
 /*   400 */   790,  720,  821,  834,  835,   59,  287,   43,    1,   46,
 /*   410 */   787,  235,  732,  733,  734,  735,  130,  230,  836,  800,
 /*   420 */   789,  801,  122,  329,  113,  329,  743,  744,  745,  746,
 /*   430 */   747,  280,  279,  789,  128,  815,  773,  774,  775,  776,
 /*   440 */   777,  778,  779,  780,  781,  782,  783,  784,  785,  786,
 /*   450 */   788,  342,  341,  806,  336,  332,  804,  800,  789,  801,
 /*   460 */   295,  309,  147,  291,  822,  823,  824,  825,  826,  827,
 /*   470 */   828,  830,  831,  832,  833,  837,   71,   68,   67,   66,
 /*   480 */    70,   69,   65,   64,   62,   61,   60,   63,   58,  649,
 /*   490 */    72,   73,   79,   78,   77,   85,   84,   83,   82,   81,
 /*   500 */    80,   86,   74,   75,   76,   89,   88,   87,   97,  100,
 /*   510 */    95,   94,   93,   91,   90,   92,  352,  661,  270,  948,
 /*   520 */   949,  708,   59,  373,  366,   98,  360,  355,  358,  346,
 /*   530 */   144,  771,   54,  171,  355,  259,  169,  855,  263,   71,
 /*   540 */    68,   67,   66,   70,   69,   65,   64,   62,   61,   60,
 /*   550 */    63,   58,  164,   72,   73,   79,   78,   77,   85,   84,
 /*   560 */    83,   82,   81,   80,   86,   74,   75,   76,   89,   88,
 /*   570 */    87,   97,  100,   95,   94,   93,   91,   90,   92,  293,
 /*   580 */   134,  110,  109,  809,  148,   59,  808,  808,   99,  789,
 /*   590 */   107,  108,  155,   30,  192,  355,  229,  870,  853,   41,
 /*   600 */   856,  154,  327,  229,  171,  853,  185,  355,  231,  916,
 /*   610 */   355,  163,  787,  800,  789,  801,  245,  931,  918,   89,
 /*   620 */    88,   87,   97,  100,   95,   94,   93,   91,   90,   92,
 /*   630 */   852,  938,   54,   28,  941,  267,   59,  233,  773,  774,
 /*   640 */   775,  776,  777,  778,  779,  780,  781,  782,  783,  784,
 /*   650 */   785,  786,  788,  342,  335,  807,  336,  332,   54,  237,
 /*   660 */   237,  278,  192,  355,  229,  192,  853,  233,  233,  102,
 /*   670 */   763,  767,  768,  749,  966,  808,  229,  185,  853,  229,
 /*   680 */   869,  853,  106,  105,  104,  103,  919,  920,  921,  922,
 /*   690 */   923,  924,   71,   68,   67,   66,   70,   69,   65,   64,
 /*   700 */    62,   61,   60,   63,   58,  249,   72,   73,   79,   78,
 /*   710 */    77,   85,   84,   83,   82,   81,   80,   86,   74,   75,
 /*   720 */    76,   89,   88,   87,   97,  100,   95,   94,   93,   91,
 /*   730 */    90,   92,  229,  192,  853,  249,  249,  340,   59,  268,
 /*   740 */    71,   68,   67,   66,   70,   69,   65,   64,   62,   61,
 /*   750 */    60,   63,   58,  748,   72,   73,   79,   78,   77,   85,
 /*   760 */    84,   83,   82,   81,   80,   86,   74,   75,   76,   89,
 /*   770 */    88,   87,   97,  100,   95,   94,   93,   91,   90,   92,
 /*   780 */   127,  129,   18,  757,  931,  275,   59,  750,  339,   44,
 /*   790 */   234,   71,   68,   67,   66,   70,   69,   65,   64,   62,
 /*   800 */    61,   60,   63,   58,  959,   72,   73,   79,   78,   77,
 /*   810 */    85,   84,   83,   82,   81,   80,   86,   74,   75,   76,
 /*   820 */    89,   88,   87,   97,  100,   95,   94,   93,   91,   90,
 /*   830 */    92,  146,  167,  289,  288,  723,  236,   59,  816,   71,
 /*   840 */    68,   67,   66,   70,   69,   65,   64,   62,   61,   60,
 /*   850 */    63,   58,  119,   72,   73,   79,   78,   77,   85,   84,
 /*   860 */    83,   82,   81,   80,   86,   74,   75,   76,   89,   88,
 /*   870 */    87,   97,  100,   95,   94,   93,   91,   90,   92,  813,
 /*   880 */   969,  839,  115,  247,  153,   59,  797,   71,   68,   67,
 /*   890 */    66,   70,   69,   65,   64,   62,   61,   60,   63,   58,
 /*   900 */     5,   72,   73,   79,   78,   77,   85,   84,   83,   82,
 /*   910 */    81,   80,   86,   74,   75,   76,   89,   88,   87,   97,
 /*   920 */   100,   95,   94,   93,   91,   90,   92,  337,  703,  156,
 /*   930 */   979,  972,  699,   59,  126,   71,   68,   67,   66,   70,
 /*   940 */    69,   65,   64,   62,   61,   60,   63,   58,    6,   72,
 /*   950 */    73,   79,   78,   77,   85,   84,   83,   82,   81,   80,
 /*   960 */    86,   74,   75,   76,   89,   88,   87,   97,  100,   95,
 /*   970 */    94,   93,   91,   90,   92,  345,  684,  916,  376,   14,
 /*   980 */   227,   59,  273,   71,   68,   67,   66,   70,   69,   65,
 /*   990 */    64,   62,   61,   60,   63,   58,  946,   72,   73,   79,
 /*  1000 */    78,   77,   85,   84,   83,   82,   81,   80,   86,   74,
 /*  1010 */    75,   76,   89,   88,   87,   97,  100,   95,   94,   93,
 /*  1020 */    91,   90,   92,   12,  274,  281,  228,   13,  162,   59,
 /*  1030 */   256,   71,   68,   67,   66,   70,   69,   65,   64,   62,
 /*  1040 */    61,   60,   63,   58,   10,   72,   73,   79,   78,   77,
 /*  1050 */    85,   84,   83,   82,   81,   80,   86,   74,   75,   76,
 /*  1060 */    89,   88,   87,   97,  100,   95,   94,   93,   91,   90,
 /*  1070 */    92,  188,  355,  257,  660,  230,  260,   59,  261,   71,
 /*  1080 */    68,   67,   66,   70,   69,   65,   64,   62,   61,   60,
 /*  1090 */    63,   58,   57,   72,   73,   79,   78,   77,   85,   84,
 /*  1100 */    83,   82,   81,   80,   86,   74,   75,   76,   89,   88,
 /*  1110 */    87,   97,  100,   95,   94,   93,   91,   90,   92,  232,
 /*  1120 */   689,  686,  687,  292,  284,   59,  136,   38,  650,   17,
 /*  1130 */   861,  862,  353,   20,   56,  722,  688,  265,  766,  139,
 /*  1140 */   140,  229,  188,  853,   54,  859,  980,   71,   68,   67,
 /*  1150 */    66,   70,   69,   65,   64,   62,   61,   60,   63,   58,
 /*  1160 */   967,   72,   73,   79,   78,   77,   85,   84,   83,   82,
 /*  1170 */    81,   80,   86,   74,   75,   76,   89,   88,   87,   97,
 /*  1180 */   100,   95,   94,   93,   91,   90,   92,  755,  754,  753,
 /*  1190 */   752,  751,  143,   59,   45,   71,   68,   67,   66,   70,
 /*  1200 */    69,   65,   64,   62,   61,   60,   63,   58,  854,   72,
 /*  1210 */    73,   79,   78,   77,   85,   84,   83,   82,   81,   80,
 /*  1220 */    86,   74,   75,   76,   89,   88,   87,   97,  100,   95,
 /*  1230 */    94,   93,   91,   90,   92,  124,  690,  282,  283,  820,
 /*  1240 */   285,   59,  286,  698,  819,   71,   68,   67,   66,   70,
 /*  1250 */    69,   65,   64,   62,   61,   60,   63,   58,  290,   72,
 /*  1260 */    73,   79,   78,   77,   85,   84,   83,   82,   81,   80,
 /*  1270 */    86,   74,   75,   76,   89,   88,   87,   97,  100,   95,
 /*  1280 */    94,   93,   91,   90,   92,  818,  145,  724,  810,   47,
 /*  1290 */    58,   59,   72,   73,   79,   78,   77,   85,   84,   83,
 /*  1300 */    82,   81,   80,   86,   74,   75,   76,   89,   88,   87,
 /*  1310 */    97,  100,   95,   94,   93,   91,   90,   92,  155,   54,
 /*  1320 */    31,  189,  355, 1056,   59,  692,  694,  154,  790,  968,
 /*  1330 */   358,  346,    8,  294,  120,  314,  695,  696,  787,   86,
 /*  1340 */    74,   75,   76,   89,   88,   87,   97,  100,   95,   94,
 /*  1350 */    93,   91,   90,   92,   31,  328,  697,  359,   39,   39,
 /*  1360 */    59,  296,  296,   40,  773,  774,  775,  776,  777,  778,
 /*  1370 */   779,  780,  781,  782,  783,  784,  785,  786,  788,  342,
 /*  1380 */   335,  355,  336,  332,   32,  149,   23,   54,   48,  960,
 /*  1390 */    50,  229,  189,  853,  665,   51,    7,   22,  858,  954,
 /*  1400 */   355,   41,   15,  319,   23,  848,  849,  850, 1002,  270,
 /*  1410 */    34,   11,   52,  375,  373,  366,  857,  360,   53,  358,
 /*  1420 */   346,  144,   73,   79,   78,   77,   85,   84,   83,   82,
 /*  1430 */    81,   80,   86,   74,   75,   76,   89,   88,   87,   97,
 /*  1440 */   100,   95,   94,   93,   91,   90,   92,  142,  192,  355,
 /*  1450 */   229,  868,  853,   59,  188,  355,  970,  711,  936,  161,
 /*  1460 */   266,  264,  694,   35,  189,  355,  713,  712,  716,  229,
 /*  1470 */   867,  853,  695,  696,  935,  258,  934,  315,  932,  360,
 /*  1480 */   316,  358,  346,  717,  718,  714,  715,  719,  933,  789,
 /*  1490 */    41,  250,  697,  317,   36,  693,  137,  138,  320,  321,
 /*  1500 */  1341,  710,  242,  322,  276,  930,    3,  358,  346,  929,
 /*  1510 */   928,  150,  765,  800,  789,  801,  121,  661,  229,  192,
 /*  1520 */   853,  250,  250,  355,  229,  188,  853, 1155,   24,  760,
 /*  1530 */   805,  796,   25,   15,  229,  189,  853,  795,   15,  927,
 /*  1540 */   942,  926,  326,  942,  942,  942,  325,  324,  310,   26,
 /*  1550 */   248,  305,   79,   78,   77,   85,   84,   83,   82,   81,
 /*  1560 */    80,   86,   74,   75,   76,   89,   88,   87,   97,  100,
 /*  1570 */    95,   94,   93,   91,   90,   92,   27,  338,   41,  246,
 /*  1580 */   793,  792,   59,  188,  355,  791,   55,  188,  355,  114,
 /*  1590 */   110,  109,  229,  866,  853,  158,  189,  355,  159,  107,
 /*  1600 */   108,  230,   30,  137,  138,  347,  772,   19,  348,  350,
 /*  1610 */   932,  851,  349,  110,  109,  355,  990,  860,  916,  765,
 /*  1620 */    96,  789,  107,  108,  661,   30,   59,  918,  917,  937,
 /*  1630 */   101,  239,  357,  681,  851,  240,  761,  160,    4,  852,
 /*  1640 */   269,  916,  168,  298,  361,  800,  789,  801,  121,  362,
 /*  1650 */   918,  363,  364,  229,  188,  853,  365,  229,  188,  853,
 /*  1660 */   188,  355,  852,  189,  355,   28,  229,  189,  853, 1089,
 /*  1670 */   311,  927,  942,  926,  326,  942,  942,  942,  325,  324,
 /*  1680 */   310,  355,  367,  305,  229,  865,  853,  189,  355,  368,
 /*  1690 */   680,  106,  105,  104,  103,  919,  920,  921,  922,  923,
 /*  1700 */   924,  932,  764,  767,  768, 1088,  123,  372,  238,  679,
 /*  1710 */   374,  311,  789, 1004,  106,  105,  104,  103,  919,  920,
 /*  1720 */   921,  922,  923,  924, 1004,  188,  355,  277,  189,  355,
 /*  1730 */   229,  188,  853,  229,  189,  853,  800,  789,  801,  121,
 /*  1740 */  1004,  953,  932, 1004, 1004, 1004,  188,  355, 1004,  241,
 /*  1750 */   229,  864,  853,  789, 1004, 1004, 1004,  229,  189,  853,
 /*  1760 */  1004, 1004,  927,  943,  926,  326,  943,  943,  943,  325,
 /*  1770 */   324,  310,  355,  243,  305, 1004, 1004,  800,  789,  801,
 /*  1780 */   121, 1004, 1004,  330,  190,  355, 1004,  183,  355, 1004,
 /*  1790 */  1004, 1004, 1004, 1004,  244,  229,  188,  853,  229,  189,
 /*  1800 */   853, 1004,  311,  927,  943,  926,  326,  943,  943,  943,
 /*  1810 */   325,  324,  310,  172,  355,  305,  229,  188,  853,  189,
 /*  1820 */   355, 1004, 1004, 1004, 1004, 1004, 1004, 1004, 1004, 1004,
 /*  1830 */  1004, 1004, 1004,  932, 1004, 1004, 1004,  173,  355, 1004,
 /*  1840 */  1004,  229,  863,  853,  789,  311,  125,  355, 1004,  184,
 /*  1850 */   355, 1004,  186,  355,  229,  190,  853,  229,  183,  853,
 /*  1860 */  1004, 1004,  189,  355, 1004, 1004, 1004, 1004,  800,  789,
 /*  1870 */   801,  121, 1004, 1004, 1004, 1004,  932, 1004, 1004, 1004,
 /*  1880 */  1004, 1004, 1004,  229,  172,  853, 1004,  789, 1004,  229,
 /*  1890 */   189,  853,  174,  355,  927,  958,  926,  326,  958,  958,
 /*  1900 */   958,  325,  324,  310, 1004, 1004,  305,  229,  173,  853,
 /*  1910 */  1004,  800,  789,  801,  121, 1004,  229,  125,  853,  229,
 /*  1920 */   184,  853,  229,  186,  853, 1004, 1004,  175,  355, 1004,
 /*  1930 */  1004, 1004,  229,  189,  853,  311, 1004,  927,  957,  926,
 /*  1940 */   326,  957,  957,  957,  325,  324,  310, 1004, 1004,  305,
 /*  1950 */  1004, 1004,  189,  355, 1004, 1004, 1004, 1004, 1004, 1004,
 /*  1960 */  1004, 1004,  229,  174,  853, 1004,  932, 1004, 1004, 1004,
 /*  1970 */  1004, 1004, 1004, 1004, 1004, 1004,  311,  789,  176,  355,
 /*  1980 */  1004, 1004,  177,  355, 1004,  178,  355, 1004,  187,  355,
 /*  1990 */  1004, 1004, 1004,  189,  355, 1004, 1004,  229,  175,  853,
 /*  2000 */  1004,  800,  789,  801,  121, 1004, 1004,  932, 1004, 1004,
 /*  2010 */  1004,  191,  355, 1004, 1004, 1004, 1004, 1004,  789, 1004,
 /*  2020 */   311, 1004,  229,  189,  853, 1004, 1004,  927,  956,  926,
 /*  2030 */   326,  956,  956,  956,  325,  324,  310,  189,  355,  305,
 /*  2040 */  1004, 1004,  800,  789,  801,  121, 1004, 1004,  229,  176,
 /*  2050 */   853,  932,  229,  177,  853,  229,  178,  853,  229,  187,
 /*  2060 */   853, 1004,  789,  229,  189,  853,  179,  355,  927,  947,
 /*  2070 */   926,  326,  947,  947,  947,  325,  324,  310, 1004, 1004,
 /*  2080 */   305,  229,  191,  853, 1004, 1004,  800,  789,  801,  121,
 /*  2090 */   206,  355, 1004,  180,  355, 1004, 1004, 1004,  909,  355,
 /*  2100 */  1004,  193,  355, 1004, 1004, 1004, 1004,  229,  189,  853,
 /*  2110 */   311, 1004,  927,  132,  926,  326,  132,  132,  132,  325,
 /*  2120 */   324,  310, 1004, 1004,  305, 1004, 1004,  189,  355, 1004,
 /*  2130 */  1004, 1004, 1004, 1004, 1004, 1004,  229,  179,  853, 1004,
 /*  2140 */  1004,  932, 1004, 1004, 1004, 1004,  110,  109, 1004, 1004,
 /*  2150 */  1004, 1004,  789, 1004, 1004,  107,  108, 1004,   30, 1004,
 /*  2160 */   229,  206,  853,  229,  180,  853,  351,  851,  229,  909,
 /*  2170 */   853,  229,  193,  853,  916, 1004,  800,  789,  801,  121,
 /*  2180 */  1004, 1004, 1004,  918, 1004, 1004, 1004, 1004, 1004, 1004,
 /*  2190 */  1004, 1004, 1004, 1004, 1004,  852, 1004,  229,  189,  853,
 /*  2200 */  1004, 1004,  927,  945,  926,  326,  945,  945,  945,  325,
 /*  2210 */   324,  310, 1004, 1004,  305, 1004, 1004, 1004,   85,   84,
 /*  2220 */    83,   82,   81,   80,   86,   74,   75,   76,   89,   88,
 /*  2230 */    87,   97,  100,   95,   94,   93,   91,   90,   92, 1004,
 /*  2240 */  1004, 1004, 1004, 1004, 1004,   59, 1004,  106,  105,  104,
 /*  2250 */   103,  919,  920,  921,  922,  923,  924,  110,  109, 1004,
 /*  2260 */  1004, 1004, 1004,  189,  355, 1004,  107,  108, 1004,   30,
 /*  2270 */   110,  109,  194,  355, 1004, 1004, 1004, 1004,  851,  107,
 /*  2280 */   108, 1004,   30,  110,  109,  916, 1004, 1004,  789,   21,
 /*  2290 */  1004,  356,  107,  108,  918,   30, 1004, 1004,  916, 1004,
 /*  2300 */  1004, 1004, 1004, 1004,  851, 1004,  852,  918, 1004, 1004,
 /*  2310 */  1004,  916,  800,  789,  801,  121, 1004, 1004, 1004,  852,
 /*  2320 */   918, 1004, 1004, 1004, 1004, 1004,  195,  355, 1004,  196,
 /*  2330 */   355, 1004,  852,  229,  189,  853,  197,  355, 1004,  198,
 /*  2340 */   355,  953,  229,  194,  853, 1004,  950, 1004,  307,  297,
 /*  2350 */   199,  355, 1004,  200,  355, 1004, 1004, 1004,  106,  105,
 /*  2360 */   104,  103,  919,  920,  921,  922,  923,  924, 1004,  201,
 /*  2370 */   355,  106,  105,  104,  103,  919,  920,  921,  922,  923,
 /*  2380 */   924,  202,  355, 1004,  106,  105,  104,  103,  919,  920,
 /*  2390 */   921,  922,  923,  924,  203,  355,  229,  195,  853,  229,
 /*  2400 */   196,  853,  204,  355, 1004, 1004,  229,  197,  853,  229,
 /*  2410 */   198,  853,  207,  355, 1004, 1004, 1004, 1004, 1004, 1004,
 /*  2420 */   229,  199,  853,  229,  200,  853,  208,  355, 1004,  219,
 /*  2430 */   355, 1004,  220,  355, 1004, 1004, 1004,  221,  355,  229,
 /*  2440 */   201,  853, 1004,  209,  355, 1004,  210,  355, 1004, 1004,
 /*  2450 */  1004,  229,  202,  853,  211,  355, 1004,  212,  355, 1004,
 /*  2460 */  1004, 1004,  213,  355,  229,  203,  853,  214,  355, 1004,
 /*  2470 */  1004, 1004,  229,  204,  853, 1004, 1004, 1004,  215,  355,
 /*  2480 */  1004, 1004,  229,  207,  853,  216,  355, 1004,  217,  355,
 /*  2490 */  1004, 1004, 1004,  218,  355, 1004,  229,  208,  853,  229,
 /*  2500 */   219,  853,  229,  220,  853, 1004, 1004,  229,  221,  853,
 /*  2510 */   222,  355, 1004,  229,  209,  853,  229,  210,  853, 1004,
 /*  2520 */   223,  355, 1004, 1004,  229,  211,  853,  229,  212,  853,
 /*  2530 */  1004, 1004,  229,  213,  853,  224,  355,  229,  214,  853,
 /*  2540 */   251,  355, 1004,  252,  355, 1004,  354,  355,  229,  215,
 /*  2550 */   853,  253,  355, 1004, 1004,  229,  216,  853,  229,  217,
 /*  2560 */   853,  254,  355,  229,  218,  853,  255,  355, 1004,  205,
 /*  2570 */   355, 1004,  226,  355, 1004,  181,  355, 1004, 1004, 1004,
 /*  2580 */   229,  222,  853,  170,  355, 1004,  225,  355, 1004, 1004,
 /*  2590 */   229,  223,  853, 1004,  182,  355, 1004, 1004, 1004, 1004,
 /*  2600 */  1004, 1004, 1004, 1004, 1004,  229,  224,  853, 1004, 1004,
 /*  2610 */   229,  251,  853,  229,  252,  853,  229,  354,  853, 1004,
 /*  2620 */  1004,  229,  253,  853, 1004, 1004, 1004, 1004, 1004, 1004,
 /*  2630 */  1004,  229,  254,  853, 1004, 1004,  229,  255,  853,  229,
 /*  2640 */   205,  853,  229,  226,  853,  229,  181,  853, 1004, 1004,
 /*  2650 */  1004, 1004, 1004,  229,  170,  853,  229,  225,  853, 1004,
 /*  2660 */  1004, 1004, 1004, 1004,  229,  182,  853,
};
static const YYCODETYPE yy_lookahead[] = {
 /*     0 */    33,   34,  163,  164,  165,  166,  167,  168,  169,   42,
 /*    10 */    43,   44,   45,   46,  175,  198,   49,  208,  209,   49,
 /*    20 */    53,   54,  203,  204,  205,  206,  198,   54,   61,   54,
 /*    30 */    63,   64,   65,   66,   44,   65,   50,   70,  199,  222,
 /*    40 */   223,  224,  225,   53,   54,  228,  230,  231,   62,   82,
 /*    50 */   222,  223,  224,  225,   64,   82,  228,   90,   91,   92,
 /*    60 */    93,   94,   95,   96,   97,   98,   99,  100,  101,  102,
 /*    70 */   103,  104,  105,  106,  156,  108,  109,   45,   46,   54,
 /*    80 */    90,   91,   92,   93,   94,   95,   96,   97,   98,   99,
 /*    90 */   100,  101,  102,  103,  104,  105,  106,   50,  108,  109,
 /*   100 */   156,  134,  135,  136,  137,  138,  139,  140,  141,  142,
 /*   110 */   143,  144,  145,  146,  147,  148,  149,  150,  151,  152,
 /*   120 */   202,  154,  155,   29,   30,   31,   32,   33,   34,   35,
 /*   130 */    36,   37,   38,   39,   40,   33,   34,  156,  194,  195,
 /*   140 */   196,   47,  161,  162,   42,   43,   44,   45,   46,   46,
 /*   150 */   157,   49,  230,  231,   49,   53,   54,  173,  174,  166,
 /*   160 */   167,  168,  115,   61,   54,   63,   64,   65,   66,  130,
 /*   170 */   177,   66,   70,   63,   64,  182,  183,  184,  185,  186,
 /*   180 */   187,  241,  242,   46,   82,   90,   91,   92,   93,   94,
 /*   190 */    95,   54,   90,   91,   92,   93,   94,   95,   96,   97,
 /*   200 */    98,   99,  100,  101,  102,  103,  104,  105,  106,   54,
 /*   210 */   108,  109,   27,   28,   29,   30,   31,   32,   33,   34,
 /*   220 */    35,   36,   37,   38,   39,   40,  233,  243,  244,  245,
 /*   230 */   246,  247,   47,  172,  173,  174,  134,  135,  136,  137,
 /*   240 */   138,  139,  140,  141,  142,  143,  144,  145,  146,  147,
 /*   250 */   148,  149,  150,  151,  152,   62,  154,  155,   33,   34,
 /*   260 */    35,   36,   37,   38,   39,   40,  261,  262,    1,  198,
 /*   270 */    33,   34,   47,   35,   36,   37,   38,   39,   40,   42,
 /*   280 */    43,   44,   45,   46,  198,   47,   49,  230,  231,  211,
 /*   290 */    53,   54,  207,  222,  223,  224,  225,   54,   61,  228,
 /*   300 */    63,   64,   65,  110,  243,  244,  245,   70,  222,  223,
 /*   310 */   224,  225,   63,   46,  228,   66,   67,   68,   69,   82,
 /*   320 */    71,   21,   73,   74,   75,    1,  198,   90,   91,   92,
 /*   330 */    93,   94,   95,   96,   97,   98,   99,  100,  101,  102,
 /*   340 */   103,  104,  105,  106,   44,  108,  109,   14,   28,   29,
 /*   350 */    30,   31,   32,   33,   34,   35,   36,   37,   38,   39,
 /*   360 */    40,   55,   56,   57,   58,   59,   60,   47,  191,  192,
 /*   370 */    46,  134,  135,  136,  137,  138,  139,  140,  141,  142,
 /*   380 */   143,  144,  145,  146,  147,  148,  149,  150,  151,  152,
 /*   390 */    44,  154,  155,  144,  207,  198,  207,   54,   40,   53,
 /*   400 */    54,   66,   56,   57,   58,   47,   60,   34,   65,   76,
 /*   410 */    64,   76,   77,   78,   79,   80,   81,   44,   72,  222,
 /*   420 */   223,  224,  225,  226,  227,  228,   83,   84,   85,   86,
 /*   430 */    87,   88,   89,  198,  181,  238,   90,   91,   92,   93,
 /*   440 */    94,   95,   96,   97,   98,   99,  100,  101,  102,  103,
 /*   450 */   104,  105,  106,  231,  108,  109,  110,  222,  223,  224,
 /*   460 */   225,  257,  116,  117,  118,  119,  120,  121,  122,  123,
 /*   470 */   124,  125,  126,  127,  128,  129,    1,    2,    3,    4,
 /*   480 */     5,    6,    7,    8,    9,   10,   11,   12,   13,  178,
 /*   490 */    15,   16,   17,   18,   19,   20,   21,   22,   23,   24,
 /*   500 */    25,   26,   27,   28,   29,   30,   31,   32,   33,   34,
 /*   510 */    35,   36,   37,   38,   39,   40,  156,   54,   63,  150,
 /*   520 */   151,   66,   47,   68,   69,   50,   71,  174,   73,   74,
 /*   530 */    75,   49,   50,  173,  174,  181,   49,   62,  181,    1,
 /*   540 */     2,    3,    4,    5,    6,    7,    8,    9,   10,   11,
 /*   550 */    12,   13,   65,   15,   16,   17,   18,   19,   20,   21,
 /*   560 */    22,   23,   24,   25,   26,   27,   28,   29,   30,   31,
 /*   570 */    32,   33,   34,   35,   36,   37,   38,   39,   40,  156,
 /*   580 */    14,   33,   34,   49,   50,   47,  159,  160,   50,  198,
 /*   590 */    42,   43,   44,   45,  173,  174,  243,  244,  245,  144,
 /*   600 */    62,   53,   54,  243,  244,  245,  173,  174,  156,   61,
 /*   610 */   174,  179,   64,  222,  223,  224,  225,   49,   70,   30,
 /*   620 */    31,   32,   33,   34,   35,   36,   37,   38,   39,   40,
 /*   630 */    82,   49,   50,  181,   66,  181,   47,  216,   90,   91,
 /*   640 */    92,   93,   94,   95,   96,   97,   98,   99,  100,  101,
 /*   650 */   102,  103,  104,  105,  106,  232,  108,  109,   50,  236,
 /*   660 */   237,   50,  173,  174,  243,  244,  245,  246,  247,  217,
 /*   670 */   218,  219,  220,   62,   66,  248,  243,  244,  245,  243,
 /*   680 */   244,  245,  134,  135,  136,  137,  138,  139,  140,  141,
 /*   690 */   142,  143,    1,    2,    3,    4,    5,    6,    7,    8,
 /*   700 */     9,   10,   11,   12,   13,  216,   15,   16,   17,   18,
 /*   710 */    19,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*   720 */    29,   30,   31,   32,   33,   34,   35,   36,   37,   38,
 /*   730 */    39,   40,  243,  244,  245,  246,  247,   54,   47,  181,
 /*   740 */     1,    2,    3,    4,    5,    6,    7,    8,    9,   10,
 /*   750 */    11,   12,   13,   62,   15,   16,   17,   18,   19,   20,
 /*   760 */    21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
 /*   770 */    31,   32,   33,   34,   35,   36,   37,   38,   39,   40,
 /*   780 */   181,  181,   45,  210,   49,  213,   47,   61,  105,   50,
 /*   790 */   214,    1,    2,    3,    4,    5,    6,    7,    8,    9,
 /*   800 */    10,   11,   12,   13,   14,   15,   16,   17,   18,   19,
 /*   810 */    20,   21,   22,   23,   24,   25,   26,   27,   28,   29,
 /*   820 */    30,   31,   32,   33,   34,   35,   36,   37,   38,   39,
 /*   830 */    40,   45,  212,   50,  239,   54,  192,   47,  212,    1,
 /*   840 */     2,    3,    4,    5,    6,    7,    8,    9,   10,   11,
 /*   850 */    12,   13,   54,   15,   16,   17,   18,   19,   20,   21,
 /*   860 */    22,   23,   24,   25,   26,   27,   28,   29,   30,   31,
 /*   870 */    32,   33,   34,   35,   36,   37,   38,   39,   40,  237,
 /*   880 */   262,   73,  235,  181,   20,   47,  229,    1,    2,    3,
 /*   890 */     4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*   900 */    62,   15,   16,   17,   18,   19,   20,   21,   22,   23,
 /*   910 */    24,   25,   26,   27,   28,   29,   30,   31,   32,   33,
 /*   920 */    34,   35,   36,   37,   38,   39,   40,  181,  196,   50,
 /*   930 */   171,   49,  170,   47,   14,    1,    2,    3,    4,    5,
 /*   940 */     6,    7,    8,    9,   10,   11,   12,   13,   62,   15,
 /*   950 */    16,   17,   18,   19,   20,   21,   22,   23,   24,   25,
 /*   960 */    26,   27,   28,   29,   30,   31,   32,   33,   34,   35,
 /*   970 */    36,   37,   38,   39,   40,  197,  170,   61,  174,  200,
 /*   980 */   180,   47,  213,    1,    2,    3,    4,    5,    6,    7,
 /*   990 */     8,    9,   10,   11,   12,   13,   62,   15,   16,   17,
 /*  1000 */    18,   19,   20,   21,   22,   23,   24,   25,   26,   27,
 /*  1010 */    28,   29,   30,   31,   32,   33,   34,   35,   36,   37,
 /*  1020 */    38,   39,   40,  176,  213,  213,  193,  176,   65,   47,
 /*  1030 */    54,    1,    2,    3,    4,    5,    6,    7,    8,    9,
 /*  1040 */    10,   11,   12,   13,   62,   15,   16,   17,   18,   19,
 /*  1050 */    20,   21,   22,   23,   24,   25,   26,   27,   28,   29,
 /*  1060 */    30,   31,   32,   33,   34,   35,   36,   37,   38,   39,
 /*  1070 */    40,  173,  174,   53,   62,   44,   61,   47,   45,    1,
 /*  1080 */     2,    3,    4,    5,    6,    7,    8,    9,   10,   11,
 /*  1090 */    12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
 /*  1100 */    22,   23,   24,   25,   26,   27,   28,   29,   30,   31,
 /*  1110 */    32,   33,   34,   35,   36,   37,   38,   39,   40,  221,
 /*  1120 */    56,   57,   58,   50,   60,   47,   54,   65,   54,   65,
 /*  1130 */    42,   43,   44,   45,   46,   62,   72,   53,   49,   47,
 /*  1140 */    47,  243,  244,  245,   50,  115,   49,    1,    2,    3,
 /*  1150 */     4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*  1160 */    66,   15,   16,   17,   18,   19,   20,   21,   22,   23,
 /*  1170 */    24,   25,   26,   27,   28,   29,   30,   31,   32,   33,
 /*  1180 */    34,   35,   36,   37,   38,   39,   40,   49,   66,   66,
 /*  1190 */    66,   61,   45,   47,   45,    1,    2,    3,    4,    5,
 /*  1200 */     6,    7,    8,    9,   10,   11,   12,   13,   62,   15,
 /*  1210 */    16,   17,   18,   19,   20,   21,   22,   23,   24,   25,
 /*  1220 */    26,   27,   28,   29,   30,   31,   32,   33,   34,   35,
 /*  1230 */    36,   37,   38,   39,   40,   65,   62,   61,   45,   62,
 /*  1240 */    61,   47,   45,   49,   62,    1,    2,    3,    4,    5,
 /*  1250 */     6,    7,    8,    9,   10,   11,   12,   13,   45,   15,
 /*  1260 */    16,   17,   18,   19,   20,   21,   22,   23,   24,   25,
 /*  1270 */    26,   27,   28,   29,   30,   31,   32,   33,   34,   35,
 /*  1280 */    36,   37,   38,   39,   40,   61,   61,   54,   49,    1,
 /*  1290 */    13,   47,   15,   16,   17,   18,   19,   20,   21,   22,
 /*  1300 */    23,   24,   25,   26,   27,   28,   29,   30,   31,   32,
 /*  1310 */    33,   34,   35,   36,   37,   38,   39,   40,   44,   50,
 /*  1320 */    50,  173,  174,   66,   47,  156,  157,   53,   54,   66,
 /*  1330 */    73,   74,   62,   54,   50,   66,  167,  168,   64,   26,
 /*  1340 */    27,   28,   29,   30,   31,   32,   33,   34,   35,   36,
 /*  1350 */    37,   38,   39,   40,   50,  234,  187,  188,  189,  190,
 /*  1360 */    47,  240,  241,  242,   90,   91,   92,   93,   94,   95,
 /*  1370 */    96,   97,   98,   99,  100,  101,  102,  103,  104,  105,
 /*  1380 */   106,  174,  108,  109,   65,   50,   50,   50,    1,   14,
 /*  1390 */    45,  243,  244,  245,   48,   45,  153,   49,   62,  251,
 /*  1400 */   174,  144,  233,   66,   50,  131,  132,  133,    0,   63,
 /*  1410 */    49,   45,   45,   67,   68,   69,   62,   71,   45,   73,
 /*  1420 */    74,   75,   16,   17,   18,   19,   20,   21,   22,   23,
 /*  1430 */    24,   25,   26,   27,   28,   29,   30,   31,   32,   33,
 /*  1440 */    34,   35,   36,   37,   38,   39,   40,  156,  173,  174,
 /*  1450 */   243,  244,  245,   47,  173,  174,   48,  157,   49,   51,
 /*  1460 */    52,   53,  157,   65,  173,  174,  166,  167,  168,  243,
 /*  1470 */   244,  245,  167,  168,   49,   67,   49,    1,  187,   71,
 /*  1480 */    54,   73,   74,  183,  184,  185,  186,  187,   49,  198,
 /*  1490 */   144,  216,  187,  115,   65,  190,   33,   34,    1,  115,
 /*  1500 */    66,  201,  221,   46,  213,   49,  215,   73,   74,   49,
 /*  1510 */    49,   62,   49,  222,  223,  224,  225,   54,  243,  244,
 /*  1520 */   245,  246,  247,  174,  243,  244,  245,   54,   50,   66,
 /*  1530 */   115,   21,   20,  233,  243,  244,  245,   21,  233,  248,
 /*  1540 */   249,  250,  251,  252,  253,  254,  255,  256,  257,   50,
 /*  1550 */    20,  260,   17,   18,   19,   20,   21,   22,   23,   24,
 /*  1560 */    25,   26,   27,   28,   29,   30,   31,   32,   33,   34,
 /*  1570 */    35,   36,   37,   38,   39,   40,   20,   54,  144,  156,
 /*  1580 */    21,   21,   47,  173,  174,   54,    1,  173,  174,   65,
 /*  1590 */    33,   34,  243,  244,  245,   66,  173,  174,   54,   42,
 /*  1600 */    43,   44,   45,   33,   34,   62,   49,   45,   21,   20,
 /*  1610 */   187,   54,   54,   33,   34,  174,   62,   54,   61,   49,
 /*  1620 */    14,  198,   42,   43,   54,   45,   47,   70,   61,   49,
 /*  1630 */     1,  221,   54,   49,   54,  221,   66,   66,  215,   82,
 /*  1640 */   156,   61,   54,  156,   70,  222,  223,  224,  225,   50,
 /*  1650 */    70,   54,   14,  243,  244,  245,   54,  243,  244,  245,
 /*  1660 */   173,  174,   82,  173,  174,  181,  243,  244,  245,   50,
 /*  1670 */   156,  248,  249,  250,  251,  252,  253,  254,  255,  256,
 /*  1680 */   257,  174,   54,  260,  243,  244,  245,  173,  174,   50,
 /*  1690 */    49,  134,  135,  136,  137,  138,  139,  140,  141,  142,
 /*  1700 */   143,  187,  218,  219,  220,   50,   14,   54,  221,   49,
 /*  1710 */    54,  156,  198,  263,  134,  135,  136,  137,  138,  139,
 /*  1720 */   140,  141,  142,  143,  263,  173,  174,  213,  173,  174,
 /*  1730 */   243,  244,  245,  243,  244,  245,  222,  223,  224,  225,
 /*  1740 */   263,  251,  187,  263,  263,  263,  173,  174,  263,  259,
 /*  1750 */   243,  244,  245,  198,  263,  263,  263,  243,  244,  245,
 /*  1760 */   263,  263,  248,  249,  250,  251,  252,  253,  254,  255,
 /*  1770 */   256,  257,  174,  221,  260,  263,  263,  222,  223,  224,
 /*  1780 */   225,  263,  263,  172,  173,  174,  263,  173,  174,  263,
 /*  1790 */   263,  263,  263,  263,  221,  243,  244,  245,  243,  244,
 /*  1800 */   245,  263,  156,  248,  249,  250,  251,  252,  253,  254,
 /*  1810 */   255,  256,  257,  173,  174,  260,  243,  244,  245,  173,
 /*  1820 */   174,  263,  263,  263,  263,  263,  263,  263,  263,  263,
 /*  1830 */   263,  263,  263,  187,  263,  263,  263,  173,  174,  263,
 /*  1840 */   263,  243,  244,  245,  198,  156,  173,  174,  263,  173,
 /*  1850 */   174,  263,  173,  174,  243,  244,  245,  243,  244,  245,
 /*  1860 */   263,  263,  173,  174,  263,  263,  263,  263,  222,  223,
 /*  1870 */   224,  225,  263,  263,  263,  263,  187,  263,  263,  263,
 /*  1880 */   263,  263,  263,  243,  244,  245,  263,  198,  263,  243,
 /*  1890 */   244,  245,  173,  174,  248,  249,  250,  251,  252,  253,
 /*  1900 */   254,  255,  256,  257,  263,  263,  260,  243,  244,  245,
 /*  1910 */   263,  222,  223,  224,  225,  263,  243,  244,  245,  243,
 /*  1920 */   244,  245,  243,  244,  245,  263,  263,  173,  174,  263,
 /*  1930 */   263,  263,  243,  244,  245,  156,  263,  248,  249,  250,
 /*  1940 */   251,  252,  253,  254,  255,  256,  257,  263,  263,  260,
 /*  1950 */   263,  263,  173,  174,  263,  263,  263,  263,  263,  263,
 /*  1960 */   263,  263,  243,  244,  245,  263,  187,  263,  263,  263,
 /*  1970 */   263,  263,  263,  263,  263,  263,  156,  198,  173,  174,
 /*  1980 */   263,  263,  173,  174,  263,  173,  174,  263,  173,  174,
 /*  1990 */   263,  263,  263,  173,  174,  263,  263,  243,  244,  245,
 /*  2000 */   263,  222,  223,  224,  225,  263,  263,  187,  263,  263,
 /*  2010 */   263,  173,  174,  263,  263,  263,  263,  263,  198,  263,
 /*  2020 */   156,  263,  243,  244,  245,  263,  263,  248,  249,  250,
 /*  2030 */   251,  252,  253,  254,  255,  256,  257,  173,  174,  260,
 /*  2040 */   263,  263,  222,  223,  224,  225,  263,  263,  243,  244,
 /*  2050 */   245,  187,  243,  244,  245,  243,  244,  245,  243,  244,
 /*  2060 */   245,  263,  198,  243,  244,  245,  173,  174,  248,  249,
 /*  2070 */   250,  251,  252,  253,  254,  255,  256,  257,  263,  263,
 /*  2080 */   260,  243,  244,  245,  263,  263,  222,  223,  224,  225,
 /*  2090 */   173,  174,  263,  173,  174,  263,  263,  263,  173,  174,
 /*  2100 */   263,  173,  174,  263,  263,  263,  263,  243,  244,  245,
 /*  2110 */   156,  263,  248,  249,  250,  251,  252,  253,  254,  255,
 /*  2120 */   256,  257,  263,  263,  260,  263,  263,  173,  174,  263,
 /*  2130 */   263,  263,  263,  263,  263,  263,  243,  244,  245,  263,
 /*  2140 */   263,  187,  263,  263,  263,  263,   33,   34,  263,  263,
 /*  2150 */   263,  263,  198,  263,  263,   42,   43,  263,   45,  263,
 /*  2160 */   243,  244,  245,  243,  244,  245,   53,   54,  243,  244,
 /*  2170 */   245,  243,  244,  245,   61,  263,  222,  223,  224,  225,
 /*  2180 */   263,  263,  263,   70,  263,  263,  263,  263,  263,  263,
 /*  2190 */   263,  263,  263,  263,  263,   82,  263,  243,  244,  245,
 /*  2200 */   263,  263,  248,  249,  250,  251,  252,  253,  254,  255,
 /*  2210 */   256,  257,  263,  263,  260,  263,  263,  263,   20,   21,
 /*  2220 */    22,   23,   24,   25,   26,   27,   28,   29,   30,   31,
 /*  2230 */    32,   33,   34,   35,   36,   37,   38,   39,   40,  263,
 /*  2240 */   263,  263,  263,  263,  263,   47,  263,  134,  135,  136,
 /*  2250 */   137,  138,  139,  140,  141,  142,  143,   33,   34,  263,
 /*  2260 */   263,  263,  263,  173,  174,  263,   42,   43,  263,   45,
 /*  2270 */    33,   34,  173,  174,  263,  263,  263,  263,   54,   42,
 /*  2280 */    43,  263,   45,   33,   34,   61,  263,  263,  198,   65,
 /*  2290 */   263,   54,   42,   43,   70,   45,  263,  263,   61,  263,
 /*  2300 */   263,  263,  263,  263,   54,  263,   82,   70,  263,  263,
 /*  2310 */   263,   61,  222,  223,  224,  225,  263,  263,  263,   82,
 /*  2320 */    70,  263,  263,  263,  263,  263,  173,  174,  263,  173,
 /*  2330 */   174,  263,   82,  243,  244,  245,  173,  174,  263,  173,
 /*  2340 */   174,  251,  243,  244,  245,  263,  256,  263,  258,  259,
 /*  2350 */   173,  174,  263,  173,  174,  263,  263,  263,  134,  135,
 /*  2360 */   136,  137,  138,  139,  140,  141,  142,  143,  263,  173,
 /*  2370 */   174,  134,  135,  136,  137,  138,  139,  140,  141,  142,
 /*  2380 */   143,  173,  174,  263,  134,  135,  136,  137,  138,  139,
 /*  2390 */   140,  141,  142,  143,  173,  174,  243,  244,  245,  243,
 /*  2400 */   244,  245,  173,  174,  263,  263,  243,  244,  245,  243,
 /*  2410 */   244,  245,  173,  174,  263,  263,  263,  263,  263,  263,
 /*  2420 */   243,  244,  245,  243,  244,  245,  173,  174,  263,  173,
 /*  2430 */   174,  263,  173,  174,  263,  263,  263,  173,  174,  243,
 /*  2440 */   244,  245,  263,  173,  174,  263,  173,  174,  263,  263,
 /*  2450 */   263,  243,  244,  245,  173,  174,  263,  173,  174,  263,
 /*  2460 */   263,  263,  173,  174,  243,  244,  245,  173,  174,  263,
 /*  2470 */   263,  263,  243,  244,  245,  263,  263,  263,  173,  174,
 /*  2480 */   263,  263,  243,  244,  245,  173,  174,  263,  173,  174,
 /*  2490 */   263,  263,  263,  173,  174,  263,  243,  244,  245,  243,
 /*  2500 */   244,  245,  243,  244,  245,  263,  263,  243,  244,  245,
 /*  2510 */   173,  174,  263,  243,  244,  245,  243,  244,  245,  263,
 /*  2520 */   173,  174,  263,  263,  243,  244,  245,  243,  244,  245,
 /*  2530 */   263,  263,  243,  244,  245,  173,  174,  243,  244,  245,
 /*  2540 */   173,  174,  263,  173,  174,  263,  173,  174,  243,  244,
 /*  2550 */   245,  173,  174,  263,  263,  243,  244,  245,  243,  244,
 /*  2560 */   245,  173,  174,  243,  244,  245,  173,  174,  263,  173,
 /*  2570 */   174,  263,  173,  174,  263,  173,  174,  263,  263,  263,
 /*  2580 */   243,  244,  245,  173,  174,  263,  173,  174,  263,  263,
 /*  2590 */   243,  244,  245,  263,  173,  174,  263,  263,  263,  263,
 /*  2600 */   263,  263,  263,  263,  263,  243,  244,  245,  263,  263,
 /*  2610 */   243,  244,  245,  243,  244,  245,  243,  244,  245,  263,
 /*  2620 */   263,  243,  244,  245,  263,  263,  263,  263,  263,  263,
 /*  2630 */   263,  243,  244,  245,  263,  263,  243,  244,  245,  243,
 /*  2640 */   244,  245,  243,  244,  245,  243,  244,  245,  263,  263,
 /*  2650 */   263,  263,  263,  243,  244,  245,  243,  244,  245,  263,
 /*  2660 */   263,  263,  263,  263,  243,  244,  245,
};
#define YY_SHIFT_USE_DFLT (2667)
#define YY_SHIFT_COUNT    (376)
#define YY_SHIFT_MIN      (-33)
#define YY_SHIFT_MAX      (2250)
static const short yy_shift_ofst[] = {
 /*     0 */  2667,  237,  -33,  237,  102,  237,  237,  237,  237,  237,
 /*    10 */   237,  548,  249, 1346,  455,  346, 1408, 1257, 2237, 2237,
 /*    20 */  2237, 2250, 2250, 2237,  -10,  -10,  -10,  -10, 1557, 1580,
 /*    30 */  2113, 2250, 2250, 2250, 2250, 2250, 2250, 2250, 1463, 1434,
 /*    40 */  1274,  -10, 2224, 2250, 2250, 2250, 2250, 2250, 2250, 2250,
 /*    50 */  2250, 2250, 2250, 2250, 2250, 2250, 2250, 2250, 2250, 2250,
 /*    60 */  2250, 2250, 2250, 2250, 2250, 2250, 2250, 2250, 2250, 2250,
 /*    70 */  2250, 2250, 2250, 2250, 2250, 2250, 2250, 2250, 2250, 2250,
 /*    80 */  2250, 2250, 2250, 2250, 2250, 2250, 2250, 2250, 2250, 2250,
 /*    90 */  2250, 2250, 2250, 2250, 2250, 2250, 2250, 2250, 2250, 2250,
 /*   100 */  2250, 2250, 1570, 2250, 2250, 2250, 2250, 2250, 2250, 2250,
 /*   110 */  2250,  335,  193,  -25,   25,  -30,  343,  324,   32,  103,
 /*   120 */    39,  155,  103,  243, 2667, 1244,   95,  373,  373,  373,
 /*   130 */   -27,  267,  369,  487,  463,  463,  566,  463,  463,  463,
 /*   140 */   463,  737,  735,  726,  786,  783,  781,  786,  798,  155,
 /*   150 */   808,  103,  103,  463,  864,  463,   25,  879,  882,  920,
 /*   160 */   882,  916, 2667, 2667, 2667, 2667, 2667, 2667, 2667, 2667,
 /*   170 */   475,  538,  691,  739,  790,  838,  886,  934,  982, 1030,
 /*   180 */  1078, 1146, 1194, 1244, 1244, 1244, 1244, 1244, 1244, 1244,
 /*   190 */  1244, 1244, 1244, 1244, 1244, 1244, 1244, 1244, 1244, 1244,
 /*   200 */  1244, 1244, 1244, 1244, 1244, 1244, 1277, 1406, 1535, 2198,
 /*   210 */  2198, 2198, 1313, 1313, 1313, 1313, 1313, 1313,  185,  320,
 /*   220 */    94,  589,  225,  225,  225,  238,  238,  306, 1064, 1088,
 /*   230 */   110,  105,  482,  -14,  611,  333, 1073,  534,  608, 1094,
 /*   240 */    47, 1270,  582, 1269, 1337,  137,  568,  300,  683, 1336,
 /*   250 */  1354,  358,  358,  358,  358,  358,  963,  976, 1020, 1031,
 /*   260 */  1012, 1015, 1033, 1031, 1072, 1074, 1084, 1031, 1031, 1089,
 /*   270 */  1062, 1092, 1093, 1097, 1138, 1122, 1123, 1124, 1130, 1147,
 /*   280 */  1149, 1170, 1174, 1176, 1193, 1177, 1179, 1197, 1182, 1224,
 /*   290 */  1225, 1213, 1233, 1239, 1288, 1279, 1284, 1304, 1263, 1319,
 /*   300 */  1335, 1387, 1375, 1345, 1350, 1243, 1348, 1361, 1366, 1367,
 /*   310 */  1373,  735, 1409, 1425, 1427, 1398, 1476, 1426, 1378, 1439,
 /*   320 */  1429, 1497, 1384, 1457, 1456, 1460, 1461, 1473, 1449, 1478,
 /*   330 */  1415, 1510, 1512, 1516, 1499, 1530, 1556, 1031, 1559, 1523,
 /*   340 */  1560, 1530, 1531, 1585, 1529, 1524, 1544, 1562, 1543, 1587,
 /*   350 */  1558, 1589, 1554, 1563, 1579, 1567, 1606, 1629, 1578, 1571,
 /*   360 */  1588, 1584, 1574, 1599, 1597, 1638, 1602, 1619, 1628, 1639,
 /*   370 */  1655, 1641, 1692, 1653, 1660, 1656, 1567,
};
#define YY_REDUCE_USE_DFLT (-192)
#define YY_REDUCE_COUNT (169)
#define YY_REDUCE_MIN   (-191)
#define YY_REDUCE_MAX   (2421)
static const short yy_reduce_ofst[] = {
 /*     0 */   -19, 1291, 1423, 1514, 1555, 1646, 1689, 1779, 1820, 1864,
 /*    10 */  1954, 2090,   -7,   -7, 1300,  197, -161, 1169,  421,  489,
 /*    20 */  1275, 1487, 1490,  -16, -183, -172,   71,   86,  898, 1281,
 /*    30 */   360, 1148, 1410, 1414,   61, 1552, 1573, 1611,  452, 1305,
 /*    40 */   235,  391,  433, 1614, 1640, 1664, 1673, 1676, 1679, 1719,
 /*    50 */  1754, 1805, 1809, 1812, 1815, 1838, 1893, 1917, 1920, 1925,
 /*    60 */  1928, 2099, 2153, 2156, 2163, 2166, 2177, 2180, 2196, 2208,
 /*    70 */  2221, 2229, 2239, 2253, 2256, 2259, 2264, 2270, 2273, 2281,
 /*    80 */  2284, 2289, 2294, 2305, 2312, 2315, 2320, 2337, 2347, 2362,
 /*    90 */  2367, 2370, 2373, 2378, 2388, 2393, 2396, 2399, 2402, 2410,
 /*   100 */  2413, 2421, 1484,  353,  436, 1207, 1226, 1349, 1441, 1507,
 /*   110 */  1598, -181, 1121,  423,  -56,  427, -191, -184,  -78,  -78,
 /*   120 */   -60,    5,   57,  177,  -82,   78,  128,   85,  187,  189,
 /*   130 */   253,  222,  204,  311,  354,  357,  432,  454,  558,  599,
 /*   140 */   600,  573,  572,  576,  620,  595,  644,  626,  642,  618,
 /*   150 */   647,  222,  222,  702,  657,  746,  732,  759,  762,  778,
 /*   160 */   806,  804,  779,  800,  847,  769,  811,  812,  833,  851,
};
static const YYACTIONTYPE yy_default[] = {
 /*     0 */  1003, 1090, 1367, 1090, 1367, 1367, 1367, 1367, 1367, 1367,
 /*    10 */  1367, 1317, 1179, 1179, 1179, 1367, 1367, 1179, 1278, 1278,
 /*    20 */  1278, 1367, 1317, 1278, 1367, 1367, 1367, 1367, 1367, 1367,
 /*    30 */  1367, 1367, 1367, 1367, 1012, 1367, 1367, 1012, 1367, 1179,
 /*    40 */  1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367,
 /*    50 */  1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367,
 /*    60 */  1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367,
 /*    70 */  1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367,
 /*    80 */  1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367,
 /*    90 */  1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367,
 /*   100 */  1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367,
 /*   110 */  1367, 1367, 1212, 1367, 1069, 1367, 1121, 1328, 1176, 1176,
 /*   120 */  1212, 1367, 1347, 1367, 1091, 1107, 1367, 1104, 1104, 1104,
 /*   130 */  1367, 1329, 1367, 1367, 1367, 1367, 1017, 1367, 1367, 1367,
 /*   140 */  1367, 1123, 1090, 1367, 1086, 1182, 1367, 1086, 1367, 1367,
 /*   150 */  1203, 1177, 1167, 1367, 1163, 1367, 1339, 1338, 1336, 1065,
 /*   160 */  1336, 1367, 1074, 1019, 1032, 1090, 1090, 1090, 1050, 1032,
 /*   170 */  1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367,
 /*   180 */  1367, 1367, 1367, 1105, 1211, 1330, 1326, 1276, 1358, 1309,
 /*   190 */  1340, 1071, 1280, 1273, 1272, 1271, 1270, 1269, 1268, 1267,
 /*   200 */  1266, 1265, 1264, 1263, 1262, 1279, 1275, 1261, 1260, 1256,
 /*   210 */  1255, 1254, 1253, 1252, 1251, 1250, 1249, 1248, 1247, 1259,
 /*   220 */  1258, 1257, 1246, 1245, 1244, 1236, 1237, 1016, 1367, 1356,
 /*   230 */  1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367,
 /*   240 */  1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367,
 /*   250 */  1367, 1243, 1242, 1240, 1239, 1238, 1367, 1367, 1367, 1018,
 /*   260 */  1367, 1367, 1367, 1024, 1367, 1367, 1367, 1135, 1134, 1367,
 /*   270 */  1367, 1367, 1026, 1367, 1367, 1367, 1367, 1367, 1367, 1367,
 /*   280 */  1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367,
 /*   290 */  1367, 1367, 1367, 1367, 1210, 1367, 1353, 1316, 1367, 1367,
 /*   300 */  1327, 1367, 1367, 1367, 1367, 1320, 1367, 1367, 1367, 1367,
 /*   310 */  1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367, 1367,
 /*   320 */  1367, 1367, 1367, 1367, 1367, 1367, 1367, 1216, 1367, 1349,
 /*   330 */  1367, 1367, 1367, 1367, 1367, 1367, 1367, 1159, 1367, 1367,
 /*   340 */  1367, 1194, 1367, 1070, 1367, 1367, 1367, 1367, 1367, 1367,
 /*   350 */  1367, 1367, 1367, 1367, 1241, 1361, 1216, 1367, 1367, 1367,
 /*   360 */  1367, 1367, 1367, 1367, 1367, 1367, 1367, 1048, 1367, 1367,
 /*   370 */  1047, 1367, 1367, 1367, 1367, 1367, 1013,
};
/********** End of lemon-generated parsing tables *****************************/

/* The next table maps tokens (terminal symbols) into fallback tokens.  
** If a construct like the following:
** 
**      %fallback ID X Y Z.
**
** appears in the grammar, then ID becomes a fallback token for X, Y,
** and Z.  Whenever one of the tokens X, Y, or Z is input to the parser
** but it does not parse, the type of the token is changed to ID and
** the parse is retried before an error is thrown.
**
** This feature can be used, for example, to cause some keywords in a language
** to revert to identifiers if they keyword does not apply in the context where
** it appears.
*/
#ifdef YYFALLBACK
static const YYCODETYPE yyFallback[] = {
    0,  /*          $ => nothing */
    0,  /*         EQ => nothing */
    0,  /*      MULEQ => nothing */
    0,  /*      DIVEQ => nothing */
    0,  /*      MODEQ => nothing */
    0,  /*      ADDEQ => nothing */
    0,  /*      SUBEQ => nothing */
    0,  /*      LSHEQ => nothing */
    0,  /*      RSHEQ => nothing */
    0,  /*      ANDEQ => nothing */
    0,  /*       OREQ => nothing */
    0,  /*      XOREQ => nothing */
    0,  /*     URSHEQ => nothing */
    0,  /*   QUESTION => nothing */
    0,  /*      COLON => nothing */
    0,  /*       OROR => nothing */
    0,  /*     ANDAND => nothing */
    0,  /*       EQEQ => nothing */
    0,  /*        NEQ => nothing */
    0,  /*   APPROXEQ => nothing */
    0,  /*         LT => nothing */
    0,  /*         GT => nothing */
    0,  /*       LTEQ => nothing */
    0,  /*       GTEQ => nothing */
    0,  /*     LTGTEQ => nothing */
    0,  /*         IS => nothing */
    0,  /*     DOTDOT => nothing */
    0,  /*         OR => nothing */
    0,  /*        XOR => nothing */
    0,  /*        AND => nothing */
    0,  /*        LSH => nothing */
    0,  /*        RSH => nothing */
    0,  /*       URSH => nothing */
    0,  /*        SUB => nothing */
    0,  /*        ADD => nothing */
    0,  /*        MUL => nothing */
    0,  /*        DIV => nothing */
    0,  /*        MOD => nothing */
    0,  /*  CROSSPROD => nothing */
    0,  /*    DOTPROD => nothing */
    0,  /*        POW => nothing */
    0,  /*      UNARY => nothing */
    0,  /*     ADDADD => nothing */
    0,  /*     SUBSUB => nothing */
    0,  /*        DOT => nothing */
    0,  /*     LPAREN => nothing */
    0,  /*   LBRACKET => nothing */
    0,  /*      SCOPE => nothing */
    0,  /*        EOF => nothing */
    0,  /*  SEMICOLON => nothing */
    0,  /*      COMMA => nothing */
    0,  /*    INCLUDE => nothing */
    0,  /*     EXTEND => nothing */
    0,  /*      CLASS => nothing */
    0,  /* IDENTIFIER => nothing */
    0,  /*   ABSTRACT => nothing */
    0,  /*     NATIVE => nothing */
    0,  /*         UI => nothing */
    0,  /*       PLAY => nothing */
    0,  /*   REPLACES => nothing */
    0,  /*    VERSION => nothing */
    0,  /*   STRCONST => nothing */
    0,  /*     RPAREN => nothing */
   54,  /*    DEFAULT => IDENTIFIER */
   54,  /*      COLOR => IDENTIFIER */
    0,  /*     LBRACE => nothing */
    0,  /*     RBRACE => nothing */
    0,  /*      MIXIN => nothing */
   54,  /*   PROPERTY => IDENTIFIER */
    0,  /*    FLAGDEF => nothing */
    0,  /*   INTCONST => nothing */
    0,  /*     STRUCT => nothing */
    0,  /* CLEARSCOPE => nothing */
    0,  /*      CONST => nothing */
    0,  /*       ENUM => nothing */
    0,  /*     STATES => nothing */
    0,  /*        NWS => nothing */
    0,  /*       STOP => nothing */
    0,  /*       WAIT => nothing */
    0,  /*       FAIL => nothing */
    0,  /*       LOOP => nothing */
    0,  /*       GOTO => nothing */
    0,  /*      SUPER => nothing */
    0,  /*     BRIGHT => nothing */
    0,  /*       FAST => nothing */
    0,  /*       SLOW => nothing */
    0,  /*    NODELAY => nothing */
    0,  /*   CANRAISE => nothing */
    0,  /*     OFFSET => nothing */
    0,  /*      LIGHT => nothing */
   54,  /*      SBYTE => IDENTIFIER */
   54,  /*       BYTE => IDENTIFIER */
   54,  /*      SHORT => IDENTIFIER */
   54,  /*     USHORT => IDENTIFIER */
   54,  /*        INT => IDENTIFIER */
   54,  /*       UINT => IDENTIFIER */
   54,  /*       BOOL => IDENTIFIER */
   54,  /*      FLOAT => IDENTIFIER */
   54,  /*     DOUBLE => IDENTIFIER */
   54,  /*    VECTOR2 => IDENTIFIER */
   54,  /*    VECTOR3 => IDENTIFIER */
   54,  /*       NAME => IDENTIFIER */
   54,  /*      SOUND => IDENTIFIER */
   54,  /*      STATE => IDENTIFIER */
    0,  /*        LET => nothing */
    0,  /*     ATSIGN => nothing */
    0,  /*   READONLY => nothing */
   54,  /*     STRING => IDENTIFIER */
   54,  /*        MAP => IDENTIFIER */
   54,  /*      ARRAY => IDENTIFIER */
   54,  /*       VOID => IDENTIFIER */
   54,  /*      UINT8 => IDENTIFIER */
   54,  /*       INT8 => IDENTIFIER */
   54,  /*     UINT16 => IDENTIFIER */
   54,  /*      INT16 => IDENTIFIER */
};
#endif /* YYFALLBACK */

/* The following structure represents a single element of the
** parser's stack.  Information stored includes:
**
**   +  The state number for the parser at this level of the stack.
**
**   +  The value of the token stored at this level of the stack.
**      (In other words, the "major" token.)
**
**   +  The semantic value stored at this level of the stack.  This is
**      the information used by the action routines in the grammar.
**      It is sometimes called the "minor" token.
**
** After the "shift" half of a SHIFTREDUCE action, the stateno field
** actually contains the reduce action for the second half of the
** SHIFTREDUCE.
*/
struct yyStackEntry {
  YYACTIONTYPE stateno;  /* The state-number, or reduce action in SHIFTREDUCE */
  YYCODETYPE major;      /* The major token value.  This is the code
                         ** number for the token at this stack level */
  YYMINORTYPE minor;     /* The user-supplied minor token value.  This
                         ** is the value of the token  */
};
typedef struct yyStackEntry yyStackEntry;

/* The state of the parser is completely contained in an instance of
** the following structure */
struct yyParser {
  yyStackEntry *yytos;          /* Pointer to top element of the stack */
#ifdef YYTRACKMAXSTACKDEPTH
  int yyhwm;                    /* High-water mark of the stack */
#endif
#ifndef YYNOERRORRECOVERY
  int yyerrcnt;                 /* Shifts left before out of the error */
#endif
  ZCCParseARG_SDECL                /* A place to hold %extra_argument */
#if YYSTACKDEPTH<=0
  int yystksz;                  /* Current side of the stack */
  yyStackEntry *yystack;        /* The parser's stack */
  yyStackEntry yystk0;          /* First stack entry */
#else
  yyStackEntry yystack[YYSTACKDEPTH];  /* The parser's stack */
#endif
};
typedef struct yyParser yyParser;

#ifndef NDEBUG
#include <stdio.h>
static FILE *yyTraceFILE = 0;
static char *yyTracePrompt = 0;
#endif /* NDEBUG */

#ifndef NDEBUG
/* 
** Turn parser tracing on by giving a stream to which to write the trace
** and a prompt to preface each trace message.  Tracing is turned off
** by making either argument NULL 
**
** Inputs:
** <ul>
** <li> A FILE* to which trace output should be written.
**      If NULL, then tracing is turned off.
** <li> A prefix string written at the beginning of every
**      line of trace output.  If NULL, then tracing is
**      turned off.
** </ul>
**
** Outputs:
** None.
*/
void ZCCParseTrace(FILE *TraceFILE, char *zTracePrompt){
  yyTraceFILE = TraceFILE;
  yyTracePrompt = zTracePrompt;
  if( yyTraceFILE==0 ) yyTracePrompt = 0;
  else if( yyTracePrompt==0 ) yyTraceFILE = 0;
}
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing shifts, the names of all terminals and nonterminals
** are required.  The following table supplies these names */
static const char *const yyTokenName[] = { 
  "$",             "EQ",            "MULEQ",         "DIVEQ",       
  "MODEQ",         "ADDEQ",         "SUBEQ",         "LSHEQ",       
  "RSHEQ",         "ANDEQ",         "OREQ",          "XOREQ",       
  "URSHEQ",        "QUESTION",      "COLON",         "OROR",        
  "ANDAND",        "EQEQ",          "NEQ",           "APPROXEQ",    
  "LT",            "GT",            "LTEQ",          "GTEQ",        
  "LTGTEQ",        "IS",            "DOTDOT",        "OR",          
  "XOR",           "AND",           "LSH",           "RSH",         
  "URSH",          "SUB",           "ADD",           "MUL",         
  "DIV",           "MOD",           "CROSSPROD",     "DOTPROD",     
  "POW",           "UNARY",         "ADDADD",        "SUBSUB",      
  "DOT",           "LPAREN",        "LBRACKET",      "SCOPE",       
  "EOF",           "SEMICOLON",     "COMMA",         "INCLUDE",     
  "EXTEND",        "CLASS",         "IDENTIFIER",    "ABSTRACT",    
  "NATIVE",        "UI",            "PLAY",          "REPLACES",    
  "VERSION",       "STRCONST",      "RPAREN",        "DEFAULT",     
  "COLOR",         "LBRACE",        "RBRACE",        "MIXIN",       
  "PROPERTY",      "FLAGDEF",       "INTCONST",      "STRUCT",      
  "CLEARSCOPE",    "CONST",         "ENUM",          "STATES",      
  "NWS",           "STOP",          "WAIT",          "FAIL",        
  "LOOP",          "GOTO",          "SUPER",         "BRIGHT",      
  "FAST",          "SLOW",          "NODELAY",       "CANRAISE",    
  "OFFSET",        "LIGHT",         "SBYTE",         "BYTE",        
  "SHORT",         "USHORT",        "INT",           "UINT",        
  "BOOL",          "FLOAT",         "DOUBLE",        "VECTOR2",     
  "VECTOR3",       "NAME",          "SOUND",         "STATE",       
  "LET",           "ATSIGN",        "READONLY",      "STRING",      
  "MAP",           "ARRAY",         "VOID",          "UINT8",       
  "INT8",          "UINT16",        "INT16",         "RBRACKET",    
  "ACTION",        "DEPRECATED",    "STATIC",        "PRIVATE",     
  "PROTECTED",     "LATENT",        "FINAL",         "META",        
  "TRANSIENT",     "INTERNAL",      "VIRTUAL",       "OVERRIDE",    
  "VARARG",        "VIRTUALSCOPE",  "ELLIPSIS",      "IN",          
  "OUT",           "OPTIONAL",      "TILDE",         "BANG",        
  "SIZEOF",        "ALIGNOF",       "UINTCONST",     "FLOATCONST",  
  "NAMECONST",     "FALSE",         "TRUE",          "NULLPTR",     
  "STATICCONST",   "CONTINUE",      "BREAK",         "RETURN",      
  "DO",            "FOR",           "WHILE",         "UNTIL",       
  "IF",            "ELSE",          "SWITCH",        "CASE",        
  "error",         "declarator",    "declarator_no_fun",  "opt_func_body",
  "function_body",  "main",          "translation_unit",  "external_declaration",
  "mixin_definition",  "class_definition",  "struct_def",    "enum_def",    
  "const_def",     "include_def",   "opt_semicolon",  "opt_comma",   
  "opt_expr",      "expr",          "string_constant",  "class_head",  
  "class_innards",  "class_member",  "class_body",    "class_ancestry",
  "class_flags",   "dottable_id",   "mixin_statement",  "property_def",
  "flag_def",      "states_def",    "default_def",   "staticarray_statement",
  "opt_struct_body",  "struct_body",   "struct_member",  "identifier_list",
  "states_opt",    "struct_flags",  "enum_list",     "opt_enum_list",
  "enumerator",    "enum_type",     "int_type",      "mixin_class_definition",
  "mixin_class_body",  "mixin_class_member",  "states_body",   "state_line",  
  "state_label",   "state_flow",    "state_flow_type",  "state_goto_offset",
  "state_action",  "state_call",    "state_call_params",  "state_opts",  
  "states_opts",   "scanner_mode",  "light_list",    "statement_list",
  "func_expr_list",  "default_statement_list",  "default_statement",  "property_statement",
  "flag_statement",  "expr_list",     "type_name",     "type_name1",  
  "aggregate_type",  "type",          "type_list",     "type_list_or_void",
  "type_or_array",  "class_restrictor",  "array_size",    "array_size_expr",
  "variables_or_function",  "decl_flags",    "func_params",   "func_const",  
  "variable_list",  "variable_name",  "decl_flag",     "opt_deprecation_message",
  "func_param_list",  "func_param",    "func_param_flags",  "primary",     
  "unary_expr",    "constant",      "func_expr_item",  "named_expr",  
  "compound_statement",  "statement",     "labeled_statement",  "expression_statement",
  "selection_statement",  "iteration_statement",  "jump_statement",  "assign_statement",
  "local_var",     "while_or_until",  "for_init",      "for_bump",    
  "if_front",      "variable_list_with_init",  "var_init",    
};
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing reduce actions, the names of all rules are required.
*/
static const char *const yyRuleName[] = {
 /*   0 */ "main ::= translation_unit",
 /*   1 */ "translation_unit ::=",
 /*   2 */ "translation_unit ::= translation_unit external_declaration",
 /*   3 */ "translation_unit ::= error",
 /*   4 */ "external_declaration ::= mixin_definition",
 /*   5 */ "external_declaration ::= class_definition",
 /*   6 */ "external_declaration ::= struct_def",
 /*   7 */ "external_declaration ::= enum_def",
 /*   8 */ "external_declaration ::= const_def",
 /*   9 */ "external_declaration ::= include_def",
 /*  10 */ "opt_expr ::=",
 /*  11 */ "include_def ::= INCLUDE string_constant",
 /*  12 */ "class_definition ::= class_head class_body",
 /*  13 */ "class_head ::= EXTEND CLASS IDENTIFIER",
 /*  14 */ "class_head ::= CLASS IDENTIFIER class_ancestry class_flags",
 /*  15 */ "class_ancestry ::=",
 /*  16 */ "class_ancestry ::= COLON dottable_id",
 /*  17 */ "class_flags ::=",
 /*  18 */ "class_flags ::= class_flags ABSTRACT",
 /*  19 */ "class_flags ::= class_flags NATIVE",
 /*  20 */ "class_flags ::= class_flags UI",
 /*  21 */ "class_flags ::= class_flags PLAY",
 /*  22 */ "class_flags ::= class_flags REPLACES dottable_id",
 /*  23 */ "class_flags ::= class_flags VERSION LPAREN STRCONST RPAREN",
 /*  24 */ "dottable_id ::= IDENTIFIER",
 /*  25 */ "dottable_id ::= dottable_id DOT IDENTIFIER",
 /*  26 */ "dottable_id ::= dottable_id DOT DEFAULT",
 /*  27 */ "dottable_id ::= dottable_id DOT COLOR",
 /*  28 */ "class_body ::= SEMICOLON class_innards EOF",
 /*  29 */ "class_body ::= LBRACE class_innards RBRACE",
 /*  30 */ "class_innards ::=",
 /*  31 */ "class_innards ::= class_innards class_member",
 /*  32 */ "class_member ::= declarator",
 /*  33 */ "class_member ::= mixin_statement",
 /*  34 */ "class_member ::= enum_def",
 /*  35 */ "class_member ::= struct_def",
 /*  36 */ "class_member ::= states_def",
 /*  37 */ "class_member ::= default_def",
 /*  38 */ "class_member ::= const_def",
 /*  39 */ "class_member ::= property_def",
 /*  40 */ "class_member ::= flag_def",
 /*  41 */ "class_member ::= staticarray_statement",
 /*  42 */ "mixin_statement ::= MIXIN IDENTIFIER SEMICOLON",
 /*  43 */ "property_def ::= PROPERTY IDENTIFIER COLON identifier_list SEMICOLON",
 /*  44 */ "flag_def ::= FLAGDEF IDENTIFIER COLON IDENTIFIER COMMA INTCONST SEMICOLON",
 /*  45 */ "identifier_list ::= IDENTIFIER",
 /*  46 */ "identifier_list ::= states_opt COMMA IDENTIFIER",
 /*  47 */ "struct_def ::= STRUCT IDENTIFIER struct_flags LBRACE opt_struct_body RBRACE opt_semicolon",
 /*  48 */ "struct_flags ::=",
 /*  49 */ "struct_flags ::= struct_flags UI",
 /*  50 */ "struct_flags ::= struct_flags PLAY",
 /*  51 */ "struct_flags ::= struct_flags CLEARSCOPE",
 /*  52 */ "struct_flags ::= struct_flags NATIVE",
 /*  53 */ "struct_flags ::= struct_flags VERSION LPAREN STRCONST RPAREN",
 /*  54 */ "opt_struct_body ::=",
 /*  55 */ "opt_struct_body ::= error",
 /*  56 */ "struct_body ::= struct_body struct_member",
 /*  57 */ "struct_member ::= declarator",
 /*  58 */ "struct_member ::= enum_def",
 /*  59 */ "struct_member ::= const_def",
 /*  60 */ "struct_member ::= staticarray_statement",
 /*  61 */ "const_def ::= CONST IDENTIFIER EQ expr SEMICOLON",
 /*  62 */ "enum_def ::= ENUM IDENTIFIER enum_type LBRACE opt_enum_list RBRACE opt_semicolon",
 /*  63 */ "enum_type ::=",
 /*  64 */ "enum_type ::= COLON int_type",
 /*  65 */ "enum_list ::= error",
 /*  66 */ "enum_list ::= enum_list COMMA enumerator",
 /*  67 */ "opt_enum_list ::=",
 /*  68 */ "enumerator ::= IDENTIFIER",
 /*  69 */ "enumerator ::= IDENTIFIER EQ expr",
 /*  70 */ "mixin_definition ::= mixin_class_definition",
 /*  71 */ "mixin_class_definition ::= MIXIN CLASS IDENTIFIER LBRACE mixin_class_body RBRACE",
 /*  72 */ "mixin_class_body ::=",
 /*  73 */ "mixin_class_body ::= mixin_class_body mixin_class_member",
 /*  74 */ "mixin_class_member ::= declarator",
 /*  75 */ "mixin_class_member ::= enum_def",
 /*  76 */ "mixin_class_member ::= struct_def",
 /*  77 */ "mixin_class_member ::= states_def",
 /*  78 */ "mixin_class_member ::= default_def",
 /*  79 */ "mixin_class_member ::= const_def",
 /*  80 */ "mixin_class_member ::= property_def",
 /*  81 */ "mixin_class_member ::= flag_def",
 /*  82 */ "mixin_class_member ::= staticarray_statement",
 /*  83 */ "states_def ::= STATES states_opts scanner_mode LBRACE states_body RBRACE",
 /*  84 */ "states_opts ::=",
 /*  85 */ "states_opts ::= LPAREN states_opt RPAREN",
 /*  86 */ "states_opt ::= IDENTIFIER",
 /*  87 */ "states_opt ::= states_opt COMMA IDENTIFIER",
 /*  88 */ "scanner_mode ::=",
 /*  89 */ "states_body ::=",
 /*  90 */ "states_body ::= error",
 /*  91 */ "states_body ::= states_body state_line",
 /*  92 */ "states_body ::= states_body state_label",
 /*  93 */ "states_body ::= states_body state_flow",
 /*  94 */ "state_label ::= NWS COLON",
 /*  95 */ "state_flow_type ::= STOP",
 /*  96 */ "state_flow_type ::= WAIT",
 /*  97 */ "state_flow_type ::= FAIL",
 /*  98 */ "state_flow_type ::= LOOP",
 /*  99 */ "state_flow_type ::= GOTO dottable_id state_goto_offset",
 /* 100 */ "state_flow_type ::= GOTO IDENTIFIER SCOPE dottable_id state_goto_offset",
 /* 101 */ "state_flow_type ::= GOTO SUPER SCOPE dottable_id state_goto_offset",
 /* 102 */ "state_goto_offset ::=",
 /* 103 */ "state_goto_offset ::= ADD expr",
 /* 104 */ "state_line ::= NWS NWS expr state_opts state_action",
 /* 105 */ "state_opts ::=",
 /* 106 */ "state_opts ::= state_opts BRIGHT",
 /* 107 */ "state_opts ::= state_opts FAST",
 /* 108 */ "state_opts ::= state_opts SLOW",
 /* 109 */ "state_opts ::= state_opts NODELAY",
 /* 110 */ "state_opts ::= state_opts CANRAISE",
 /* 111 */ "state_opts ::= state_opts OFFSET LPAREN expr COMMA expr RPAREN",
 /* 112 */ "state_opts ::= state_opts LIGHT LPAREN light_list RPAREN",
 /* 113 */ "light_list ::= STRCONST",
 /* 114 */ "light_list ::= light_list COMMA STRCONST",
 /* 115 */ "state_action ::= LBRACE statement_list scanner_mode RBRACE",
 /* 116 */ "state_action ::= LBRACE scanner_mode RBRACE",
 /* 117 */ "state_action ::= LBRACE error scanner_mode RBRACE",
 /* 118 */ "state_action ::= state_call scanner_mode SEMICOLON",
 /* 119 */ "state_call ::=",
 /* 120 */ "state_call ::= IDENTIFIER state_call_params",
 /* 121 */ "state_call_params ::=",
 /* 122 */ "state_call_params ::= LPAREN func_expr_list RPAREN",
 /* 123 */ "default_def ::= DEFAULT LBRACE RBRACE",
 /* 124 */ "default_def ::= DEFAULT LBRACE default_statement_list RBRACE",
 /* 125 */ "default_def ::= DEFAULT LBRACE error RBRACE",
 /* 126 */ "default_statement_list ::= default_statement",
 /* 127 */ "default_statement_list ::= default_statement_list default_statement",
 /* 128 */ "default_statement ::= SEMICOLON",
 /* 129 */ "default_statement ::= error SEMICOLON",
 /* 130 */ "default_statement ::= property_statement",
 /* 131 */ "default_statement ::= flag_statement",
 /* 132 */ "flag_statement ::= ADD dottable_id",
 /* 133 */ "flag_statement ::= SUB dottable_id",
 /* 134 */ "property_statement ::= dottable_id expr_list SEMICOLON",
 /* 135 */ "property_statement ::= dottable_id SEMICOLON",
 /* 136 */ "int_type ::= SBYTE",
 /* 137 */ "int_type ::= BYTE",
 /* 138 */ "int_type ::= SHORT",
 /* 139 */ "int_type ::= USHORT",
 /* 140 */ "int_type ::= INT",
 /* 141 */ "int_type ::= UINT",
 /* 142 */ "type_name1 ::= BOOL",
 /* 143 */ "type_name1 ::= FLOAT",
 /* 144 */ "type_name1 ::= DOUBLE",
 /* 145 */ "type_name1 ::= VECTOR2",
 /* 146 */ "type_name1 ::= VECTOR3",
 /* 147 */ "type_name1 ::= NAME",
 /* 148 */ "type_name1 ::= SOUND",
 /* 149 */ "type_name1 ::= STATE",
 /* 150 */ "type_name1 ::= COLOR",
 /* 151 */ "type_name1 ::= LET",
 /* 152 */ "type_name ::= type_name1",
 /* 153 */ "type_name ::= IDENTIFIER",
 /* 154 */ "type_name ::= ATSIGN IDENTIFIER",
 /* 155 */ "type_name ::= READONLY LT IDENTIFIER GT",
 /* 156 */ "type_name ::= READONLY LT ATSIGN IDENTIFIER GT",
 /* 157 */ "type_name ::= DOT dottable_id",
 /* 158 */ "aggregate_type ::= MAP LT type_or_array COMMA type_or_array GT",
 /* 159 */ "aggregate_type ::= ARRAY LT type_or_array GT",
 /* 160 */ "aggregate_type ::= CLASS class_restrictor",
 /* 161 */ "class_restrictor ::=",
 /* 162 */ "class_restrictor ::= LT dottable_id GT",
 /* 163 */ "type ::= type_name",
 /* 164 */ "type ::= aggregate_type",
 /* 165 */ "type_or_array ::= type array_size",
 /* 166 */ "type_list ::= type_list COMMA type_or_array",
 /* 167 */ "type_list_or_void ::= VOID",
 /* 168 */ "array_size_expr ::= LBRACKET opt_expr RBRACKET",
 /* 169 */ "array_size ::= array_size array_size_expr",
 /* 170 */ "declarator ::= decl_flags type_list_or_void variables_or_function",
 /* 171 */ "variables_or_function ::= IDENTIFIER LPAREN func_params RPAREN func_const opt_func_body",
 /* 172 */ "variables_or_function ::= variable_list SEMICOLON",
 /* 173 */ "variables_or_function ::= error SEMICOLON",
 /* 174 */ "variable_name ::= IDENTIFIER",
 /* 175 */ "variable_name ::= IDENTIFIER array_size",
 /* 176 */ "variable_list ::= variable_list COMMA variable_name",
 /* 177 */ "decl_flags ::=",
 /* 178 */ "decl_flags ::= decl_flags decl_flag",
 /* 179 */ "decl_flags ::= decl_flags ACTION states_opts",
 /* 180 */ "opt_deprecation_message ::=",
 /* 181 */ "opt_deprecation_message ::= COMMA STRCONST",
 /* 182 */ "decl_flags ::= decl_flags DEPRECATED LPAREN STRCONST opt_deprecation_message RPAREN",
 /* 183 */ "decl_flags ::= decl_flags VERSION LPAREN STRCONST RPAREN",
 /* 184 */ "decl_flag ::= NATIVE",
 /* 185 */ "decl_flag ::= STATIC",
 /* 186 */ "decl_flag ::= PRIVATE",
 /* 187 */ "decl_flag ::= PROTECTED",
 /* 188 */ "decl_flag ::= LATENT",
 /* 189 */ "decl_flag ::= FINAL",
 /* 190 */ "decl_flag ::= META",
 /* 191 */ "decl_flag ::= TRANSIENT",
 /* 192 */ "decl_flag ::= READONLY",
 /* 193 */ "decl_flag ::= INTERNAL",
 /* 194 */ "decl_flag ::= VIRTUAL",
 /* 195 */ "decl_flag ::= OVERRIDE",
 /* 196 */ "decl_flag ::= VARARG",
 /* 197 */ "decl_flag ::= UI",
 /* 198 */ "decl_flag ::= PLAY",
 /* 199 */ "decl_flag ::= CLEARSCOPE",
 /* 200 */ "decl_flag ::= VIRTUALSCOPE",
 /* 201 */ "func_const ::=",
 /* 202 */ "func_const ::= CONST",
 /* 203 */ "opt_func_body ::= SEMICOLON",
 /* 204 */ "func_params ::=",
 /* 205 */ "func_params ::= VOID",
 /* 206 */ "func_params ::= func_param_list COMMA ELLIPSIS",
 /* 207 */ "func_param_list ::= func_param_list COMMA func_param",
 /* 208 */ "func_param ::= func_param_flags type IDENTIFIER",
 /* 209 */ "func_param ::= func_param_flags type IDENTIFIER EQ expr",
 /* 210 */ "func_param_flags ::=",
 /* 211 */ "func_param_flags ::= func_param_flags IN",
 /* 212 */ "func_param_flags ::= func_param_flags OUT",
 /* 213 */ "func_param_flags ::= func_param_flags OPTIONAL",
 /* 214 */ "primary ::= IDENTIFIER",
 /* 215 */ "primary ::= SUPER",
 /* 216 */ "primary ::= constant",
 /* 217 */ "primary ::= LPAREN expr COMMA expr COMMA expr RPAREN",
 /* 218 */ "primary ::= LPAREN expr COMMA expr RPAREN",
 /* 219 */ "primary ::= LPAREN expr RPAREN",
 /* 220 */ "primary ::= primary LPAREN func_expr_list RPAREN",
 /* 221 */ "primary ::= LPAREN CLASS LT IDENTIFIER GT RPAREN LPAREN func_expr_list RPAREN",
 /* 222 */ "primary ::= primary LBRACKET expr RBRACKET",
 /* 223 */ "primary ::= primary DOT IDENTIFIER",
 /* 224 */ "primary ::= primary ADDADD",
 /* 225 */ "primary ::= primary SUBSUB",
 /* 226 */ "unary_expr ::= SUB unary_expr",
 /* 227 */ "unary_expr ::= ADD unary_expr",
 /* 228 */ "unary_expr ::= SUBSUB unary_expr",
 /* 229 */ "unary_expr ::= ADDADD unary_expr",
 /* 230 */ "unary_expr ::= TILDE unary_expr",
 /* 231 */ "unary_expr ::= BANG unary_expr",
 /* 232 */ "unary_expr ::= SIZEOF unary_expr",
 /* 233 */ "unary_expr ::= ALIGNOF unary_expr",
 /* 234 */ "expr ::= expr ADD expr",
 /* 235 */ "expr ::= expr SUB expr",
 /* 236 */ "expr ::= expr MUL expr",
 /* 237 */ "expr ::= expr DIV expr",
 /* 238 */ "expr ::= expr MOD expr",
 /* 239 */ "expr ::= expr POW expr",
 /* 240 */ "expr ::= expr CROSSPROD expr",
 /* 241 */ "expr ::= expr DOTPROD expr",
 /* 242 */ "expr ::= expr LSH expr",
 /* 243 */ "expr ::= expr RSH expr",
 /* 244 */ "expr ::= expr URSH expr",
 /* 245 */ "expr ::= expr DOTDOT expr",
 /* 246 */ "expr ::= expr LT expr",
 /* 247 */ "expr ::= expr GT expr",
 /* 248 */ "expr ::= expr LTEQ expr",
 /* 249 */ "expr ::= expr GTEQ expr",
 /* 250 */ "expr ::= expr LTGTEQ expr",
 /* 251 */ "expr ::= expr IS expr",
 /* 252 */ "expr ::= expr EQEQ expr",
 /* 253 */ "expr ::= expr NEQ expr",
 /* 254 */ "expr ::= expr APPROXEQ expr",
 /* 255 */ "expr ::= expr AND expr",
 /* 256 */ "expr ::= expr XOR expr",
 /* 257 */ "expr ::= expr OR expr",
 /* 258 */ "expr ::= expr ANDAND expr",
 /* 259 */ "expr ::= expr OROR expr",
 /* 260 */ "expr ::= expr EQ expr",
 /* 261 */ "expr ::= expr ADDEQ expr",
 /* 262 */ "expr ::= expr SUBEQ expr",
 /* 263 */ "expr ::= expr MULEQ expr",
 /* 264 */ "expr ::= expr DIVEQ expr",
 /* 265 */ "expr ::= expr MODEQ expr",
 /* 266 */ "expr ::= expr LSHEQ expr",
 /* 267 */ "expr ::= expr RSHEQ expr",
 /* 268 */ "expr ::= expr URSHEQ expr",
 /* 269 */ "expr ::= expr ANDEQ expr",
 /* 270 */ "expr ::= expr OREQ expr",
 /* 271 */ "expr ::= expr XOREQ expr",
 /* 272 */ "expr ::= expr SCOPE expr",
 /* 273 */ "expr ::= expr QUESTION expr COLON expr",
 /* 274 */ "expr_list ::= expr_list COMMA expr",
 /* 275 */ "func_expr_list ::= func_expr_list COMMA func_expr_item",
 /* 276 */ "func_expr_item ::=",
 /* 277 */ "named_expr ::= IDENTIFIER COLON expr",
 /* 278 */ "named_expr ::= expr",
 /* 279 */ "string_constant ::= STRCONST",
 /* 280 */ "string_constant ::= string_constant STRCONST",
 /* 281 */ "constant ::= INTCONST",
 /* 282 */ "constant ::= UINTCONST",
 /* 283 */ "constant ::= FLOATCONST",
 /* 284 */ "constant ::= NAMECONST",
 /* 285 */ "constant ::= FALSE",
 /* 286 */ "constant ::= TRUE",
 /* 287 */ "constant ::= NULLPTR",
 /* 288 */ "statement ::= SEMICOLON",
 /* 289 */ "statement ::= labeled_statement",
 /* 290 */ "statement ::= compound_statement",
 /* 291 */ "statement ::= expression_statement SEMICOLON",
 /* 292 */ "statement ::= assign_statement SEMICOLON",
 /* 293 */ "statement ::= local_var SEMICOLON",
 /* 294 */ "statement ::= error SEMICOLON",
 /* 295 */ "statement ::= staticarray_statement",
 /* 296 */ "staticarray_statement ::= STATICCONST type IDENTIFIER LBRACKET RBRACKET EQ LBRACE expr_list RBRACE SEMICOLON",
 /* 297 */ "staticarray_statement ::= STATICCONST type LBRACKET RBRACKET IDENTIFIER EQ LBRACE expr_list RBRACE SEMICOLON",
 /* 298 */ "jump_statement ::= CONTINUE SEMICOLON",
 /* 299 */ "jump_statement ::= BREAK SEMICOLON",
 /* 300 */ "jump_statement ::= RETURN SEMICOLON",
 /* 301 */ "jump_statement ::= RETURN expr_list SEMICOLON",
 /* 302 */ "compound_statement ::= LBRACE RBRACE",
 /* 303 */ "compound_statement ::= LBRACE statement_list RBRACE",
 /* 304 */ "compound_statement ::= LBRACE error RBRACE",
 /* 305 */ "statement_list ::= statement",
 /* 306 */ "statement_list ::= statement_list statement",
 /* 307 */ "expression_statement ::= expr",
 /* 308 */ "iteration_statement ::= while_or_until LPAREN expr RPAREN statement",
 /* 309 */ "iteration_statement ::= DO statement while_or_until LPAREN expr RPAREN",
 /* 310 */ "iteration_statement ::= FOR LPAREN for_init SEMICOLON opt_expr SEMICOLON for_bump RPAREN statement",
 /* 311 */ "while_or_until ::= WHILE",
 /* 312 */ "while_or_until ::= UNTIL",
 /* 313 */ "for_init ::= local_var",
 /* 314 */ "for_init ::= for_bump",
 /* 315 */ "for_bump ::=",
 /* 316 */ "for_bump ::= expression_statement",
 /* 317 */ "for_bump ::= for_bump COMMA expression_statement",
 /* 318 */ "selection_statement ::= if_front",
 /* 319 */ "selection_statement ::= if_front ELSE statement",
 /* 320 */ "if_front ::= IF LPAREN expr RPAREN statement",
 /* 321 */ "selection_statement ::= SWITCH LPAREN expr RPAREN statement",
 /* 322 */ "labeled_statement ::= CASE expr COLON",
 /* 323 */ "labeled_statement ::= DEFAULT COLON",
 /* 324 */ "assign_statement ::= LBRACKET expr_list RBRACKET EQ expr",
 /* 325 */ "local_var ::= type variable_list_with_init",
 /* 326 */ "var_init ::= IDENTIFIER",
 /* 327 */ "var_init ::= IDENTIFIER array_size",
 /* 328 */ "var_init ::= IDENTIFIER EQ expr",
 /* 329 */ "var_init ::= IDENTIFIER EQ LBRACE expr_list RBRACE",
 /* 330 */ "var_init ::= IDENTIFIER array_size EQ LBRACE expr_list RBRACE",
 /* 331 */ "var_init ::= IDENTIFIER EQ LBRACE error RBRACE",
 /* 332 */ "variable_list_with_init ::= variable_list_with_init COMMA var_init",
 /* 333 */ "translation_unit ::= translation_unit EOF",
 /* 334 */ "opt_semicolon ::=",
 /* 335 */ "opt_semicolon ::= SEMICOLON",
 /* 336 */ "opt_comma ::=",
 /* 337 */ "opt_comma ::= COMMA",
 /* 338 */ "opt_expr ::= expr",
 /* 339 */ "opt_struct_body ::= struct_body",
 /* 340 */ "struct_body ::= struct_member",
 /* 341 */ "enum_list ::= enumerator",
 /* 342 */ "opt_enum_list ::= enum_list opt_comma",
 /* 343 */ "state_flow ::= state_flow_type scanner_mode SEMICOLON",
 /* 344 */ "type_name1 ::= int_type",
 /* 345 */ "type_or_array ::= type",
 /* 346 */ "type_list ::= type_or_array",
 /* 347 */ "type_list_or_void ::= type_list",
 /* 348 */ "array_size ::= array_size_expr",
 /* 349 */ "variable_list ::= variable_name",
 /* 350 */ "opt_func_body ::= function_body",
 /* 351 */ "func_params ::= func_param_list",
 /* 352 */ "func_param_list ::= func_param",
 /* 353 */ "primary ::= LPAREN error RPAREN",
 /* 354 */ "unary_expr ::= primary",
 /* 355 */ "expr ::= unary_expr",
 /* 356 */ "expr_list ::= expr",
 /* 357 */ "func_expr_list ::= func_expr_item",
 /* 358 */ "func_expr_item ::= named_expr",
 /* 359 */ "constant ::= string_constant",
 /* 360 */ "function_body ::= compound_statement",
 /* 361 */ "statement ::= selection_statement",
 /* 362 */ "statement ::= iteration_statement",
 /* 363 */ "statement ::= jump_statement",
 /* 364 */ "variable_list_with_init ::= var_init",
};
#endif /* NDEBUG */


#if YYSTACKDEPTH<=0
/*
** Try to increase the size of the parser stack.  Return the number
** of errors.  Return 0 on success.
*/
static int yyGrowStack(yyParser *p){
  int newSize;
  int idx;
  yyStackEntry *pNew;

  newSize = p->yystksz*2 + 100;
  idx = p->yytos ? (int)(p->yytos - p->yystack) : 0;
  if( p->yystack==&p->yystk0 ){
    pNew = (yyStackEntry *)malloc(newSize*sizeof(pNew[0]));
    if( pNew ) pNew[0] = p->yystk0;
  }else{
    pNew = (yyStackEntry *)realloc(p->yystack, newSize*sizeof(pNew[0]));
  }
  if( pNew ){
    p->yystack = pNew;
    p->yytos = &p->yystack[idx];
#ifndef NDEBUG
    if( yyTraceFILE ){
      fprintf(yyTraceFILE,"%sStack grows from %d to %d entries.\n",
              yyTracePrompt, p->yystksz, newSize);
      fflush(yyTraceFILE);
    }
#endif
    p->yystksz = newSize;
  }
  return pNew==0; 
}
#endif

/* Datatype of the argument to the memory allocated passed as the
** second argument to ZCCParseAlloc() below.  This can be changed by
** putting an appropriate #define in the %include section of the input
** grammar.
*/
#ifndef YYMALLOCARGTYPE
# define YYMALLOCARGTYPE size_t
#endif

/* 
** This function allocates a new parser.
** The only argument is a pointer to a function which works like
** malloc.
**
** Inputs:
** A pointer to the function used to allocate memory.
**
** Outputs:
** A pointer to a parser.  This pointer is used in subsequent calls
** to ZCCParse and ZCCParseFree.
*/
void *ZCCParseAlloc(void *(CDECL *mallocProc)(YYMALLOCARGTYPE)){
  yyParser *pParser;
  pParser = (yyParser*)(*mallocProc)( (YYMALLOCARGTYPE)sizeof(yyParser) );
  if( pParser ){
#ifdef YYTRACKMAXSTACKDEPTH
    pParser->yyhwm = 0;
#endif
#if YYSTACKDEPTH<=0
    pParser->yytos = NULL;
    pParser->yystack = NULL;
    pParser->yystksz = 0;
    if( yyGrowStack(pParser) ){
      pParser->yystack = &pParser->yystk0;
      pParser->yystksz = 1;
    }
#endif
#ifndef YYNOERRORRECOVERY
    pParser->yyerrcnt = -1;
#endif
    pParser->yytos = pParser->yystack;
    pParser->yystack[0].stateno = 0;
    pParser->yystack[0].major = 0;
  }
  return pParser;
}

/* The following function deletes the "minor type" or semantic value
** associated with a symbol.  The symbol can be either a terminal
** or nonterminal. "yymajor" is the symbol code, and "yypminor" is
** a pointer to the value to be deleted.  The code used to do the 
** deletions is derived from the %destructor and/or %token_destructor
** directives of the input grammar.
*/
static void yy_destructor(
  yyParser *yypParser,    /* The parser */
  YYCODETYPE yymajor,     /* Type code for object to destroy */
  YYMINORTYPE *yypminor   /* The object to be destroyed */
){
  ZCCParseARG_FETCH;
  switch( yymajor ){
    /* Here is inserted the actions which take place when a
    ** terminal or non-terminal is destroyed.  This can happen
    ** when the symbol is popped from the stack during a
    ** reduce or during error processing or when a parser is 
    ** being destroyed before it is finished parsing.
    **
    ** Note: during a reduce, the only symbols destroyed are those
    ** which appear on the RHS of the rule, but which are *not* used
    ** inside the C code.
    */
/********* Begin destructor definitions ***************************************/
      /* TERMINAL Destructor */
    case 1: /* EQ */
    case 2: /* MULEQ */
    case 3: /* DIVEQ */
    case 4: /* MODEQ */
    case 5: /* ADDEQ */
    case 6: /* SUBEQ */
    case 7: /* LSHEQ */
    case 8: /* RSHEQ */
    case 9: /* ANDEQ */
    case 10: /* OREQ */
    case 11: /* XOREQ */
    case 12: /* URSHEQ */
    case 13: /* QUESTION */
    case 14: /* COLON */
    case 15: /* OROR */
    case 16: /* ANDAND */
    case 17: /* EQEQ */
    case 18: /* NEQ */
    case 19: /* APPROXEQ */
    case 20: /* LT */
    case 21: /* GT */
    case 22: /* LTEQ */
    case 23: /* GTEQ */
    case 24: /* LTGTEQ */
    case 25: /* IS */
    case 26: /* DOTDOT */
    case 27: /* OR */
    case 28: /* XOR */
    case 29: /* AND */
    case 30: /* LSH */
    case 31: /* RSH */
    case 32: /* URSH */
    case 33: /* SUB */
    case 34: /* ADD */
    case 35: /* MUL */
    case 36: /* DIV */
    case 37: /* MOD */
    case 38: /* CROSSPROD */
    case 39: /* DOTPROD */
    case 40: /* POW */
    case 41: /* UNARY */
    case 42: /* ADDADD */
    case 43: /* SUBSUB */
    case 44: /* DOT */
    case 45: /* LPAREN */
    case 46: /* LBRACKET */
    case 47: /* SCOPE */
    case 48: /* EOF */
    case 49: /* SEMICOLON */
    case 50: /* COMMA */
    case 51: /* INCLUDE */
    case 52: /* EXTEND */
    case 53: /* CLASS */
    case 54: /* IDENTIFIER */
    case 55: /* ABSTRACT */
    case 56: /* NATIVE */
    case 57: /* UI */
    case 58: /* PLAY */
    case 59: /* REPLACES */
    case 60: /* VERSION */
    case 61: /* STRCONST */
    case 62: /* RPAREN */
    case 63: /* DEFAULT */
    case 64: /* COLOR */
    case 65: /* LBRACE */
    case 66: /* RBRACE */
    case 67: /* MIXIN */
    case 68: /* PROPERTY */
    case 69: /* FLAGDEF */
    case 70: /* INTCONST */
    case 71: /* STRUCT */
    case 72: /* CLEARSCOPE */
    case 73: /* CONST */
    case 74: /* ENUM */
    case 75: /* STATES */
    case 76: /* NWS */
    case 77: /* STOP */
    case 78: /* WAIT */
    case 79: /* FAIL */
    case 80: /* LOOP */
    case 81: /* GOTO */
    case 82: /* SUPER */
    case 83: /* BRIGHT */
    case 84: /* FAST */
    case 85: /* SLOW */
    case 86: /* NODELAY */
    case 87: /* CANRAISE */
    case 88: /* OFFSET */
    case 89: /* LIGHT */
    case 90: /* SBYTE */
    case 91: /* BYTE */
    case 92: /* SHORT */
    case 93: /* USHORT */
    case 94: /* INT */
    case 95: /* UINT */
    case 96: /* BOOL */
    case 97: /* FLOAT */
    case 98: /* DOUBLE */
    case 99: /* VECTOR2 */
    case 100: /* VECTOR3 */
    case 101: /* NAME */
    case 102: /* SOUND */
    case 103: /* STATE */
    case 104: /* LET */
    case 105: /* ATSIGN */
    case 106: /* READONLY */
    case 107: /* STRING */
    case 108: /* MAP */
    case 109: /* ARRAY */
    case 110: /* VOID */
    case 111: /* UINT8 */
    case 112: /* INT8 */
    case 113: /* UINT16 */
    case 114: /* INT16 */
    case 115: /* RBRACKET */
    case 116: /* ACTION */
    case 117: /* DEPRECATED */
    case 118: /* STATIC */
    case 119: /* PRIVATE */
    case 120: /* PROTECTED */
    case 121: /* LATENT */
    case 122: /* FINAL */
    case 123: /* META */
    case 124: /* TRANSIENT */
    case 125: /* INTERNAL */
    case 126: /* VIRTUAL */
    case 127: /* OVERRIDE */
    case 128: /* VARARG */
    case 129: /* VIRTUALSCOPE */
    case 130: /* ELLIPSIS */
    case 131: /* IN */
    case 132: /* OUT */
    case 133: /* OPTIONAL */
    case 134: /* TILDE */
    case 135: /* BANG */
    case 136: /* SIZEOF */
    case 137: /* ALIGNOF */
    case 138: /* UINTCONST */
    case 139: /* FLOATCONST */
    case 140: /* NAMECONST */
    case 141: /* FALSE */
    case 142: /* TRUE */
    case 143: /* NULLPTR */
    case 144: /* STATICCONST */
    case 145: /* CONTINUE */
    case 146: /* BREAK */
    case 147: /* RETURN */
    case 148: /* DO */
    case 149: /* FOR */
    case 150: /* WHILE */
    case 151: /* UNTIL */
    case 152: /* IF */
    case 153: /* ELSE */
    case 154: /* SWITCH */
    case 155: /* CASE */
{
#line 117 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"

#line 1878 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
}
      break;
/********* End destructor definitions *****************************************/
    default:  break;   /* If no destructor action specified: do nothing */
  }
}

/*
** Pop the parser's stack once.
**
** If there is a destructor routine associated with the token which
** is popped from the stack, then call it.
*/
static void yy_pop_parser_stack(yyParser *pParser){
  yyStackEntry *yytos;
  assert( pParser->yytos!=0 );
  assert( pParser->yytos > pParser->yystack );
  yytos = pParser->yytos--;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sPopping %s\n",
      yyTracePrompt,
      yyTokenName[yytos->major]);
    fflush(yyTraceFILE);
  }
#endif
  yy_destructor(pParser, yytos->major, &yytos->minor);
}

/* 
** Deallocate and destroy a parser.  Destructors are called for
** all stack elements before shutting the parser down.
**
** If the YYPARSEFREENEVERNULL macro exists (for example because it
** is defined in a %include section of the input grammar) then it is
** assumed that the input pointer is never NULL.
*/
void ZCCParseFree(
  void *p,                    /* The parser to be deleted */
  void (CDECL *freeProc)(void*)     /* Function used to reclaim memory */
){
  yyParser *pParser = (yyParser*)p;
#ifndef YYPARSEFREENEVERNULL
  if( pParser==0 ) return;
#endif
  while( pParser->yytos>pParser->yystack ) yy_pop_parser_stack(pParser);
#if YYSTACKDEPTH<=0
  if( pParser->yystack!=&pParser->yystk0 ) free(pParser->yystack);
#endif
  (*freeProc)((void*)pParser);
}

/*
** Return the peak depth of the stack for a parser.
*/
#ifdef YYTRACKMAXSTACKDEPTH
int ZCCParseStackPeak(void *p){
  yyParser *pParser = (yyParser*)p;
  return pParser->yyhwm;
}
#endif

/*
** Find the appropriate action for a parser given the terminal
** look-ahead token iLookAhead.
*/
static unsigned int yy_find_shift_action(
  yyParser *pParser,        /* The parser */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
  int stateno = pParser->yytos->stateno;
 
  if( stateno>=YY_MIN_REDUCE ) return stateno;
  assert( stateno <= YY_SHIFT_COUNT );
  do{
    i = yy_shift_ofst[stateno];
    assert( iLookAhead!=YYNOCODE );
    i += iLookAhead;
    if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
#ifdef YYFALLBACK
      YYCODETYPE iFallback;            /* Fallback token */
      if( iLookAhead<sizeof(yyFallback)/sizeof(yyFallback[0])
             && (iFallback = yyFallback[iLookAhead])!=0 ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE, "%sFALLBACK %s => %s\n",
             yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[iFallback]);
          fflush(yyTraceFILE);
        }
#endif
        assert( yyFallback[iFallback]==0 ); /* Fallback loop must terminate */
        iLookAhead = iFallback;
        continue;
      }
#endif
#ifdef YYWILDCARD
      {
        int j = i - iLookAhead + YYWILDCARD;
        if( 
#if YY_SHIFT_MIN+YYWILDCARD<0
          j>=0 &&
#endif
#if YY_SHIFT_MAX+YYWILDCARD>=YY_ACTTAB_COUNT
          j<YY_ACTTAB_COUNT &&
#endif
          yy_lookahead[j]==YYWILDCARD && iLookAhead>0
        ){
#ifndef NDEBUG
          if( yyTraceFILE ){
            fprintf(yyTraceFILE, "%sWILDCARD %s => %s\n",
               yyTracePrompt, yyTokenName[iLookAhead],
               yyTokenName[YYWILDCARD]);
            fflush(yyTraceFILE);
          }
#endif /* NDEBUG */
          return yy_action[j];
        }
      }
#endif /* YYWILDCARD */
      return yy_default[stateno];
    }else{
      return yy_action[i];
    }
  }while(1);
}

/*
** Find the appropriate action for a parser given the non-terminal
** look-ahead token iLookAhead.
*/
static int yy_find_reduce_action(
  int stateno,              /* Current state number */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
#ifdef YYERRORSYMBOL
  if( stateno>YY_REDUCE_COUNT ){
    return yy_default[stateno];
  }
#else
  assert( stateno<=YY_REDUCE_COUNT );
#endif
  i = yy_reduce_ofst[stateno];
  assert( i!=YY_REDUCE_USE_DFLT );
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
#ifdef YYERRORSYMBOL
  if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
    return yy_default[stateno];
  }
#else
  assert( i>=0 && i<YY_ACTTAB_COUNT );
  assert( yy_lookahead[i]==iLookAhead );
#endif
  return yy_action[i];
}

/*
** The following routine is called if the stack overflows.
*/
static void yyStackOverflow(yyParser *yypParser){
   ZCCParseARG_FETCH;
   yypParser->yytos--;
#ifndef NDEBUG
   if( yyTraceFILE ){
     fprintf(yyTraceFILE,"%sStack Overflow!\n",yyTracePrompt);
     fflush(yyTraceFILE);
   }
#endif
   while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
   /* Here code is inserted which will execute if the parser
   ** stack every overflows */
/******** Begin %stack_overflow code ******************************************/
/******** End %stack_overflow code ********************************************/
   ZCCParseARG_STORE; /* Suppress warning about unused %extra_argument var */
}

/*
** Print tracing information for a SHIFT action
*/
#ifndef NDEBUG
static void yyTraceShift(yyParser *yypParser, int yyNewState){
  if( yyTraceFILE ){
    if( yyNewState<YYNSTATE ){
      fprintf(yyTraceFILE,"%sShift '%s', go to state %d\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major],
         yyNewState);
    }else{
      fprintf(yyTraceFILE,"%sShift '%s'\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major]);
    }
    fflush(yyTraceFILE);
  }
}
#else
# define yyTraceShift(X,Y)
#endif

/*
** Perform a shift action.
*/
static void yy_shift(
  yyParser *yypParser,          /* The parser to be shifted */
  int yyNewState,               /* The new state to shift in */
  int yyMajor,                  /* The major token to shift in */
  ZCCParseTOKENTYPE yyMinor        /* The minor token to shift in */
){
  yyStackEntry *yytos;
  yypParser->yytos++;
#ifdef YYTRACKMAXSTACKDEPTH
  if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
    yypParser->yyhwm++;
    assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack) );
  }
#endif
#if YYSTACKDEPTH>0 
  if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH] ){
    yyStackOverflow(yypParser);
    return;
  }
#else
  if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz] ){
    if( yyGrowStack(yypParser) ){
      yyStackOverflow(yypParser);
      return;
    }
  }
#endif
  if( yyNewState > YY_MAX_SHIFT ){
    yyNewState += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
  }
  yytos = yypParser->yytos;
  yytos->stateno = (YYACTIONTYPE)yyNewState;
  yytos->major = (YYCODETYPE)yyMajor;
  yytos->minor.yy0 = yyMinor;
  yyTraceShift(yypParser, yyNewState);
}

/* The following table contains information about every rule that
** is used during the reduce.
*/
static const struct {
  YYCODETYPE lhs;         /* Symbol on the left-hand side of the rule */
  unsigned char nrhs;     /* Number of right-hand side symbols in the rule */
} yyRuleInfo[] = {
  { 161, 1 },
  { 162, 0 },
  { 162, 2 },
  { 162, 1 },
  { 163, 1 },
  { 163, 1 },
  { 163, 1 },
  { 163, 1 },
  { 163, 1 },
  { 163, 1 },
  { 172, 0 },
  { 169, 2 },
  { 165, 2 },
  { 175, 3 },
  { 175, 4 },
  { 179, 0 },
  { 179, 2 },
  { 180, 0 },
  { 180, 2 },
  { 180, 2 },
  { 180, 2 },
  { 180, 2 },
  { 180, 3 },
  { 180, 5 },
  { 181, 1 },
  { 181, 3 },
  { 181, 3 },
  { 181, 3 },
  { 178, 3 },
  { 178, 3 },
  { 176, 0 },
  { 176, 2 },
  { 177, 1 },
  { 177, 1 },
  { 177, 1 },
  { 177, 1 },
  { 177, 1 },
  { 177, 1 },
  { 177, 1 },
  { 177, 1 },
  { 177, 1 },
  { 177, 1 },
  { 182, 3 },
  { 183, 5 },
  { 184, 7 },
  { 191, 1 },
  { 191, 3 },
  { 166, 7 },
  { 193, 0 },
  { 193, 2 },
  { 193, 2 },
  { 193, 2 },
  { 193, 2 },
  { 193, 5 },
  { 188, 0 },
  { 188, 1 },
  { 189, 2 },
  { 190, 1 },
  { 190, 1 },
  { 190, 1 },
  { 190, 1 },
  { 168, 5 },
  { 167, 7 },
  { 197, 0 },
  { 197, 2 },
  { 194, 1 },
  { 194, 3 },
  { 195, 0 },
  { 196, 1 },
  { 196, 3 },
  { 164, 1 },
  { 199, 6 },
  { 200, 0 },
  { 200, 2 },
  { 201, 1 },
  { 201, 1 },
  { 201, 1 },
  { 201, 1 },
  { 201, 1 },
  { 201, 1 },
  { 201, 1 },
  { 201, 1 },
  { 201, 1 },
  { 185, 6 },
  { 212, 0 },
  { 212, 3 },
  { 192, 1 },
  { 192, 3 },
  { 213, 0 },
  { 202, 0 },
  { 202, 1 },
  { 202, 2 },
  { 202, 2 },
  { 202, 2 },
  { 204, 2 },
  { 206, 1 },
  { 206, 1 },
  { 206, 1 },
  { 206, 1 },
  { 206, 3 },
  { 206, 5 },
  { 206, 5 },
  { 207, 0 },
  { 207, 2 },
  { 203, 5 },
  { 211, 0 },
  { 211, 2 },
  { 211, 2 },
  { 211, 2 },
  { 211, 2 },
  { 211, 2 },
  { 211, 7 },
  { 211, 5 },
  { 214, 1 },
  { 214, 3 },
  { 208, 4 },
  { 208, 3 },
  { 208, 4 },
  { 208, 3 },
  { 209, 0 },
  { 209, 2 },
  { 210, 0 },
  { 210, 3 },
  { 186, 3 },
  { 186, 4 },
  { 186, 4 },
  { 217, 1 },
  { 217, 2 },
  { 218, 1 },
  { 218, 2 },
  { 218, 1 },
  { 218, 1 },
  { 220, 2 },
  { 220, 2 },
  { 219, 3 },
  { 219, 2 },
  { 198, 1 },
  { 198, 1 },
  { 198, 1 },
  { 198, 1 },
  { 198, 1 },
  { 198, 1 },
  { 223, 1 },
  { 223, 1 },
  { 223, 1 },
  { 223, 1 },
  { 223, 1 },
  { 223, 1 },
  { 223, 1 },
  { 223, 1 },
  { 223, 1 },
  { 223, 1 },
  { 222, 1 },
  { 222, 1 },
  { 222, 2 },
  { 222, 4 },
  { 222, 5 },
  { 222, 2 },
  { 224, 6 },
  { 224, 4 },
  { 224, 2 },
  { 229, 0 },
  { 229, 3 },
  { 225, 1 },
  { 225, 1 },
  { 228, 2 },
  { 226, 3 },
  { 227, 1 },
  { 231, 3 },
  { 230, 2 },
  { 157, 3 },
  { 232, 6 },
  { 232, 2 },
  { 232, 2 },
  { 237, 1 },
  { 237, 2 },
  { 236, 3 },
  { 233, 0 },
  { 233, 2 },
  { 233, 3 },
  { 239, 0 },
  { 239, 2 },
  { 233, 6 },
  { 233, 5 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 235, 0 },
  { 235, 1 },
  { 159, 1 },
  { 234, 0 },
  { 234, 1 },
  { 234, 3 },
  { 240, 3 },
  { 241, 3 },
  { 241, 5 },
  { 242, 0 },
  { 242, 2 },
  { 242, 2 },
  { 242, 2 },
  { 243, 1 },
  { 243, 1 },
  { 243, 1 },
  { 243, 7 },
  { 243, 5 },
  { 243, 3 },
  { 243, 4 },
  { 243, 9 },
  { 243, 4 },
  { 243, 3 },
  { 243, 2 },
  { 243, 2 },
  { 244, 2 },
  { 244, 2 },
  { 244, 2 },
  { 244, 2 },
  { 244, 2 },
  { 244, 2 },
  { 244, 2 },
  { 244, 2 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 5 },
  { 221, 3 },
  { 216, 3 },
  { 246, 0 },
  { 247, 3 },
  { 247, 1 },
  { 174, 1 },
  { 174, 2 },
  { 245, 1 },
  { 245, 1 },
  { 245, 1 },
  { 245, 1 },
  { 245, 1 },
  { 245, 1 },
  { 245, 1 },
  { 249, 1 },
  { 249, 1 },
  { 249, 1 },
  { 249, 2 },
  { 249, 2 },
  { 249, 2 },
  { 249, 2 },
  { 249, 1 },
  { 187, 10 },
  { 187, 10 },
  { 254, 2 },
  { 254, 2 },
  { 254, 2 },
  { 254, 3 },
  { 248, 2 },
  { 248, 3 },
  { 248, 3 },
  { 215, 1 },
  { 215, 2 },
  { 251, 1 },
  { 253, 5 },
  { 253, 6 },
  { 253, 9 },
  { 257, 1 },
  { 257, 1 },
  { 258, 1 },
  { 258, 1 },
  { 259, 0 },
  { 259, 1 },
  { 259, 3 },
  { 252, 1 },
  { 252, 3 },
  { 260, 5 },
  { 252, 5 },
  { 250, 3 },
  { 250, 2 },
  { 255, 5 },
  { 256, 2 },
  { 262, 1 },
  { 262, 2 },
  { 262, 3 },
  { 262, 5 },
  { 262, 6 },
  { 262, 5 },
  { 261, 3 },
  { 162, 2 },
  { 170, 0 },
  { 170, 1 },
  { 171, 0 },
  { 171, 1 },
  { 172, 1 },
  { 188, 1 },
  { 189, 1 },
  { 194, 1 },
  { 195, 2 },
  { 205, 3 },
  { 223, 1 },
  { 228, 1 },
  { 226, 1 },
  { 227, 1 },
  { 230, 1 },
  { 236, 1 },
  { 159, 1 },
  { 234, 1 },
  { 240, 1 },
  { 243, 3 },
  { 244, 1 },
  { 173, 1 },
  { 221, 1 },
  { 216, 1 },
  { 246, 1 },
  { 245, 1 },
  { 160, 1 },
  { 249, 1 },
  { 249, 1 },
  { 249, 1 },
  { 261, 1 },
};

static void yy_accept(yyParser*);  /* Forward Declaration */

/*
** Perform a reduce action and the shift that must immediately
** follow the reduce.
*/
static void yy_reduce(
  yyParser *yypParser,         /* The parser */
  unsigned int yyruleno        /* Number of the rule by which to reduce */
){
  int yygoto;                     /* The next state */
  int yyact;                      /* The next action */
  yyStackEntry *yymsp;            /* The top of the parser's stack */
  int yysize;                     /* Amount to pop the stack */
  ZCCParseARG_FETCH;
  yymsp = yypParser->yytos;
#ifndef NDEBUG
  if( yyTraceFILE && yyruleno<(int)(sizeof(yyRuleName)/sizeof(yyRuleName[0])) ){
    yysize = yyRuleInfo[yyruleno].nrhs;
    fprintf(yyTraceFILE, "%sReduce [%s], go to state %d.\n", yyTracePrompt,
      yyRuleName[yyruleno], yymsp[-yysize].stateno);
    fflush(yyTraceFILE);
  }
#endif /* NDEBUG */

  /* Check that the stack is large enough to grow by a single entry
  ** if the RHS of the rule is empty.  This ensures that there is room
  ** enough on the stack to push the LHS value */
  if( yyRuleInfo[yyruleno].nrhs==0 ){
#ifdef YYTRACKMAXSTACKDEPTH
    if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
      yypParser->yyhwm++;
      assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack));
    }
#endif
#if YYSTACKDEPTH>0 
    if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH-1] ){
      yyStackOverflow(yypParser);
      return;
    }
#else
    if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz-1] ){
      if( yyGrowStack(yypParser) ){
        yyStackOverflow(yypParser);
        return;
      }
      yymsp = yypParser->yytos;
    }
#endif
  }

  switch( yyruleno ){
  /* Beginning here are the reduction cases.  A typical example
  ** follows:
  **   case 0:
  **  #line <lineno> <grammarfile>
  **     { ... }           // User supplied code
  **  #line <lineno> <thisfile>
  **     break;
  */
/********** Begin reduce actions **********************************************/
        YYMINORTYPE yylhsminor;
      case 0: /* main ::= translation_unit */
#line 173 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ stat->TopNode = yymsp[0].minor.yy38; DPrintf(DMSG_SPAMMY, "Parse complete\n"); }
#line 2557 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 1: /* translation_unit ::= */
      case 30: /*class_innards ::= */ yytestcase(yyruleno==30);
      case 54: /*opt_struct_body ::= */ yytestcase(yyruleno==54);
      case 72: /*mixin_class_body ::= */ yytestcase(yyruleno==72);
#line 176 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy38 = NULL; }
#line 2565 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 2: /* translation_unit ::= translation_unit external_declaration */
      case 31: /*class_innards ::= class_innards class_member */ yytestcase(yyruleno==31);
      case 73: /*mixin_class_body ::= mixin_class_body mixin_class_member */ yytestcase(yyruleno==73);
#line 177 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ SAFE_APPEND(yymsp[-1].minor.yy38,yymsp[0].minor.yy38); }
#line 2572 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 3: /* translation_unit ::= error */
      case 55: /*opt_struct_body ::= error */ yytestcase(yyruleno==55);
#line 179 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy38 = NULL; }
#line 2578 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 4: /* external_declaration ::= mixin_definition */
#line 182 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy38 = yymsp[0].minor.yy48; /*X-overwrites-A*/ }
#line 2583 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 5: /* external_declaration ::= class_definition */
#line 183 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy38 = yymsp[0].minor.yy414; /*X-overwrites-A*/ }
#line 2588 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 6: /* external_declaration ::= struct_def */
      case 35: /*class_member ::= struct_def */ yytestcase(yyruleno==35);
      case 76: /*mixin_class_member ::= struct_def */ yytestcase(yyruleno==76);
#line 184 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy38 = yymsp[0].minor.yy262; /*X-overwrites-A*/ }
#line 2595 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 7: /* external_declaration ::= enum_def */
      case 34: /*class_member ::= enum_def */ yytestcase(yyruleno==34);
      case 58: /*struct_member ::= enum_def */ yytestcase(yyruleno==58);
      case 75: /*mixin_class_member ::= enum_def */ yytestcase(yyruleno==75);
#line 185 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy38 = yymsp[0].minor.yy245; /*X-overwrites-A*/ }
#line 2603 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 8: /* external_declaration ::= const_def */
      case 38: /*class_member ::= const_def */ yytestcase(yyruleno==38);
      case 59: /*struct_member ::= const_def */ yytestcase(yyruleno==59);
      case 79: /*mixin_class_member ::= const_def */ yytestcase(yyruleno==79);
#line 186 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy38 = yymsp[0].minor.yy307; /*X-overwrites-A*/ }
#line 2611 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 9: /* external_declaration ::= include_def */
#line 187 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy38 = nullptr; }
#line 2616 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 10: /* opt_expr ::= */
#line 198 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	yymsp[1].minor.yy138 = NULL;
}
#line 2623 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 11: /* include_def ::= INCLUDE string_constant */
{  yy_destructor(yypParser,51,&yymsp[-1].minor);
#line 205 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	AddInclude(yymsp[0].minor.yy237);
}
#line 2631 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
}
        break;
      case 12: /* class_definition ::= class_head class_body */
#line 219 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	yymsp[-1].minor.yy414->Body = yymsp[0].minor.yy38;
	yymsp[-1].minor.yy414 = yymsp[-1].minor.yy414; /*X-overwrites-A*/
}
#line 2640 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 13: /* class_head ::= EXTEND CLASS IDENTIFIER */
{  yy_destructor(yypParser,52,&yymsp[-2].minor);
#line 225 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Class,head,yymsp[-1].minor.yy0);
	head->NodeName = yymsp[0].minor.yy0.Name();
	head->ParentName = nullptr;
	head->Flags =  ZCC_Extension;
	head->Replaces = nullptr;
	head->Version = {0, 0};
	head->Type = nullptr;
	head->Symbol = nullptr;
	yymsp[-2].minor.yy414 = head;
}
#line 2656 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
}
        break;
      case 14: /* class_head ::= CLASS IDENTIFIER class_ancestry class_flags */
#line 238 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Class,head,yymsp[-3].minor.yy0);
	head->NodeName = yymsp[-2].minor.yy0.Name();
	head->ParentName = yymsp[-1].minor.yy35;
	head->Flags = yymsp[0].minor.yy37.Flags;
	head->Replaces = yymsp[0].minor.yy37.Replaces;
	head->Version = yymsp[0].minor.yy37.Version;
	head->Type = nullptr;
	head->Symbol = nullptr;
	yylhsminor.yy414 = head;
}
#line 2672 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[-3].minor.yy414 = yylhsminor.yy414;
        break;
      case 15: /* class_ancestry ::= */
      case 161: /*class_restrictor ::= */ yytestcase(yyruleno==161);
#line 251 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy35 = NULL; }
#line 2679 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 16: /* class_ancestry ::= COLON dottable_id */
{  yy_destructor(yypParser,14,&yymsp[-1].minor);
#line 252 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy35 = yymsp[0].minor.yy35; /*yymsp[-1].minor.yy35-overwrites-yymsp[0].minor.yy35*/ }
#line 2685 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
}
        break;
      case 17: /* class_flags ::= */
#line 255 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy37.Flags = 0; yymsp[1].minor.yy37.Replaces = NULL; yymsp[1].minor.yy37.Version = {0,0}; }
#line 2691 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 18: /* class_flags ::= class_flags ABSTRACT */
#line 256 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy37.Flags = yymsp[-1].minor.yy37.Flags | ZCC_Abstract; yylhsminor.yy37.Replaces = yymsp[-1].minor.yy37.Replaces; }
#line 2696 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,55,&yymsp[0].minor);
  yymsp[-1].minor.yy37 = yylhsminor.yy37;
        break;
      case 19: /* class_flags ::= class_flags NATIVE */
#line 257 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy37.Flags = yymsp[-1].minor.yy37.Flags | ZCC_Native; yylhsminor.yy37.Replaces = yymsp[-1].minor.yy37.Replaces; }
#line 2703 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,56,&yymsp[0].minor);
  yymsp[-1].minor.yy37 = yylhsminor.yy37;
        break;
      case 20: /* class_flags ::= class_flags UI */
#line 258 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy37.Flags = yymsp[-1].minor.yy37.Flags | ZCC_UIFlag; yylhsminor.yy37.Replaces = yymsp[-1].minor.yy37.Replaces; }
#line 2710 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,57,&yymsp[0].minor);
  yymsp[-1].minor.yy37 = yylhsminor.yy37;
        break;
      case 21: /* class_flags ::= class_flags PLAY */
#line 259 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy37.Flags = yymsp[-1].minor.yy37.Flags | ZCC_Play; yylhsminor.yy37.Replaces = yymsp[-1].minor.yy37.Replaces; }
#line 2717 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,58,&yymsp[0].minor);
  yymsp[-1].minor.yy37 = yylhsminor.yy37;
        break;
      case 22: /* class_flags ::= class_flags REPLACES dottable_id */
#line 260 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy37.Flags = yymsp[-2].minor.yy37.Flags; yylhsminor.yy37.Replaces = yymsp[0].minor.yy35; }
#line 2724 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,59,&yymsp[-1].minor);
  yymsp[-2].minor.yy37 = yylhsminor.yy37;
        break;
      case 23: /* class_flags ::= class_flags VERSION LPAREN STRCONST RPAREN */
#line 261 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy37.Flags = yymsp[-4].minor.yy37.Flags | ZCC_Version; yylhsminor.yy37.Replaces = yymsp[-4].minor.yy37.Replaces; yylhsminor.yy37.Version = yymsp[-1].minor.yy0.String->GetChars(); }
#line 2731 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,60,&yymsp[-3].minor);
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
  yymsp[-4].minor.yy37 = yylhsminor.yy37;
        break;
      case 24: /* dottable_id ::= IDENTIFIER */
      case 45: /*identifier_list ::= IDENTIFIER */ yytestcase(yyruleno==45);
      case 86: /*states_opt ::= IDENTIFIER */ yytestcase(yyruleno==86);
#line 269 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id,yymsp[0].minor.yy0);
	id->Id = yymsp[0].minor.yy0.Name();
	yylhsminor.yy35 = id;
}
#line 2746 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy35 = yylhsminor.yy35;
        break;
      case 25: /* dottable_id ::= dottable_id DOT IDENTIFIER */
#line 275 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id2,yymsp[-2].minor.yy35);
	id2->Id = yymsp[0].minor.yy0.Name();
	AppendTreeNodeSibling(yymsp[-2].minor.yy35, id2);
	yymsp[-2].minor.yy35 = yymsp[-2].minor.yy35; /*X-overwrites-A*/
}
#line 2757 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,44,&yymsp[-1].minor);
        break;
      case 26: /* dottable_id ::= dottable_id DOT DEFAULT */
#line 282 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id2,yymsp[-2].minor.yy35);
	id2->Id = NAME_Default;
	AppendTreeNodeSibling(yymsp[-2].minor.yy35, id2);
	yymsp[-2].minor.yy35 = yymsp[-2].minor.yy35; /*X-overwrites-A*/
}
#line 2768 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,44,&yymsp[-1].minor);
  yy_destructor(yypParser,63,&yymsp[0].minor);
        break;
      case 27: /* dottable_id ::= dottable_id DOT COLOR */
#line 293 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id2,yymsp[-2].minor.yy35);
	id2->Id = NAME_Color;
	AppendTreeNodeSibling(yymsp[-2].minor.yy35, id2);
	yymsp[-2].minor.yy35 = yymsp[-2].minor.yy35; /*X-overwrites-A*/
}
#line 2780 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,44,&yymsp[-1].minor);
  yy_destructor(yypParser,64,&yymsp[0].minor);
        break;
      case 28: /* class_body ::= SEMICOLON class_innards EOF */
{  yy_destructor(yypParser,49,&yymsp[-2].minor);
#line 310 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-2].minor.yy38 = yymsp[-1].minor.yy38; /*yymsp[-2].minor.yy38-overwrites-yymsp[-1].minor.yy38*/ }
#line 2788 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,48,&yymsp[0].minor);
}
        break;
      case 29: /* class_body ::= LBRACE class_innards RBRACE */
{  yy_destructor(yypParser,65,&yymsp[-2].minor);
#line 311 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-2].minor.yy38 = yymsp[-1].minor.yy38; /*yymsp[-2].minor.yy38-overwrites-yymsp[-1].minor.yy38*/ }
#line 2796 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
}
        break;
      case 32: /* class_member ::= declarator */
      case 57: /*struct_member ::= declarator */ yytestcase(yyruleno==57);
      case 74: /*mixin_class_member ::= declarator */ yytestcase(yyruleno==74);
#line 324 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy38 = yymsp[0].minor.yy243; /*X-overwrites-A*/ }
#line 2805 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 33: /* class_member ::= mixin_statement */
#line 325 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy38 = yymsp[0].minor.yy523; /*X-overwrites-A*/ }
#line 2810 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 36: /* class_member ::= states_def */
      case 77: /*mixin_class_member ::= states_def */ yytestcase(yyruleno==77);
#line 328 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy38 = yymsp[0].minor.yy276; /*X-overwrites-A*/ }
#line 2816 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 37: /* class_member ::= default_def */
      case 78: /*mixin_class_member ::= default_def */ yytestcase(yyruleno==78);
#line 329 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy38 = yymsp[0].minor.yy205; /*X-overwrites-A*/ }
#line 2822 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 39: /* class_member ::= property_def */
      case 80: /*mixin_class_member ::= property_def */ yytestcase(yyruleno==80);
#line 331 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy38 = yymsp[0].minor.yy387; /*X-overwrites-A*/ }
#line 2828 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 40: /* class_member ::= flag_def */
      case 81: /*mixin_class_member ::= flag_def */ yytestcase(yyruleno==81);
#line 332 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy38 = yymsp[0].minor.yy73; /*X-overwrites-A*/ }
#line 2834 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 41: /* class_member ::= staticarray_statement */
      case 60: /*struct_member ::= staticarray_statement */ yytestcase(yyruleno==60);
      case 82: /*mixin_class_member ::= staticarray_statement */ yytestcase(yyruleno==82);
#line 333 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy38 = yymsp[0].minor.yy152; /*X-overwrites-A*/ }
#line 2841 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 42: /* mixin_statement ::= MIXIN IDENTIFIER SEMICOLON */
#line 338 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(MixinStmt,stmt,yymsp[-2].minor.yy0);
	stmt->MixinName = yymsp[-1].minor.yy0.Name();
	yylhsminor.yy523 = stmt;
}
#line 2850 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-2].minor.yy523 = yylhsminor.yy523;
        break;
      case 43: /* property_def ::= PROPERTY IDENTIFIER COLON identifier_list SEMICOLON */
#line 353 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Property,def,yymsp[-4].minor.yy0);
	def->NodeName = yymsp[-3].minor.yy0.Name();
	def->Body = yymsp[-1].minor.yy35;
	yylhsminor.yy387 = def;
}
#line 2862 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[-2].minor);
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-4].minor.yy387 = yylhsminor.yy387;
        break;
      case 44: /* flag_def ::= FLAGDEF IDENTIFIER COLON IDENTIFIER COMMA INTCONST SEMICOLON */
#line 361 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(FlagDef,def,yymsp[-6].minor.yy0);
	def->NodeName = yymsp[-5].minor.yy0.Name();
	def->RefName = yymsp[-3].minor.yy0.Name();
	def->BitValue = yymsp[-1].minor.yy0.Int;
	yylhsminor.yy73 = def;
}
#line 2876 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[-4].minor);
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-6].minor.yy73 = yylhsminor.yy73;
        break;
      case 46: /* identifier_list ::= states_opt COMMA IDENTIFIER */
      case 87: /*states_opt ::= states_opt COMMA IDENTIFIER */ yytestcase(yyruleno==87);
#line 378 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id,yymsp[0].minor.yy0);
	id->Id = yymsp[0].minor.yy0.Name();
	yymsp[-2].minor.yy35 = yymsp[-2].minor.yy35; /*X-overwrites-A*/
	AppendTreeNodeSibling(yymsp[-2].minor.yy35, id);
}
#line 2891 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 47: /* struct_def ::= STRUCT IDENTIFIER struct_flags LBRACE opt_struct_body RBRACE opt_semicolon */
#line 386 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Struct,def,yymsp[-6].minor.yy0);
	def->NodeName = yymsp[-5].minor.yy0.Name();
	def->Body = yymsp[-2].minor.yy38;
	def->Type = nullptr;
	def->Symbol = nullptr;
	def->Version = yymsp[-4].minor.yy37.Version;
	def->Flags = yymsp[-4].minor.yy37.Flags;
	yylhsminor.yy262 = def;
}
#line 2906 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,65,&yymsp[-3].minor);
  yy_destructor(yypParser,66,&yymsp[-1].minor);
  yymsp[-6].minor.yy262 = yylhsminor.yy262;
        break;
      case 48: /* struct_flags ::= */
#line 398 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy37.Flags = 0; yymsp[1].minor.yy37.Version = {0, 0}; }
#line 2914 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 49: /* struct_flags ::= struct_flags UI */
#line 399 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy37.Flags = yymsp[-1].minor.yy37.Flags | ZCC_UIFlag; }
#line 2919 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,57,&yymsp[0].minor);
  yymsp[-1].minor.yy37 = yylhsminor.yy37;
        break;
      case 50: /* struct_flags ::= struct_flags PLAY */
#line 400 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy37.Flags = yymsp[-1].minor.yy37.Flags | ZCC_Play; }
#line 2926 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,58,&yymsp[0].minor);
  yymsp[-1].minor.yy37 = yylhsminor.yy37;
        break;
      case 51: /* struct_flags ::= struct_flags CLEARSCOPE */
#line 401 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy37.Flags = yymsp[-1].minor.yy37.Flags | ZCC_ClearScope; }
#line 2933 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,72,&yymsp[0].minor);
  yymsp[-1].minor.yy37 = yylhsminor.yy37;
        break;
      case 52: /* struct_flags ::= struct_flags NATIVE */
#line 402 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy37.Flags = yymsp[-1].minor.yy37.Flags | ZCC_Native; }
#line 2940 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,56,&yymsp[0].minor);
  yymsp[-1].minor.yy37 = yylhsminor.yy37;
        break;
      case 53: /* struct_flags ::= struct_flags VERSION LPAREN STRCONST RPAREN */
#line 403 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy37.Flags = yymsp[-4].minor.yy37.Flags | ZCC_Version; yylhsminor.yy37.Version = yymsp[-1].minor.yy0.String->GetChars(); }
#line 2947 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,60,&yymsp[-3].minor);
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
  yymsp[-4].minor.yy37 = yylhsminor.yy37;
        break;
      case 56: /* struct_body ::= struct_body struct_member */
#line 411 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy38 = yymsp[-1].minor.yy38; /*X-overwrites-A*/ AppendTreeNodeSibling(yymsp[-1].minor.yy38, yymsp[0].minor.yy38); }
#line 2956 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 61: /* const_def ::= CONST IDENTIFIER EQ expr SEMICOLON */
#line 421 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ConstantDef,def,yymsp[-4].minor.yy0);
	def->NodeName = yymsp[-3].minor.yy0.Name();
	def->Value = yymsp[-1].minor.yy138;
	def->Symbol = NULL;
	yylhsminor.yy307 = def;
}
#line 2967 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-2].minor);
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-4].minor.yy307 = yylhsminor.yy307;
        break;
      case 62: /* enum_def ::= ENUM IDENTIFIER enum_type LBRACE opt_enum_list RBRACE opt_semicolon */
#line 438 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Enum,def,yymsp[-6].minor.yy0);
	def->NodeName = yymsp[-5].minor.yy0.Name();
	def->EnumType = (EZCCBuiltinType)yymsp[-4].minor.yy0.Int;
	def->Elements = yymsp[-2].minor.yy307;
	def->Symbol = nullptr;

	// If the first element does not have an explicit value, make it 0.
	if (yymsp[-2].minor.yy307 != NULL)
	{
		ZCC_ConstantDef *node = yymsp[-2].minor.yy307, *prev = node;

		if (node->Value == NULL)
		{
			NEW_INTCONST_NODE(zero, TypeSInt32, 0, yymsp[-2].minor.yy307);
			node->Value = zero;
		}
		for (node = static_cast<ZCC_ConstantDef *>(node->SiblingNext);
			node != yymsp[-2].minor.yy307;
			prev = node, node = static_cast<ZCC_ConstantDef *>(node->SiblingNext))
		{
			assert(node->NodeType == AST_ConstantDef);
			// Leave explicit values alone.
			if (node->Value != NULL)
			{
				continue;
			}
			// Compute implicit values by adding one to the preceding value.
			assert(prev->Value != NULL);
			// If the preceding node is a constant, then we can do this now.
			if (prev->Value->Operation == PEX_ConstValue && prev->Value->Type->isInt())
			{
				NEW_INTCONST_NODE(cval, prev->Value->Type, static_cast<ZCC_ExprConstant *>(prev->Value)->IntVal + 1, node);
				node->Value = cval;
			}
			// Otherwise, create a new addition expression to add 1.
			else
			{
				NEW_INTCONST_NODE(one, TypeSInt32, 1, yymsp[-6].minor.yy0);
				NEW_AST_NODE(ExprID, label, node);
				label->Operation = PEX_ID;
				label->Identifier = prev->NodeName;
				label->Type = NULL;

				BINARY_EXPR(label, one, PEX_Add);
				node->Value = expr2;
			}
		}
		// Add a new terminating node, to indicate that the ConstantDefs for this enum are done.
		NEW_AST_NODE(EnumTerminator,term,yymsp[-1].minor.yy0);
		AppendTreeNodeSibling(yymsp[-2].minor.yy307, term);
	}
	if (yymsp[-2].minor.yy307 != NULL)
	{
		AppendTreeNodeSibling(def, yymsp[-2].minor.yy307);
	}
	yylhsminor.yy245 = def;
}
#line 3032 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,65,&yymsp[-3].minor);
  yymsp[-6].minor.yy245 = yylhsminor.yy245;
        break;
      case 63: /* enum_type ::= */
#line 497 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy0.Int = ZCC_IntAuto; yymsp[1].minor.yy0.SourceLoc = stat->sc->GetMessageLine(); }
#line 3039 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 64: /* enum_type ::= COLON int_type */
{  yy_destructor(yypParser,14,&yymsp[-1].minor);
#line 498 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy0 = yymsp[0].minor.yy0; /*yymsp[-1].minor.yy0-overwrites-yymsp[0].minor.yy0*/ }
#line 3045 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
}
        break;
      case 65: /* enum_list ::= error */
#line 500 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy307 = NULL; }
#line 3051 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 66: /* enum_list ::= enum_list COMMA enumerator */
#line 502 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-2].minor.yy307 = yymsp[-2].minor.yy307; /*X-overwrites-A*/ AppendTreeNodeSibling(yymsp[-2].minor.yy307, yymsp[0].minor.yy307); }
#line 3056 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 67: /* opt_enum_list ::= */
#line 504 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy307 = NULL; }
#line 3062 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 68: /* enumerator ::= IDENTIFIER */
#line 508 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ConstantDef,node,yymsp[0].minor.yy0);
	node->NodeName = yymsp[0].minor.yy0.Name();
	node->Value = NULL;
	node->Symbol = NULL;
	yylhsminor.yy307 = node;
}
#line 3073 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy307 = yylhsminor.yy307;
        break;
      case 69: /* enumerator ::= IDENTIFIER EQ expr */
#line 516 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ConstantDef,node,yymsp[-2].minor.yy0);
	node->NodeName = yymsp[-2].minor.yy0.Name();
	node->Value = yymsp[0].minor.yy138;
	node->Symbol = NULL;
	yylhsminor.yy307 = node;
}
#line 3085 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-1].minor);
  yymsp[-2].minor.yy307 = yylhsminor.yy307;
        break;
      case 70: /* mixin_definition ::= mixin_class_definition */
#line 530 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy48 = yymsp[0].minor.yy48; /*X-overwrites-A*/ }
#line 3092 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 71: /* mixin_class_definition ::= MIXIN CLASS IDENTIFIER LBRACE mixin_class_body RBRACE */
#line 537 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(MixinDef,def,yymsp[-5].minor.yy0);
	def->Body = yymsp[-1].minor.yy38;
	def->NodeName = yymsp[-3].minor.yy0.Name();
	def->MixinType = ZCC_Mixin_Class;
	def->Symbol = nullptr;
	yylhsminor.yy48 = def;
}
#line 3104 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,53,&yymsp[-4].minor);
  yy_destructor(yypParser,65,&yymsp[-2].minor);
  yy_destructor(yypParser,66,&yymsp[0].minor);
  yymsp[-5].minor.yy48 = yylhsminor.yy48;
        break;
      case 83: /* states_def ::= STATES states_opts scanner_mode LBRACE states_body RBRACE */
#line 586 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(States,def,yymsp[-5].minor.yy0);
	def->Flags = yymsp[-4].minor.yy35;
	def->Body = yymsp[-1].minor.yy272;
	yylhsminor.yy276 = def;
}
#line 3118 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,65,&yymsp[-2].minor);
  yy_destructor(yypParser,66,&yymsp[0].minor);
  yymsp[-5].minor.yy276 = yylhsminor.yy276;
        break;
      case 84: /* states_opts ::= */
#line 593 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy35 = nullptr; }
#line 3126 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 85: /* states_opts ::= LPAREN states_opt RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-2].minor);
#line 594 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-2].minor.yy35 = yymsp[-1].minor.yy35; /*yymsp[-2].minor.yy35-overwrites-yymsp[-1].minor.yy35*/ }
#line 3132 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      case 88: /* scanner_mode ::= */
#line 623 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ stat->sc->SetStateMode(true); }
#line 3139 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 89: /* states_body ::= */
#line 625 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy272 = NULL; }
#line 3144 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 90: /* states_body ::= error */
#line 626 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy272 = NULL; }
#line 3149 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 91: /* states_body ::= states_body state_line */
      case 92: /*states_body ::= states_body state_label */ yytestcase(yyruleno==92);
      case 93: /*states_body ::= states_body state_flow */ yytestcase(yyruleno==93);
#line 627 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ SAFE_APPEND(yymsp[-1].minor.yy272,yymsp[0].minor.yy272); }
#line 3156 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 94: /* state_label ::= NWS COLON */
#line 632 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(StateLabel, label, yymsp[-1].minor.yy0);
	label->Label = yymsp[-1].minor.yy0.Name();
	yylhsminor.yy272 = label;
}
#line 3165 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[0].minor);
  yymsp[-1].minor.yy272 = yylhsminor.yy272;
        break;
      case 95: /* state_flow_type ::= STOP */
#line 640 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ NEW_AST_NODE(StateStop, flow, yymsp[0].minor.yy0); yylhsminor.yy272 = flow; }
#line 3172 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy272 = yylhsminor.yy272;
        break;
      case 96: /* state_flow_type ::= WAIT */
#line 641 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ NEW_AST_NODE(StateWait, flow, yymsp[0].minor.yy0); yylhsminor.yy272 = flow; }
#line 3178 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy272 = yylhsminor.yy272;
        break;
      case 97: /* state_flow_type ::= FAIL */
#line 642 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ NEW_AST_NODE(StateFail, flow, yymsp[0].minor.yy0); yylhsminor.yy272 = flow; }
#line 3184 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy272 = yylhsminor.yy272;
        break;
      case 98: /* state_flow_type ::= LOOP */
#line 643 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ NEW_AST_NODE(StateLoop, flow, yymsp[0].minor.yy0); yylhsminor.yy272 = flow; }
#line 3190 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy272 = yylhsminor.yy272;
        break;
      case 99: /* state_flow_type ::= GOTO dottable_id state_goto_offset */
#line 645 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(StateGoto, flow, yymsp[-2].minor.yy0);
	flow->Label = yymsp[-1].minor.yy35;
	flow->Offset = yymsp[0].minor.yy138;
	flow->Qualifier = nullptr;
	yylhsminor.yy272 = flow;
}
#line 3202 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[-2].minor.yy272 = yylhsminor.yy272;
        break;
      case 100: /* state_flow_type ::= GOTO IDENTIFIER SCOPE dottable_id state_goto_offset */
#line 654 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(StateGoto, flow, yymsp[-4].minor.yy0);
	flow->Label = yymsp[-1].minor.yy35;
	flow->Offset = yymsp[0].minor.yy138;

	NEW_AST_NODE(Identifier,id,yymsp[-3].minor.yy0);
	id->Id = yymsp[-3].minor.yy0.Name();
	flow->Qualifier =id;
	yylhsminor.yy272 = flow;
}
#line 3217 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,47,&yymsp[-2].minor);
  yymsp[-4].minor.yy272 = yylhsminor.yy272;
        break;
      case 101: /* state_flow_type ::= GOTO SUPER SCOPE dottable_id state_goto_offset */
#line 666 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(StateGoto, flow, yymsp[-4].minor.yy0);
	flow->Label = yymsp[-1].minor.yy35;
	flow->Offset = yymsp[0].minor.yy138;

	NEW_AST_NODE(Identifier,id,yymsp[-3].minor.yy0);
	id->Id = NAME_Super;
	flow->Qualifier =id;
	yylhsminor.yy272 = flow;
}
#line 3233 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,47,&yymsp[-2].minor);
  yymsp[-4].minor.yy272 = yylhsminor.yy272;
        break;
      case 102: /* state_goto_offset ::= */
#line 677 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy138 = NULL; }
#line 3240 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 103: /* state_goto_offset ::= ADD expr */
{  yy_destructor(yypParser,34,&yymsp[-1].minor);
#line 678 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy138 = yymsp[0].minor.yy138; /*yymsp[-1].minor.yy138-overwrites-yymsp[0].minor.yy138*/ }
#line 3246 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
}
        break;
      case 104: /* state_line ::= NWS NWS expr state_opts state_action */
#line 681 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(StateLine, line, yymsp[-4].minor.yy0);
	line->Sprite = stat->Strings.Alloc(FName(yymsp[-4].minor.yy0.Name()).GetChars());
	line->Frames = stat->Strings.Alloc(FName(yymsp[-3].minor.yy0.Name()).GetChars());
	line->Duration = yymsp[-2].minor.yy138;
	line->bBright = yymsp[-1].minor.yy424.Bright;
	line->bFast = yymsp[-1].minor.yy424.Fast;
	line->bSlow = yymsp[-1].minor.yy424.Slow;
	line->bNoDelay = yymsp[-1].minor.yy424.NoDelay;
	line->bCanRaise = yymsp[-1].minor.yy424.CanRaise;
	line->Offset = yymsp[-1].minor.yy424.Offset;
	line->Lights = yymsp[-1].minor.yy424.Lights;
	line->Action = yymsp[0].minor.yy38;
	yylhsminor.yy272 = line;
}
#line 3266 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[-4].minor.yy272 = yylhsminor.yy272;
        break;
      case 105: /* state_opts ::= */
#line 697 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ StateOpts opts; opts.Zero(); yymsp[1].minor.yy424 = opts; }
#line 3272 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 106: /* state_opts ::= state_opts BRIGHT */
#line 698 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy424.Bright = true; yymsp[-1].minor.yy424 = yymsp[-1].minor.yy424; /*X-overwrites-A*/ }
#line 3277 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,83,&yymsp[0].minor);
        break;
      case 107: /* state_opts ::= state_opts FAST */
#line 699 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy424.Fast = true; yymsp[-1].minor.yy424 = yymsp[-1].minor.yy424; /*X-overwrites-A*/ }
#line 3283 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,84,&yymsp[0].minor);
        break;
      case 108: /* state_opts ::= state_opts SLOW */
#line 700 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy424.Slow = true; yymsp[-1].minor.yy424 = yymsp[-1].minor.yy424; /*X-overwrites-A*/ }
#line 3289 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,85,&yymsp[0].minor);
        break;
      case 109: /* state_opts ::= state_opts NODELAY */
#line 701 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy424.NoDelay = true; yymsp[-1].minor.yy424 = yymsp[-1].minor.yy424; /*X-overwrites-A*/ }
#line 3295 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,86,&yymsp[0].minor);
        break;
      case 110: /* state_opts ::= state_opts CANRAISE */
#line 702 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy424.CanRaise = true; yymsp[-1].minor.yy424 = yymsp[-1].minor.yy424; /*X-overwrites-A*/ }
#line 3301 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,87,&yymsp[0].minor);
        break;
      case 111: /* state_opts ::= state_opts OFFSET LPAREN expr COMMA expr RPAREN */
#line 703 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-6].minor.yy424.Offset = yymsp[-3].minor.yy138; AppendTreeNodeSibling(yymsp[-3].minor.yy138, yymsp[-1].minor.yy138); yymsp[-6].minor.yy424 = yymsp[-6].minor.yy424; /*X-overwrites-A*/ }
#line 3307 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,88,&yymsp[-5].minor);
  yy_destructor(yypParser,45,&yymsp[-4].minor);
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
        break;
      case 112: /* state_opts ::= state_opts LIGHT LPAREN light_list RPAREN */
#line 704 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-4].minor.yy424 = yymsp[-4].minor.yy424; /*X-overwrites-A*/ yymsp[-4].minor.yy424.Lights = yymsp[-1].minor.yy237; }
#line 3316 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,89,&yymsp[-3].minor);
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
        break;
      case 113: /* light_list ::= STRCONST */
      case 279: /*string_constant ::= STRCONST */ yytestcase(yyruleno==279);
#line 709 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, strconst, yymsp[0].minor.yy0);
	strconst->Operation = PEX_ConstValue;
	strconst->Type = TypeString;
	strconst->StringVal = yymsp[0].minor.yy0.String;
	yylhsminor.yy237 = strconst;
}
#line 3331 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy237 = yylhsminor.yy237;
        break;
      case 114: /* light_list ::= light_list COMMA STRCONST */
#line 718 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, strconst, yymsp[0].minor.yy0);
	strconst->Operation = PEX_ConstValue;
	strconst->Type = TypeString;
	strconst->StringVal = yymsp[0].minor.yy0.String;
	AppendTreeNodeSibling(yymsp[-2].minor.yy237, strconst); 
	yymsp[-2].minor.yy237 = yymsp[-2].minor.yy237; /*X-overwrites-A*/
}
#line 3344 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 115: /* state_action ::= LBRACE statement_list scanner_mode RBRACE */
#line 729 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(CompoundStmt,stmt,yymsp[-3].minor.yy0);
	stmt->Content = yymsp[-2].minor.yy181;
	yylhsminor.yy38 = stmt;
}
#line 3354 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
  yymsp[-3].minor.yy38 = yylhsminor.yy38;
        break;
      case 116: /* state_action ::= LBRACE scanner_mode RBRACE */
{  yy_destructor(yypParser,65,&yymsp[-2].minor);
#line 735 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	yymsp[-2].minor.yy38 = NULL;
}
#line 3364 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
}
        break;
      case 117: /* state_action ::= LBRACE error scanner_mode RBRACE */
{  yy_destructor(yypParser,65,&yymsp[-3].minor);
#line 738 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-3].minor.yy38 = NULL; }
#line 3372 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
}
        break;
      case 118: /* state_action ::= state_call scanner_mode SEMICOLON */
#line 739 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-2].minor.yy38 = yymsp[-2].minor.yy519; /*X-overwrites-A*/ }
#line 3379 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 119: /* state_call ::= */
#line 741 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy519 = NULL; }
#line 3385 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 120: /* state_call ::= IDENTIFIER state_call_params */
#line 743 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprFuncCall, expr, yymsp[-1].minor.yy0);
	NEW_AST_NODE(ExprID, func, yymsp[-1].minor.yy0);

	func->Operation = PEX_ID;
	func->Identifier = yymsp[-1].minor.yy0.Name();
	expr->Operation = PEX_FuncCall;
	expr->Function = func;
	expr->Parameters = yymsp[0].minor.yy28;
	yylhsminor.yy519 = expr;
}
#line 3400 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[-1].minor.yy519 = yylhsminor.yy519;
        break;
      case 121: /* state_call_params ::= */
#line 755 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy28 = NULL; }
#line 3406 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 122: /* state_call_params ::= LPAREN func_expr_list RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-2].minor);
#line 756 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-2].minor.yy28 = yymsp[-1].minor.yy28; /*yymsp[-2].minor.yy28-overwrites-yymsp[-1].minor.yy28*/ }
#line 3412 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      case 123: /* default_def ::= DEFAULT LBRACE RBRACE */
{  yy_destructor(yypParser,63,&yymsp[-2].minor);
#line 764 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Default,stmt,yymsp[-1].minor.yy0);
	stmt->Content = NULL;
	yymsp[-2].minor.yy205 = stmt;
}
#line 3424 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
}
        break;
      case 124: /* default_def ::= DEFAULT LBRACE default_statement_list RBRACE */
{  yy_destructor(yypParser,63,&yymsp[-3].minor);
#line 770 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Default,stmt,yymsp[-2].minor.yy0);
	stmt->Content = yymsp[-1].minor.yy181;
	yymsp[-3].minor.yy205 = stmt;
}
#line 3436 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
}
        break;
      case 125: /* default_def ::= DEFAULT LBRACE error RBRACE */
{  yy_destructor(yypParser,63,&yymsp[-3].minor);
#line 776 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Default,stmt,yymsp[-2].minor.yy0);
	stmt->Content = NULL;
	yymsp[-3].minor.yy205 = stmt;
}
#line 3448 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
}
        break;
      case 126: /* default_statement_list ::= default_statement */
      case 305: /*statement_list ::= statement */ yytestcase(yyruleno==305);
#line 783 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	yymsp[0].minor.yy181 = yymsp[0].minor.yy181; /*X-overwrites-A*/
}
#line 3458 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 127: /* default_statement_list ::= default_statement_list default_statement */
      case 306: /*statement_list ::= statement_list statement */ yytestcase(yyruleno==306);
#line 787 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	SAFE_APPEND(yymsp[-1].minor.yy181,yymsp[0].minor.yy181);
}
#line 3466 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 128: /* default_statement ::= SEMICOLON */
      case 288: /*statement ::= SEMICOLON */ yytestcase(yyruleno==288);
{  yy_destructor(yypParser,49,&yymsp[0].minor);
#line 792 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy181 = NULL; }
#line 3473 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
}
        break;
      case 129: /* default_statement ::= error SEMICOLON */
      case 294: /*statement ::= error SEMICOLON */ yytestcase(yyruleno==294);
#line 793 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy181 = NULL; }
#line 3480 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 130: /* default_statement ::= property_statement */
#line 795 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy181 = yymsp[0].minor.yy213; /*X-overwrites-A*/ }
#line 3486 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 131: /* default_statement ::= flag_statement */
#line 796 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy181 = yymsp[0].minor.yy380; /*X-overwrites-A*/ }
#line 3491 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 132: /* flag_statement ::= ADD dottable_id */
{  yy_destructor(yypParser,34,&yymsp[-1].minor);
#line 801 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(FlagStmt, type, yymsp[0].minor.yy35);
	type->set = true;
	type->name = yymsp[0].minor.yy35;
	yymsp[-1].minor.yy380 = type;
}
#line 3502 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
}
        break;
      case 133: /* flag_statement ::= SUB dottable_id */
{  yy_destructor(yypParser,33,&yymsp[-1].minor);
#line 808 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(FlagStmt, type, yymsp[0].minor.yy35);
	type->set = false;
	type->name = yymsp[0].minor.yy35;
	yymsp[-1].minor.yy380 = type;
}
#line 3514 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
}
        break;
      case 134: /* property_statement ::= dottable_id expr_list SEMICOLON */
#line 818 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(PropertyStmt,stmt,yymsp[-2].minor.yy35);
	stmt->Prop = yymsp[-2].minor.yy35;
	stmt->Values = yymsp[-1].minor.yy138;
	yylhsminor.yy213 = stmt;
}
#line 3525 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-2].minor.yy213 = yylhsminor.yy213;
        break;
      case 135: /* property_statement ::= dottable_id SEMICOLON */
#line 826 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(PropertyStmt,stmt,yymsp[-1].minor.yy35);
	stmt->Prop = yymsp[-1].minor.yy35;
	stmt->Values = nullptr;
	yylhsminor.yy213 = stmt;
}
#line 3537 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-1].minor.yy213 = yylhsminor.yy213;
        break;
      case 136: /* int_type ::= SBYTE */
#line 838 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_SInt8; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3544 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 137: /* int_type ::= BYTE */
#line 839 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_UInt8; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3550 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 138: /* int_type ::= SHORT */
#line 840 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_SInt16; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3556 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 139: /* int_type ::= USHORT */
#line 841 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_UInt16; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3562 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 140: /* int_type ::= INT */
#line 842 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_SInt32; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3568 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 141: /* int_type ::= UINT */
#line 843 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_UInt32; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3574 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 142: /* type_name1 ::= BOOL */
#line 845 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Bool; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3580 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 143: /* type_name1 ::= FLOAT */
#line 847 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_FloatAuto; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3586 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 144: /* type_name1 ::= DOUBLE */
#line 848 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Float64; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3592 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 145: /* type_name1 ::= VECTOR2 */
#line 850 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Vector2; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3598 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 146: /* type_name1 ::= VECTOR3 */
#line 851 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Vector3; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3604 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 147: /* type_name1 ::= NAME */
#line 852 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Name; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3610 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 148: /* type_name1 ::= SOUND */
#line 853 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Sound; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3616 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 149: /* type_name1 ::= STATE */
#line 854 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_State; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3622 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 150: /* type_name1 ::= COLOR */
#line 855 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Color; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3628 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 151: /* type_name1 ::= LET */
#line 856 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Let; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3634 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 152: /* type_name ::= type_name1 */
#line 859 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[0].minor.yy0);
	type->Type = (EZCCBuiltinType)yymsp[0].minor.yy0.Int;
	type->UserType = NULL;
	type->isconst = false;
	yylhsminor.yy42 = type;
}
#line 3646 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy42 = yylhsminor.yy42;
        break;
      case 153: /* type_name ::= IDENTIFIER */
#line 867 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[0].minor.yy0);
	NEW_AST_NODE(Identifier, id, yymsp[0].minor.yy0);
	type->Type = ZCC_UserType;
	type->UserType = id;
	type->isconst = false;
	id->Id = yymsp[0].minor.yy0.Name();
	yylhsminor.yy42 = type;
}
#line 3660 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy42 = yylhsminor.yy42;
        break;
      case 154: /* type_name ::= ATSIGN IDENTIFIER */
{  yy_destructor(yypParser,105,&yymsp[-1].minor);
#line 878 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[0].minor.yy0);
	NEW_AST_NODE(Identifier, id, yymsp[0].minor.yy0);
	type->Type = ZCC_NativeType;
	type->UserType = id;
	type->isconst = false;
	id->Id = yymsp[0].minor.yy0.Name();
	yymsp[-1].minor.yy42 = type;
}
#line 3675 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
}
        break;
      case 155: /* type_name ::= READONLY LT IDENTIFIER GT */
{  yy_destructor(yypParser,106,&yymsp[-3].minor);
#line 889 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[-1].minor.yy0);
	NEW_AST_NODE(Identifier, id, yymsp[-1].minor.yy0);
	type->Type = ZCC_UserType;
	type->UserType = id;
	type->isconst = true;
	id->Id = yymsp[-1].minor.yy0.Name();
	yymsp[-3].minor.yy42 = type;
}
#line 3690 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-2].minor);
  yy_destructor(yypParser,21,&yymsp[0].minor);
}
        break;
      case 156: /* type_name ::= READONLY LT ATSIGN IDENTIFIER GT */
{  yy_destructor(yypParser,106,&yymsp[-4].minor);
#line 900 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[-1].minor.yy0);
	NEW_AST_NODE(Identifier, id, yymsp[-1].minor.yy0);
	type->Type = ZCC_NativeType;
	type->UserType = id;
	type->isconst = true;
	id->Id = yymsp[-1].minor.yy0.Name();
	yymsp[-4].minor.yy42 = type;
}
#line 3707 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-3].minor);
  yy_destructor(yypParser,105,&yymsp[-2].minor);
  yy_destructor(yypParser,21,&yymsp[0].minor);
}
        break;
      case 157: /* type_name ::= DOT dottable_id */
{  yy_destructor(yypParser,44,&yymsp[-1].minor);
#line 911 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[0].minor.yy35);
	type->Type = ZCC_UserType;
	type->UserType = yymsp[0].minor.yy35;
	type->isconst = false;
	yymsp[-1].minor.yy42 = type;
}
#line 3723 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
}
        break;
      case 158: /* aggregate_type ::= MAP LT type_or_array COMMA type_or_array GT */
#line 935 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(MapType,map,yymsp[-5].minor.yy0);
	map->KeyType = yymsp[-3].minor.yy6;
	map->ValueType = yymsp[-1].minor.yy6;
	yylhsminor.yy6 = map;
}
#line 3734 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-4].minor);
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,21,&yymsp[0].minor);
  yymsp[-5].minor.yy6 = yylhsminor.yy6;
        break;
      case 159: /* aggregate_type ::= ARRAY LT type_or_array GT */
#line 943 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(DynArrayType,arr,yymsp[-3].minor.yy0);
	arr->ElementType = yymsp[-1].minor.yy6;
	yylhsminor.yy6 = arr;
}
#line 3747 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-2].minor);
  yy_destructor(yypParser,21,&yymsp[0].minor);
  yymsp[-3].minor.yy6 = yylhsminor.yy6;
        break;
      case 160: /* aggregate_type ::= CLASS class_restrictor */
#line 950 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ClassType,cls,yymsp[-1].minor.yy0);
	cls->Restriction = yymsp[0].minor.yy35;
	yylhsminor.yy6 = cls;
}
#line 3759 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[-1].minor.yy6 = yylhsminor.yy6;
        break;
      case 162: /* class_restrictor ::= LT dottable_id GT */
{  yy_destructor(yypParser,20,&yymsp[-2].minor);
#line 956 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-2].minor.yy35 = yymsp[-1].minor.yy35; /*yymsp[-2].minor.yy35-overwrites-yymsp[-1].minor.yy35*/ }
#line 3766 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,21,&yymsp[0].minor);
}
        break;
      case 163: /* type ::= type_name */
#line 958 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy6 = yymsp[0].minor.yy42; /*X-overwrites-A*/ yymsp[0].minor.yy6->ArraySize = NULL; }
#line 3773 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 164: /* type ::= aggregate_type */
#line 959 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy6 = yymsp[0].minor.yy6; /*X-overwrites-A*/ yymsp[0].minor.yy6->ArraySize = NULL; }
#line 3778 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 165: /* type_or_array ::= type array_size */
#line 962 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy6 = yymsp[-1].minor.yy6; /*X-overwrites-A*/ yymsp[-1].minor.yy6->ArraySize = yymsp[0].minor.yy138; }
#line 3783 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 166: /* type_list ::= type_list COMMA type_or_array */
#line 965 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-2].minor.yy6 = yymsp[-2].minor.yy6; /*X-overwrites-A*/ AppendTreeNodeSibling(yymsp[-2].minor.yy6, yymsp[0].minor.yy6); }
#line 3788 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 167: /* type_list_or_void ::= VOID */
{  yy_destructor(yypParser,110,&yymsp[0].minor);
#line 967 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy6 = NULL; }
#line 3795 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
}
        break;
      case 168: /* array_size_expr ::= LBRACKET opt_expr RBRACKET */
#line 971 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	if (yymsp[-1].minor.yy138 == NULL)
	{
		NEW_AST_NODE(Expression,nil,yymsp[-2].minor.yy0.SourceLoc);
		nil->Operation = PEX_Nil;
		nil->Type = NULL;
		yylhsminor.yy138 = nil;
	}
	else
	{
		yylhsminor.yy138 = yymsp[-1].minor.yy138;
	}
}
#line 3813 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,115,&yymsp[0].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 169: /* array_size ::= array_size array_size_expr */
#line 986 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	AppendTreeNodeSibling(yymsp[-1].minor.yy138, yymsp[0].minor.yy138);
	yymsp[-1].minor.yy138 = yymsp[-1].minor.yy138; /*X-overwrites-A*/
}
#line 3823 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 170: /* declarator ::= decl_flags type_list_or_void variables_or_function */
#line 995 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	if (yymsp[0].minor.yy34.FuncName == NAME_None && yymsp[0].minor.yy34.VarNames == NULL)
	{ // An error. yymsp[-2].minor.yy139 message was already printed.
		yylhsminor.yy243 = NULL;
	}
	else if (yymsp[0].minor.yy34.FuncName != NAME_None)
	{ // yymsp[-2].minor.yy139 function
		NEW_AST_NODE(FuncDeclarator, decl, yymsp[-2].minor.yy139 == nullptr? yymsp[0].minor.yy34.SourceLoc : yymsp[-2].minor.yy139->SourceLoc);
		decl->Type = yymsp[-1].minor.yy6;
		decl->Params = yymsp[0].minor.yy34.FuncParams;
		decl->Name = yymsp[0].minor.yy34.FuncName;
		decl->UseFlags = yymsp[-2].minor.yy139 == nullptr? nullptr : yymsp[-2].minor.yy139->Id;
		decl->Flags = (yymsp[-2].minor.yy139 == nullptr? 0 : yymsp[-2].minor.yy139->Flags) | yymsp[0].minor.yy34.FuncFlags;
		decl->DeprecationMessage = yymsp[-2].minor.yy139 == nullptr ? nullptr : yymsp[-2].minor.yy139->DeprecationMessage;
		if (yymsp[-2].minor.yy139 == nullptr) decl->Version = {0,0,0};
		else decl->Version = yymsp[-2].minor.yy139->Version;

		decl->Body = yymsp[0].minor.yy34.FuncBody;
		yylhsminor.yy243 = decl;
	}
	else if (yymsp[-1].minor.yy6 != NULL && yymsp[-1].minor.yy6->SiblingNext == yymsp[-1].minor.yy6)
	{ // yymsp[-2].minor.yy139 variable
		NEW_AST_NODE(VarDeclarator, decl, yymsp[-2].minor.yy139 == nullptr? yymsp[-1].minor.yy6->SourceLoc : yymsp[-2].minor.yy139->SourceLoc);
		decl->Type = yymsp[-1].minor.yy6;
		decl->Names = yymsp[0].minor.yy34.VarNames;
		if (yymsp[-2].minor.yy139 == nullptr)
		{
			decl->Flags = 0;
			decl->Version = {0,0,0};
			decl->DeprecationMessage = nullptr;
		}
		else
		{
			decl->Flags = yymsp[-2].minor.yy139->Flags;
			decl->Version = yymsp[-2].minor.yy139->Version;
			decl->DeprecationMessage = yymsp[-2].minor.yy139->DeprecationMessage;
		}
		yylhsminor.yy243 = decl;
	}
	else
	{ // An invalid
		if (yymsp[-1].minor.yy6 == NULL)
		{
			stat->sc->ScriptMessage("Variables may not be of type void.\n");
		}
		else
		{
			stat->sc->ScriptMessage("Variables may be of only one type.\n");
		}
		yylhsminor.yy243 = NULL;
	}
}
#line 3879 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[-2].minor.yy243 = yylhsminor.yy243;
        break;
      case 171: /* variables_or_function ::= IDENTIFIER LPAREN func_params RPAREN func_const opt_func_body */
#line 1050 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	VarOrFun fun;

	fun.VarNames = NULL;
	fun.FuncParams = yymsp[-3].minor.yy433;
	fun.FuncFlags = yymsp[-1].minor.yy0.Int;
	fun.FuncName = yymsp[-5].minor.yy0.Name();
	fun.FuncBody = yymsp[0].minor.yy261;
	fun.SourceLoc = yymsp[-5].minor.yy0.SourceLoc;
	yylhsminor.yy34 = fun;
}
#line 3895 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-4].minor);
  yy_destructor(yypParser,62,&yymsp[-2].minor);
  yymsp[-5].minor.yy34 = yylhsminor.yy34;
        break;
      case 172: /* variables_or_function ::= variable_list SEMICOLON */
#line 1062 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	VarOrFun var;

	var.VarNames = yymsp[-1].minor.yy273;
	var.FuncParams = NULL;
	var.FuncFlags = 0;
	var.FuncName = NAME_None;
	var.FuncBody = NULL;
	var.SourceLoc = yymsp[-1].minor.yy273->SourceLoc;
	yylhsminor.yy34 = var;
}
#line 3913 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-1].minor.yy34 = yylhsminor.yy34;
        break;
      case 173: /* variables_or_function ::= error SEMICOLON */
#line 1074 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	VarOrFun bad;
	bad.VarNames = NULL;
	bad.FuncParams = NULL;
	bad.FuncFlags = 0;
	bad.FuncName = NAME_None;
	bad.FuncBody = NULL;
	bad.SourceLoc = yymsp[0].minor.yy0.SourceLoc;
	yymsp[-1].minor.yy34 = bad;
}
#line 3929 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 174: /* variable_name ::= IDENTIFIER */
#line 1091 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(VarName,var,yymsp[0].minor.yy0);
	var->Name = ENamedName(yymsp[0].minor.yy0.Int);
	var->ArraySize = NULL;
	yylhsminor.yy273 = var;
}
#line 3939 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy273 = yylhsminor.yy273;
        break;
      case 175: /* variable_name ::= IDENTIFIER array_size */
#line 1098 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(VarName,var,yymsp[-1].minor.yy0);
	var->Name = ENamedName(yymsp[-1].minor.yy0.Int);
	var->ArraySize = yymsp[0].minor.yy138;
	yylhsminor.yy273 = var;
}
#line 3950 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[-1].minor.yy273 = yylhsminor.yy273;
        break;
      case 176: /* variable_list ::= variable_list COMMA variable_name */
#line 1107 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	AppendTreeNodeSibling(yymsp[-2].minor.yy273, yymsp[0].minor.yy273);
	yymsp[-2].minor.yy273 = yymsp[-2].minor.yy273; /*X-overwrites-A*/
}
#line 3959 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 177: /* decl_flags ::= */
#line 1113 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy139 = NULL; }
#line 3965 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 178: /* decl_flags ::= decl_flags decl_flag */
#line 1115 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	if (yymsp[-1].minor.yy139 == nullptr)
	{
		NEW_AST_NODE(DeclFlags,nil_f,yymsp[0].minor.yy0);
		yylhsminor.yy139 = nil_f;
		yylhsminor.yy139->Id = nullptr;
		yylhsminor.yy139->Flags = yymsp[0].minor.yy0.Int;
		yylhsminor.yy139->Version = { 0, 0 };
		yylhsminor.yy139->DeprecationMessage = nullptr;
	}
	else
	{
		yylhsminor.yy139 = yymsp[-1].minor.yy139;
		yylhsminor.yy139->Flags |= yymsp[0].minor.yy0.Int;
	}
}
#line 3985 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[-1].minor.yy139 = yylhsminor.yy139;
        break;
      case 179: /* decl_flags ::= decl_flags ACTION states_opts */
#line 1134 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	if (yymsp[-2].minor.yy139 == nullptr)
	{
		NEW_AST_NODE(DeclFlags,nil_f,yymsp[-1].minor.yy0.SourceLoc);
		yylhsminor.yy139 = nil_f;
		yylhsminor.yy139->Flags = ZCC_Action;
		yylhsminor.yy139->Id = nullptr;
		yylhsminor.yy139->Version = { 0, 0 };
		yylhsminor.yy139->DeprecationMessage = nullptr;
	}
	else
	{
		yylhsminor.yy139 = yymsp[-2].minor.yy139;
		yylhsminor.yy139->Flags |= ZCC_Action;
	}
	yylhsminor.yy139->Id = yymsp[0].minor.yy35;
}
#line 4007 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[-2].minor.yy139 = yylhsminor.yy139;
        break;
      case 180: /* opt_deprecation_message ::= */
#line 1152 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy0.String = nullptr; yymsp[1].minor.yy0.SourceLoc = stat->sc->GetMessageLine(); }
#line 4013 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 181: /* opt_deprecation_message ::= COMMA STRCONST */
{  yy_destructor(yypParser,50,&yymsp[-1].minor);
#line 1153 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy0 = yymsp[0].minor.yy0; }
#line 4019 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
}
        break;
      case 182: /* decl_flags ::= decl_flags DEPRECATED LPAREN STRCONST opt_deprecation_message RPAREN */
#line 1156 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	if (yymsp[-5].minor.yy139 == nullptr)
	{
		NEW_AST_NODE(DeclFlags,nil_f,yymsp[-4].minor.yy0.SourceLoc);
		yylhsminor.yy139 = nil_f;
		yylhsminor.yy139->Flags = ZCC_Deprecated;
		yylhsminor.yy139->Id = nullptr;
		yylhsminor.yy139->Version = { 0, 0 };
	}
	else
	{
		yylhsminor.yy139 = yymsp[-5].minor.yy139;
		yylhsminor.yy139->Flags |= ZCC_Deprecated;
	}
	yylhsminor.yy139->Version = yymsp[-2].minor.yy0.String->GetChars();
	yylhsminor.yy139->DeprecationMessage = yymsp[-1].minor.yy0.String;
}
#line 4041 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-3].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
  yymsp[-5].minor.yy139 = yylhsminor.yy139;
        break;
      case 183: /* decl_flags ::= decl_flags VERSION LPAREN STRCONST RPAREN */
#line 1175 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ 
	if (yymsp[-4].minor.yy139 == nullptr)
	{
		NEW_AST_NODE(DeclFlags,nil_f,yymsp[-3].minor.yy0.SourceLoc);
		yylhsminor.yy139 = nil_f;
		yylhsminor.yy139->Flags = ZCC_Version;
		yylhsminor.yy139->Id = nullptr;
		yylhsminor.yy139->Version = { 0, 0 };
		yylhsminor.yy139->DeprecationMessage = nullptr;
	}
	else
	{
		yylhsminor.yy139 = yymsp[-4].minor.yy139;
		yylhsminor.yy139->Flags |= ZCC_Version;
	}
	yylhsminor.yy139->Version = yymsp[-1].minor.yy0.String->GetChars();
}
#line 4065 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
  yymsp[-4].minor.yy139 = yylhsminor.yy139;
        break;
      case 184: /* decl_flag ::= NATIVE */
#line 1193 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Native; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4073 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 185: /* decl_flag ::= STATIC */
#line 1194 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Static; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4079 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 186: /* decl_flag ::= PRIVATE */
#line 1195 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Private; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4085 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 187: /* decl_flag ::= PROTECTED */
#line 1196 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Protected; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4091 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 188: /* decl_flag ::= LATENT */
#line 1197 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Latent; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4097 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 189: /* decl_flag ::= FINAL */
#line 1198 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Final; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4103 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 190: /* decl_flag ::= META */
#line 1199 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Meta; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4109 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 191: /* decl_flag ::= TRANSIENT */
#line 1200 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Transient; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4115 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 192: /* decl_flag ::= READONLY */
#line 1201 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_ReadOnly; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4121 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 193: /* decl_flag ::= INTERNAL */
#line 1202 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Internal; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4127 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 194: /* decl_flag ::= VIRTUAL */
#line 1203 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Virtual; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4133 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 195: /* decl_flag ::= OVERRIDE */
#line 1204 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Override; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4139 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 196: /* decl_flag ::= VARARG */
#line 1205 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_VarArg; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4145 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 197: /* decl_flag ::= UI */
#line 1206 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_UIFlag; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4151 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 198: /* decl_flag ::= PLAY */
#line 1207 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Play; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4157 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 199: /* decl_flag ::= CLEARSCOPE */
#line 1208 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_ClearScope; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4163 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 200: /* decl_flag ::= VIRTUALSCOPE */
#line 1209 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_VirtualScope; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4169 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 201: /* func_const ::= */
#line 1211 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy0.Int = 0; yymsp[1].minor.yy0.SourceLoc = stat->sc->GetMessageLine(); }
#line 4175 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 202: /* func_const ::= CONST */
#line 1212 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_FuncConst; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4180 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 203: /* opt_func_body ::= SEMICOLON */
{  yy_destructor(yypParser,49,&yymsp[0].minor);
#line 1214 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy261 = NULL; }
#line 4187 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
}
        break;
      case 204: /* func_params ::= */
#line 1221 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy433 = NULL; }
#line 4193 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 205: /* func_params ::= VOID */
{  yy_destructor(yypParser,110,&yymsp[0].minor);
#line 1222 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy433 = NULL; }
#line 4199 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
}
        break;
      case 206: /* func_params ::= func_param_list COMMA ELLIPSIS */
#line 1226 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParamDecl,parm,stat->sc->GetMessageLine());
	parm->Type = nullptr;
	parm->Name = NAME_None;
	parm->Flags = 0;
	parm->Default = nullptr;
	yymsp[-2].minor.yy433 = yymsp[-2].minor.yy433; /*X-overwrites-A*/ 
	AppendTreeNodeSibling(yymsp[-2].minor.yy433, parm);
}
#line 4213 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
  yy_destructor(yypParser,130,&yymsp[0].minor);
        break;
      case 207: /* func_param_list ::= func_param_list COMMA func_param */
#line 1237 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-2].minor.yy433 = yymsp[-2].minor.yy433; /*X-overwrites-A*/ AppendTreeNodeSibling(yymsp[-2].minor.yy433, yymsp[0].minor.yy433); }
#line 4220 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 208: /* func_param ::= func_param_flags type IDENTIFIER */
#line 1240 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParamDecl,parm,yymsp[-2].minor.yy0.SourceLoc ? yymsp[-2].minor.yy0.SourceLoc : yymsp[-1].minor.yy6->SourceLoc);
	parm->Type = yymsp[-1].minor.yy6;
	parm->Name = yymsp[0].minor.yy0.Name();
	parm->Flags = yymsp[-2].minor.yy0.Int;
	parm->Default = nullptr;
	yylhsminor.yy433 = parm;
}
#line 4233 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[-2].minor.yy433 = yylhsminor.yy433;
        break;
      case 209: /* func_param ::= func_param_flags type IDENTIFIER EQ expr */
#line 1250 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParamDecl,parm,yymsp[-4].minor.yy0.SourceLoc ? yymsp[-4].minor.yy0.SourceLoc : yymsp[-3].minor.yy6->SourceLoc);
	parm->Type = yymsp[-3].minor.yy6;
	parm->Name = yymsp[-2].minor.yy0.Name();
	parm->Flags = yymsp[-4].minor.yy0.Int;
	parm->Default = yymsp[0].minor.yy138;
	yylhsminor.yy433 = parm;
}
#line 4246 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-1].minor);
  yymsp[-4].minor.yy433 = yylhsminor.yy433;
        break;
      case 210: /* func_param_flags ::= */
#line 1259 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy0.Int = 0; yymsp[1].minor.yy0.SourceLoc = 0; }
#line 4253 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 211: /* func_param_flags ::= func_param_flags IN */
#line 1260 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = yymsp[-1].minor.yy0.Int | ZCC_In; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4258 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[-1].minor.yy0 = yylhsminor.yy0;
        break;
      case 212: /* func_param_flags ::= func_param_flags OUT */
#line 1261 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = yymsp[-1].minor.yy0.Int | ZCC_Out; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4264 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[-1].minor.yy0 = yylhsminor.yy0;
        break;
      case 213: /* func_param_flags ::= func_param_flags OPTIONAL */
#line 1262 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = yymsp[-1].minor.yy0.Int | ZCC_Optional; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4270 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[-1].minor.yy0 = yylhsminor.yy0;
        break;
      case 214: /* primary ::= IDENTIFIER */
#line 1278 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprID, expr, yymsp[0].minor.yy0);
	expr->Operation = PEX_ID;
	expr->Identifier = yymsp[0].minor.yy0.Name();
	expr->Type = NULL;
	yylhsminor.yy138 = expr;
}
#line 4282 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy138 = yylhsminor.yy138;
        break;
      case 215: /* primary ::= SUPER */
#line 1286 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Expression, expr, yymsp[0].minor.yy0);
	expr->Operation = PEX_Super;
	expr->Type = NULL;
	yylhsminor.yy138 = expr;
}
#line 4293 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy138 = yylhsminor.yy138;
        break;
      case 216: /* primary ::= constant */
#line 1292 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy138 = yymsp[0].minor.yy237; /*X-overwrites-A*/ }
#line 4299 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 217: /* primary ::= LPAREN expr COMMA expr COMMA expr RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-6].minor);
#line 1294 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(VectorValue, expr, yymsp[-5].minor.yy138);
	expr->Operation = PEX_Vector;
	expr->Type = TypeVector3;
	expr->X = yymsp[-5].minor.yy138;
	expr->Y = yymsp[-3].minor.yy138;
	expr->Z = yymsp[-1].minor.yy138;
	yymsp[-6].minor.yy138 = expr;
}
#line 4313 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-4].minor);
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      case 218: /* primary ::= LPAREN expr COMMA expr RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-4].minor);
#line 1304 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(VectorValue, expr, yymsp[-3].minor.yy138);
	expr->Operation = PEX_Vector;
	expr->Type = TypeVector2;
	expr->X = yymsp[-3].minor.yy138;
	expr->Y = yymsp[-1].minor.yy138;
	expr->Z = nullptr;
	yymsp[-4].minor.yy138 = expr;
}
#line 4331 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      case 219: /* primary ::= LPAREN expr RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-2].minor);
#line 1314 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	yymsp[-2].minor.yy138 = yymsp[-1].minor.yy138; /*yymsp[-2].minor.yy138-overwrites-yymsp[-1].minor.yy138*/
}
#line 4342 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      case 220: /* primary ::= primary LPAREN func_expr_list RPAREN */
#line 1319 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprFuncCall, expr, yymsp[-3].minor.yy138);
	expr->Operation = PEX_FuncCall;
	expr->Type = NULL;
	expr->Function = yymsp[-3].minor.yy138;
	expr->Parameters = yymsp[-1].minor.yy28;
	yylhsminor.yy138 = expr;
}
#line 4356 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
  yymsp[-3].minor.yy138 = yylhsminor.yy138;
        break;
      case 221: /* primary ::= LPAREN CLASS LT IDENTIFIER GT RPAREN LPAREN func_expr_list RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-8].minor);
#line 1328 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ClassCast, expr, yymsp[-5].minor.yy0);
	expr->Operation = PEX_ClassCast;
	expr->ClassName = ENamedName(yymsp[-5].minor.yy0.Int);
	expr->Parameters = yymsp[-1].minor.yy28;
	yymsp[-8].minor.yy138 = expr;
}
#line 4371 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,53,&yymsp[-7].minor);
  yy_destructor(yypParser,20,&yymsp[-6].minor);
  yy_destructor(yypParser,21,&yymsp[-4].minor);
  yy_destructor(yypParser,62,&yymsp[-3].minor);
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      case 222: /* primary ::= primary LBRACKET expr RBRACKET */
#line 1336 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprBinary, expr, yymsp[-1].minor.yy138);
	expr->Operation = PEX_ArrayAccess;
	expr->Type = NULL;
	expr->Left = yymsp[-3].minor.yy138;
	expr->Right = yymsp[-1].minor.yy138;
	yylhsminor.yy138 = expr;
}
#line 4390 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,46,&yymsp[-2].minor);
  yy_destructor(yypParser,115,&yymsp[0].minor);
  yymsp[-3].minor.yy138 = yylhsminor.yy138;
        break;
      case 223: /* primary ::= primary DOT IDENTIFIER */
#line 1345 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprMemberAccess, expr, yymsp[0].minor.yy0);
	expr->Operation = PEX_MemberAccess;
	expr->Type = NULL;
	expr->Left = yymsp[-2].minor.yy138;
	expr->Right = ENamedName(yymsp[0].minor.yy0.Int);
	yylhsminor.yy138 = expr;
}
#line 4405 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,44,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 224: /* primary ::= primary ADDADD */
#line 1354 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[-1].minor.yy138,PEX_PostInc);
	yylhsminor.yy138 = expr1;
}
#line 4415 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,42,&yymsp[0].minor);
  yymsp[-1].minor.yy138 = yylhsminor.yy138;
        break;
      case 225: /* primary ::= primary SUBSUB */
#line 1359 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[-1].minor.yy138,PEX_PostDec);
	yylhsminor.yy138 = expr1;
}
#line 4425 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,43,&yymsp[0].minor);
  yymsp[-1].minor.yy138 = yylhsminor.yy138;
        break;
      case 226: /* unary_expr ::= SUB unary_expr */
{  yy_destructor(yypParser,33,&yymsp[-1].minor);
#line 1375 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	ZCC_ExprConstant *con = static_cast<ZCC_ExprConstant *>(yymsp[0].minor.yy138);
	if (yymsp[0].minor.yy138->Operation == PEX_ConstValue && (con->Type->isInt() || con->Type->isFloat()))
	{ // For constants, manipulate the child node directly, and don't create a new node.
		if (con->Type->isInt())
		{
			con->IntVal = -con->IntVal;
		}
		else
		{
			con->DoubleVal = -con->DoubleVal;
		}
		yymsp[-1].minor.yy138 = yymsp[0].minor.yy138;
	}
	else
	{ // For everything else, create a new node and do the negation later.
		UNARY_EXPR(yymsp[0].minor.yy138,PEX_Negate);
		yymsp[-1].minor.yy138 = expr1;
	}
}
#line 4452 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
}
        break;
      case 227: /* unary_expr ::= ADD unary_expr */
{  yy_destructor(yypParser,34,&yymsp[-1].minor);
#line 1396 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	// Even though this is really a no-op, we still need to make a node for
	// it so we can type check that it is being applied to something numeric.
	// But we can do that right now for constant numerals.
	ZCC_ExprConstant *con = static_cast<ZCC_ExprConstant *>(yymsp[0].minor.yy138);
	if (yymsp[0].minor.yy138->Operation != PEX_ConstValue || (!con->Type->isInt() && !con->Type->isFloat()))
	{
		UNARY_EXPR(yymsp[0].minor.yy138,PEX_AntiNegate);
		yymsp[-1].minor.yy138 = expr1;
	}
	else
	{
		yymsp[-1].minor.yy138 = yymsp[0].minor.yy138;
	}
}
#line 4473 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
}
        break;
      case 228: /* unary_expr ::= SUBSUB unary_expr */
{  yy_destructor(yypParser,43,&yymsp[-1].minor);
#line 1412 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy138,PEX_PreDec);
	yymsp[-1].minor.yy138 = expr1;
}
#line 4483 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
}
        break;
      case 229: /* unary_expr ::= ADDADD unary_expr */
{  yy_destructor(yypParser,42,&yymsp[-1].minor);
#line 1417 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy138,PEX_PreInc);
	yymsp[-1].minor.yy138 = expr1;
}
#line 4493 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
}
        break;
      case 230: /* unary_expr ::= TILDE unary_expr */
{  yy_destructor(yypParser,134,&yymsp[-1].minor);
#line 1422 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy138,PEX_BitNot);
	yymsp[-1].minor.yy138 = expr1;
}
#line 4503 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
}
        break;
      case 231: /* unary_expr ::= BANG unary_expr */
{  yy_destructor(yypParser,135,&yymsp[-1].minor);
#line 1427 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy138,PEX_BoolNot);
	yymsp[-1].minor.yy138 = expr1;
}
#line 4513 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
}
        break;
      case 232: /* unary_expr ::= SIZEOF unary_expr */
{  yy_destructor(yypParser,136,&yymsp[-1].minor);
#line 1432 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy138,PEX_SizeOf);
	yymsp[-1].minor.yy138 = expr1;
}
#line 4523 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
}
        break;
      case 233: /* unary_expr ::= ALIGNOF unary_expr */
{  yy_destructor(yypParser,137,&yymsp[-1].minor);
#line 1437 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy138,PEX_AlignOf);
	yymsp[-1].minor.yy138 = expr1;
}
#line 4533 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
}
        break;
      case 234: /* expr ::= expr ADD expr */
#line 1450 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_Add);
	yylhsminor.yy138 = expr2;
}
#line 4542 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,34,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 235: /* expr ::= expr SUB expr */
#line 1455 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_Sub);
	yylhsminor.yy138 = expr2;
}
#line 4552 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,33,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 236: /* expr ::= expr MUL expr */
#line 1460 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_Mul);
	yylhsminor.yy138 = expr2;
}
#line 4562 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,35,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 237: /* expr ::= expr DIV expr */
#line 1465 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_Div);
	yylhsminor.yy138 = expr2;
}
#line 4572 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,36,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 238: /* expr ::= expr MOD expr */
#line 1470 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_Mod);
	yylhsminor.yy138 = expr2;
}
#line 4582 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,37,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 239: /* expr ::= expr POW expr */
#line 1475 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_Pow);
	yylhsminor.yy138 = expr2;
}
#line 4592 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,40,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 240: /* expr ::= expr CROSSPROD expr */
#line 1480 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_CrossProduct);
	yylhsminor.yy138 = expr2;
}
#line 4602 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,38,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 241: /* expr ::= expr DOTPROD expr */
#line 1485 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_DotProduct);
	yylhsminor.yy138 = expr2;
}
#line 4612 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,39,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 242: /* expr ::= expr LSH expr */
#line 1490 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_LeftShift);
	yylhsminor.yy138 = expr2;
}
#line 4622 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,30,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 243: /* expr ::= expr RSH expr */
#line 1495 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_RightShift);
	yylhsminor.yy138 = expr2;
}
#line 4632 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,31,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 244: /* expr ::= expr URSH expr */
#line 1500 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_URightShift);
	yylhsminor.yy138 = expr2;
}
#line 4642 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,32,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 245: /* expr ::= expr DOTDOT expr */
#line 1505 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_Concat);
	yylhsminor.yy138 = expr2;
}
#line 4652 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,26,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 246: /* expr ::= expr LT expr */
#line 1511 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_LT);
	yylhsminor.yy138 = expr2;
}
#line 4662 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 247: /* expr ::= expr GT expr */
#line 1516 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_GT);
	yylhsminor.yy138 = expr2;
}
#line 4672 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,21,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 248: /* expr ::= expr LTEQ expr */
#line 1521 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_LTEQ);
	yylhsminor.yy138 = expr2;
}
#line 4682 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,22,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 249: /* expr ::= expr GTEQ expr */
#line 1526 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_GTEQ);
	yylhsminor.yy138 = expr2;
}
#line 4692 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,23,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 250: /* expr ::= expr LTGTEQ expr */
#line 1531 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_LTGTEQ);
	yylhsminor.yy138 = expr2;
}
#line 4702 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,24,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 251: /* expr ::= expr IS expr */
#line 1536 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_Is);
	yylhsminor.yy138 = expr2;
}
#line 4712 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,25,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 252: /* expr ::= expr EQEQ expr */
#line 1542 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_EQEQ);
	yylhsminor.yy138 = expr2;
}
#line 4722 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,17,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 253: /* expr ::= expr NEQ expr */
#line 1547 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_NEQ);
	yylhsminor.yy138 = expr2;
}
#line 4732 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,18,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 254: /* expr ::= expr APPROXEQ expr */
#line 1552 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_APREQ);
	yylhsminor.yy138 = expr2;
}
#line 4742 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,19,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 255: /* expr ::= expr AND expr */
#line 1558 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_BitAnd);
	yylhsminor.yy138 = expr2;
}
#line 4752 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,29,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 256: /* expr ::= expr XOR expr */
#line 1563 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_BitXor);
	yylhsminor.yy138 = expr2;
}
#line 4762 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,28,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 257: /* expr ::= expr OR expr */
#line 1568 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_BitOr);
	yylhsminor.yy138 = expr2;
}
#line 4772 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,27,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 258: /* expr ::= expr ANDAND expr */
#line 1573 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_BoolAnd);
	yylhsminor.yy138 = expr2;
}
#line 4782 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,16,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 259: /* expr ::= expr OROR expr */
#line 1578 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_BoolOr);
	yylhsminor.yy138 = expr2;
}
#line 4792 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,15,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 260: /* expr ::= expr EQ expr */
#line 1583 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_Assign);
	yylhsminor.yy138 = expr2;
}
#line 4802 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 261: /* expr ::= expr ADDEQ expr */
#line 1588 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_AddAssign);
	yylhsminor.yy138 = expr2;
}
#line 4812 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,5,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 262: /* expr ::= expr SUBEQ expr */
#line 1593 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_SubAssign);
	yylhsminor.yy138 = expr2;
}
#line 4822 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,6,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 263: /* expr ::= expr MULEQ expr */
#line 1598 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_MulAssign);
	yylhsminor.yy138 = expr2;
}
#line 4832 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,2,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 264: /* expr ::= expr DIVEQ expr */
#line 1603 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_DivAssign);
	yylhsminor.yy138 = expr2;
}
#line 4842 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,3,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 265: /* expr ::= expr MODEQ expr */
#line 1608 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_ModAssign);
	yylhsminor.yy138 = expr2;
}
#line 4852 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,4,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 266: /* expr ::= expr LSHEQ expr */
#line 1613 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_LshAssign);
	yylhsminor.yy138 = expr2;
}
#line 4862 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,7,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 267: /* expr ::= expr RSHEQ expr */
#line 1618 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_RshAssign);
	yylhsminor.yy138 = expr2;
}
#line 4872 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,8,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 268: /* expr ::= expr URSHEQ expr */
#line 1623 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_URshAssign);
	yylhsminor.yy138 = expr2;
}
#line 4882 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,12,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 269: /* expr ::= expr ANDEQ expr */
#line 1628 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_AndAssign);
	yylhsminor.yy138 = expr2;
}
#line 4892 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,9,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 270: /* expr ::= expr OREQ expr */
#line 1633 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_OrAssign);
	yylhsminor.yy138 = expr2;
}
#line 4902 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,10,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 271: /* expr ::= expr XOREQ expr */
#line 1638 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_XorAssign);
	yylhsminor.yy138 = expr2;
}
#line 4912 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,11,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 272: /* expr ::= expr SCOPE expr */
#line 1645 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy138,yymsp[0].minor.yy138,PEX_Scope);
	yylhsminor.yy138 = expr2;
}
#line 4922 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,47,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 273: /* expr ::= expr QUESTION expr COLON expr */
#line 1653 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprTrinary, expr, yymsp[-4].minor.yy138);
	expr->Operation = PEX_Trinary;
	expr->Type = NULL;
	expr->Test = yymsp[-4].minor.yy138;
	expr->Left = yymsp[-2].minor.yy138;
	expr->Right = yymsp[0].minor.yy138;
	yylhsminor.yy138 = expr;
}
#line 4937 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,13,&yymsp[-3].minor);
  yy_destructor(yypParser,14,&yymsp[-1].minor);
  yymsp[-4].minor.yy138 = yylhsminor.yy138;
        break;
      case 274: /* expr_list ::= expr_list COMMA expr */
#line 1669 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	yymsp[-2].minor.yy138 = yymsp[-2].minor.yy138;	/*X-overwrites-A*/
	AppendTreeNodeSibling(yymsp[-2].minor.yy138, yymsp[0].minor.yy138);
}
#line 4948 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 275: /* func_expr_list ::= func_expr_list COMMA func_expr_item */
#line 1685 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	// Omitted parameters still need to appear as nodes in the list.
	if (yymsp[-2].minor.yy28 == NULL)
	{
		NEW_AST_NODE(FuncParm,nil_a,yymsp[-1].minor.yy0);
		nil_a->Value = NULL;
		nil_a->Label = NAME_None;
		yymsp[-2].minor.yy28 = nil_a;
	}
	if (yymsp[0].minor.yy28 == NULL)
	{
		NEW_AST_NODE(FuncParm,nil_b,yymsp[-1].minor.yy0);
		nil_b->Value = NULL;
		nil_b->Label = NAME_None;
		yymsp[0].minor.yy28 = nil_b;
	}
	yymsp[-2].minor.yy28 = yymsp[-2].minor.yy28;	/*X-overwrites-A*/
	AppendTreeNodeSibling(yymsp[-2].minor.yy28, yymsp[0].minor.yy28);
}
#line 4972 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 276: /* func_expr_item ::= */
#line 1706 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	yymsp[1].minor.yy28 = NULL;
}
#line 4979 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 277: /* named_expr ::= IDENTIFIER COLON expr */
#line 1712 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParm, parm, yymsp[-2].minor.yy0);
	parm->Value = yymsp[0].minor.yy138;
	parm->Label = ENamedName(yymsp[-2].minor.yy0.Int);
	yylhsminor.yy28 = parm;
}
#line 4989 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[-1].minor);
  yymsp[-2].minor.yy28 = yylhsminor.yy28;
        break;
      case 278: /* named_expr ::= expr */
#line 1719 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParm, parm, yymsp[0].minor.yy138);
	parm->Value = yymsp[0].minor.yy138;
	parm->Label = NAME_None;
	yylhsminor.yy28 = parm;
}
#line 5001 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy28 = yylhsminor.yy28;
        break;
      case 280: /* string_constant ::= string_constant STRCONST */
#line 1740 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, strconst, yymsp[-1].minor.yy237);
	strconst->Operation = PEX_ConstValue;
	strconst->Type = TypeString;
	strconst->StringVal = stat->Strings.Alloc(*(yymsp[-1].minor.yy237->StringVal) + *(yymsp[0].minor.yy0.String));
	yylhsminor.yy237 = strconst;
}
#line 5013 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[-1].minor.yy237 = yylhsminor.yy237;
        break;
      case 281: /* constant ::= INTCONST */
#line 1750 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_INTCONST_NODE(intconst, TypeSInt32, yymsp[0].minor.yy0.Int, yymsp[0].minor.yy0);
	yylhsminor.yy237 = intconst;
}
#line 5022 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy237 = yylhsminor.yy237;
        break;
      case 282: /* constant ::= UINTCONST */
#line 1755 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_INTCONST_NODE(intconst, TypeUInt32, yymsp[0].minor.yy0.Int, yymsp[0].minor.yy0);
	yylhsminor.yy237 = intconst;
}
#line 5031 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy237 = yylhsminor.yy237;
        break;
      case 283: /* constant ::= FLOATCONST */
#line 1760 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, floatconst, yymsp[0].minor.yy0);
	floatconst->Operation = PEX_ConstValue;
	floatconst->Type = TypeFloat64;
	floatconst->DoubleVal = yymsp[0].minor.yy0.Float;
	yylhsminor.yy237 = floatconst;
}
#line 5043 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy237 = yylhsminor.yy237;
        break;
      case 284: /* constant ::= NAMECONST */
#line 1768 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, floatconst, yymsp[0].minor.yy0);
	floatconst->Operation = PEX_ConstValue;
	floatconst->Type = TypeName;
	floatconst->IntVal = yymsp[0].minor.yy0.Int;
	yylhsminor.yy237 = floatconst;
}
#line 5055 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy237 = yylhsminor.yy237;
        break;
      case 285: /* constant ::= FALSE */
#line 1776 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_INTCONST_NODE(boolconst, TypeBool, false, yymsp[0].minor.yy0);
	yylhsminor.yy237 = boolconst;
}
#line 5064 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy237 = yylhsminor.yy237;
        break;
      case 286: /* constant ::= TRUE */
#line 1781 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_INTCONST_NODE(boolconst, TypeBool, true, yymsp[0].minor.yy0);
	yylhsminor.yy237 = boolconst;
}
#line 5073 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy237 = yylhsminor.yy237;
        break;
      case 287: /* constant ::= NULLPTR */
#line 1786 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, nullptrconst, yymsp[0].minor.yy0);
	nullptrconst->Operation = PEX_ConstValue;
	nullptrconst->Type = TypeNullPtr;
	nullptrconst->StringVal = nullptr;
	yylhsminor.yy237 = nullptrconst;
}
#line 5085 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy237 = yylhsminor.yy237;
        break;
      case 289: /* statement ::= labeled_statement */
#line 1800 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy181 = yymsp[0].minor.yy164; /*X-overwrites-A*/ }
#line 5091 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 290: /* statement ::= compound_statement */
#line 1801 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy181 = yymsp[0].minor.yy261; /*X-overwrites-A*/ }
#line 5096 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 291: /* statement ::= expression_statement SEMICOLON */
#line 1802 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy181 = yymsp[-1].minor.yy420; /*X-overwrites-A*/ }
#line 5101 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 292: /* statement ::= assign_statement SEMICOLON */
#line 1806 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy181 = yymsp[-1].minor.yy453; /*X-overwrites-A*/ }
#line 5107 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 293: /* statement ::= local_var SEMICOLON */
#line 1807 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy181 = yymsp[-1].minor.yy388; /*X-overwrites-A*/ }
#line 5113 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 295: /* statement ::= staticarray_statement */
#line 1809 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy181 = yymsp[0].minor.yy152; /*X-overwrites-A*/ }
#line 5119 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 296: /* staticarray_statement ::= STATICCONST type IDENTIFIER LBRACKET RBRACKET EQ LBRACE expr_list RBRACE SEMICOLON */
{  yy_destructor(yypParser,144,&yymsp[-9].minor);
#line 1816 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(StaticArrayStatement, stmt, yymsp[-8].minor.yy6);
	stmt->Type = yymsp[-8].minor.yy6;
	stmt->Id = ENamedName(yymsp[-7].minor.yy0.Int);
	stmt->Values = yymsp[-2].minor.yy138;
	yymsp[-9].minor.yy152 = stmt;
}
#line 5131 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,46,&yymsp[-6].minor);
  yy_destructor(yypParser,115,&yymsp[-5].minor);
  yy_destructor(yypParser,1,&yymsp[-4].minor);
  yy_destructor(yypParser,65,&yymsp[-3].minor);
  yy_destructor(yypParser,66,&yymsp[-1].minor);
  yy_destructor(yypParser,49,&yymsp[0].minor);
}
        break;
      case 297: /* staticarray_statement ::= STATICCONST type LBRACKET RBRACKET IDENTIFIER EQ LBRACE expr_list RBRACE SEMICOLON */
{  yy_destructor(yypParser,144,&yymsp[-9].minor);
#line 1825 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(StaticArrayStatement, stmt, yymsp[-8].minor.yy6);
	stmt->Type = yymsp[-8].minor.yy6;
	stmt->Id = ENamedName(yymsp[-5].minor.yy0.Int);
	stmt->Values = yymsp[-2].minor.yy138;
	yymsp[-9].minor.yy152 = stmt;
}
#line 5150 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,46,&yymsp[-7].minor);
  yy_destructor(yypParser,115,&yymsp[-6].minor);
  yy_destructor(yypParser,1,&yymsp[-4].minor);
  yy_destructor(yypParser,65,&yymsp[-3].minor);
  yy_destructor(yypParser,66,&yymsp[-1].minor);
  yy_destructor(yypParser,49,&yymsp[0].minor);
}
        break;
      case 298: /* jump_statement ::= CONTINUE SEMICOLON */
#line 1838 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ContinueStmt, stmt, yymsp[-1].minor.yy0);
	yylhsminor.yy181 = stmt;
}
#line 5165 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-1].minor.yy181 = yylhsminor.yy181;
        break;
      case 299: /* jump_statement ::= BREAK SEMICOLON */
#line 1843 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(BreakStmt, stmt, yymsp[-1].minor.yy0);
	yylhsminor.yy181 = stmt;
}
#line 5175 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-1].minor.yy181 = yylhsminor.yy181;
        break;
      case 300: /* jump_statement ::= RETURN SEMICOLON */
#line 1848 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ReturnStmt, stmt, yymsp[-1].minor.yy0);
	stmt->Values = NULL;
	yylhsminor.yy181 = stmt;
}
#line 5186 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-1].minor.yy181 = yylhsminor.yy181;
        break;
      case 301: /* jump_statement ::= RETURN expr_list SEMICOLON */
#line 1854 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ReturnStmt, stmt, yymsp[-2].minor.yy0);
	stmt->Values = yymsp[-1].minor.yy138;
	yylhsminor.yy181 = stmt;
}
#line 5197 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-2].minor.yy181 = yylhsminor.yy181;
        break;
      case 302: /* compound_statement ::= LBRACE RBRACE */
#line 1866 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(CompoundStmt,stmt,yymsp[-1].minor.yy0);
	stmt->Content = NULL;
	yylhsminor.yy261 = stmt;
}
#line 5208 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
  yymsp[-1].minor.yy261 = yylhsminor.yy261;
        break;
      case 303: /* compound_statement ::= LBRACE statement_list RBRACE */
#line 1872 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(CompoundStmt,stmt,yymsp[-2].minor.yy0);
	stmt->Content = yymsp[-1].minor.yy181;
	yylhsminor.yy261 = stmt;
}
#line 5219 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
  yymsp[-2].minor.yy261 = yylhsminor.yy261;
        break;
      case 304: /* compound_statement ::= LBRACE error RBRACE */
#line 1878 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(CompoundStmt,stmt,yymsp[-2].minor.yy0);
	stmt->Content = NULL;
	yylhsminor.yy261 = stmt;
}
#line 5230 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
  yymsp[-2].minor.yy261 = yylhsminor.yy261;
        break;
      case 307: /* expression_statement ::= expr */
#line 1898 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExpressionStmt, stmt, yymsp[0].minor.yy138);
	stmt->Expression = yymsp[0].minor.yy138;
	yylhsminor.yy420 = stmt;
}
#line 5241 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy420 = yylhsminor.yy420;
        break;
      case 308: /* iteration_statement ::= while_or_until LPAREN expr RPAREN statement */
#line 1910 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(IterationStmt, iter, yymsp[-4].minor.yy0);
	if (yymsp[-4].minor.yy0.Int == ZCC_UNTIL)
	{ // Negate the loop condition
		UNARY_EXPR(yymsp[-2].minor.yy138,PEX_BoolNot);
		iter->LoopCondition = expr1;
	}
	else
	{
		iter->LoopCondition = yymsp[-2].minor.yy138;
	}
	iter->LoopStatement = yymsp[0].minor.yy181;
	iter->LoopBumper = NULL;
	iter->CheckAt = ZCC_IterationStmt::Start;
	yylhsminor.yy181 = iter;
}
#line 5262 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-3].minor);
  yy_destructor(yypParser,62,&yymsp[-1].minor);
  yymsp[-4].minor.yy181 = yylhsminor.yy181;
        break;
      case 309: /* iteration_statement ::= DO statement while_or_until LPAREN expr RPAREN */
#line 1928 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(IterationStmt, iter, yymsp[-5].minor.yy0);
	if (yymsp[-3].minor.yy0.Int == ZCC_UNTIL)
	{ // Negate the loop condition
		UNARY_EXPR(yymsp[-1].minor.yy138,PEX_BoolNot);
		iter->LoopCondition = expr1;
	}
	else
	{
		iter->LoopCondition = yymsp[-1].minor.yy138;
	}
	iter->LoopStatement = yymsp[-4].minor.yy181;
	iter->LoopBumper = NULL;
	iter->CheckAt = ZCC_IterationStmt::End;
	yylhsminor.yy181 = iter;
}
#line 5285 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
  yymsp[-5].minor.yy181 = yylhsminor.yy181;
        break;
      case 310: /* iteration_statement ::= FOR LPAREN for_init SEMICOLON opt_expr SEMICOLON for_bump RPAREN statement */
#line 1946 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(IterationStmt, iter, yymsp[-8].minor.yy0);
	iter->LoopCondition = yymsp[-4].minor.yy138;
	iter->LoopStatement = yymsp[0].minor.yy181;
	iter->LoopBumper = yymsp[-2].minor.yy181;
	iter->CheckAt = ZCC_IterationStmt::Start;
	// The initialization expression appears outside the loop
	// for_init may be NULL if there is no initialization.
	SAFE_APPEND(yymsp[-6].minor.yy181, iter);
	// And the whole thing gets wrapped inside a compound statement in case the loop
	// initializer defined any variables.
	NEW_AST_NODE(CompoundStmt, wrap, yymsp[-8].minor.yy0);
	wrap->Content = yymsp[-6].minor.yy181;
	yylhsminor.yy181 = wrap;
}
#line 5307 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-7].minor);
  yy_destructor(yypParser,49,&yymsp[-5].minor);
  yy_destructor(yypParser,49,&yymsp[-3].minor);
  yy_destructor(yypParser,62,&yymsp[-1].minor);
  yymsp[-8].minor.yy181 = yylhsminor.yy181;
        break;
      case 311: /* while_or_until ::= WHILE */
#line 1963 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	yylhsminor.yy0.Int = ZCC_WHILE;
	yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc;
}
#line 5320 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 312: /* while_or_until ::= UNTIL */
#line 1968 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	yylhsminor.yy0.Int = ZCC_UNTIL;
	yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc;
}
#line 5329 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 313: /* for_init ::= local_var */
#line 1974 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy181 = yymsp[0].minor.yy388 /*X-overwrites-A*/; }
#line 5335 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 314: /* for_init ::= for_bump */
#line 1975 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy181 = yymsp[0].minor.yy181 /*X-overwrites-A*/; }
#line 5340 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 315: /* for_bump ::= */
#line 1978 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy181 = NULL; }
#line 5345 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 316: /* for_bump ::= expression_statement */
#line 1979 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy181 = yymsp[0].minor.yy420; /*X-overwrites-A*/ }
#line 5350 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 317: /* for_bump ::= for_bump COMMA expression_statement */
#line 1980 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-2].minor.yy181 = yymsp[-2].minor.yy181; /*X-overwrites-A*/ AppendTreeNodeSibling(yymsp[-2].minor.yy181, yymsp[0].minor.yy420); }
#line 5355 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 318: /* selection_statement ::= if_front */
#line 1994 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	yymsp[0].minor.yy181 = yymsp[0].minor.yy167; /*X-overwrites-A*/
}
#line 5363 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
        break;
      case 319: /* selection_statement ::= if_front ELSE statement */
#line 1998 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	yymsp[-2].minor.yy167->FalsePath = yymsp[0].minor.yy181;
	yymsp[-2].minor.yy181 = yymsp[-2].minor.yy167; /*X-overwrites-A*/
}
#line 5371 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,153,&yymsp[-1].minor);
        break;
      case 320: /* if_front ::= IF LPAREN expr RPAREN statement */
#line 2004 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(IfStmt,stmt,yymsp[-4].minor.yy0);
	stmt->Condition = yymsp[-2].minor.yy138;
	stmt->TruePath = yymsp[0].minor.yy181;
	stmt->FalsePath = NULL;
	yylhsminor.yy167 = stmt;
}
#line 5383 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-3].minor);
  yy_destructor(yypParser,62,&yymsp[-1].minor);
  yymsp[-4].minor.yy167 = yylhsminor.yy167;
        break;
      case 321: /* selection_statement ::= SWITCH LPAREN expr RPAREN statement */
#line 2015 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(SwitchStmt,stmt,yymsp[-4].minor.yy0);
	stmt->Condition = yymsp[-2].minor.yy138;
	stmt->Content = yymsp[0].minor.yy181;
	yylhsminor.yy181 = stmt;
}
#line 5396 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-3].minor);
  yy_destructor(yypParser,62,&yymsp[-1].minor);
  yymsp[-4].minor.yy181 = yylhsminor.yy181;
        break;
      case 322: /* labeled_statement ::= CASE expr COLON */
#line 2027 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(CaseStmt,stmt,yymsp[-2].minor.yy0);
	stmt->Condition = yymsp[-1].minor.yy138;
	yylhsminor.yy164 = stmt;
}
#line 5408 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[0].minor);
  yymsp[-2].minor.yy164 = yylhsminor.yy164;
        break;
      case 323: /* labeled_statement ::= DEFAULT COLON */
#line 2033 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(CaseStmt,stmt,yymsp[-1].minor.yy0);
	stmt->Condition = NULL;
	yylhsminor.yy164 = stmt;
}
#line 5419 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[0].minor);
  yymsp[-1].minor.yy164 = yylhsminor.yy164;
        break;
      case 324: /* assign_statement ::= LBRACKET expr_list RBRACKET EQ expr */
{  yy_destructor(yypParser,46,&yymsp[-4].minor);
#line 2046 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(AssignStmt,stmt,yymsp[-3].minor.yy138);
	stmt->AssignOp = ZCC_EQ;
	stmt->Dests = yymsp[-3].minor.yy138;
	stmt->Sources = yymsp[0].minor.yy138;
	yymsp[-4].minor.yy453 = stmt;
}
#line 5433 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,115,&yymsp[-2].minor);
  yy_destructor(yypParser,1,&yymsp[-1].minor);
}
        break;
      case 325: /* local_var ::= type variable_list_with_init */
#line 2059 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(LocalVarStmt,vardef,yymsp[-1].minor.yy6);
	vardef->Type = yymsp[-1].minor.yy6;
	vardef->Vars = yymsp[0].minor.yy299;
	yylhsminor.yy388 = vardef;
}
#line 5446 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[-1].minor.yy388 = yylhsminor.yy388;
        break;
      case 326: /* var_init ::= IDENTIFIER */
#line 2068 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ 
	NEW_AST_NODE(VarInit,var,yymsp[0].minor.yy0);
	var->Name = ENamedName(yymsp[0].minor.yy0.Int);
	var->ArraySize = NULL;
	var->Init = NULL;
	var->InitIsArray = false;
	yylhsminor.yy299 = var;
}
#line 5459 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[0].minor.yy299 = yylhsminor.yy299;
        break;
      case 327: /* var_init ::= IDENTIFIER array_size */
#line 2078 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(VarInit,var,yymsp[-1].minor.yy0);
	var->Name = ENamedName(yymsp[-1].minor.yy0.Int);
	var->ArraySize = yymsp[0].minor.yy138;
	var->Init = NULL;
	var->InitIsArray = false;
	yylhsminor.yy299 = var;
}
#line 5472 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yymsp[-1].minor.yy299 = yylhsminor.yy299;
        break;
      case 328: /* var_init ::= IDENTIFIER EQ expr */
#line 2088 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ 
	NEW_AST_NODE(VarInit,var,yymsp[-2].minor.yy0);
	var->Name = ENamedName(yymsp[-2].minor.yy0.Int);
	var->ArraySize = NULL;
	var->Init = yymsp[0].minor.yy138;
	var->InitIsArray = false;
	yylhsminor.yy299 = var;
}
#line 5485 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-1].minor);
  yymsp[-2].minor.yy299 = yylhsminor.yy299;
        break;
      case 329: /* var_init ::= IDENTIFIER EQ LBRACE expr_list RBRACE */
#line 2098 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ 
	NEW_AST_NODE(VarInit,var,yymsp[-4].minor.yy0);
	var->Name = ENamedName(yymsp[-4].minor.yy0.Int);
	var->ArraySize = NULL;
	var->Init = yymsp[-1].minor.yy138;
	var->InitIsArray = true;
	yylhsminor.yy299 = var;
}
#line 5499 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-3].minor);
  yy_destructor(yypParser,65,&yymsp[-2].minor);
  yy_destructor(yypParser,66,&yymsp[0].minor);
  yymsp[-4].minor.yy299 = yylhsminor.yy299;
        break;
      case 330: /* var_init ::= IDENTIFIER array_size EQ LBRACE expr_list RBRACE */
#line 2108 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ 
	NEW_AST_NODE(VarInit,var,yymsp[-5].minor.yy0);
	var->Name = ENamedName(yymsp[-5].minor.yy0.Int);
	var->ArraySize = yymsp[-4].minor.yy138;
	var->Init = yymsp[-1].minor.yy138;
	var->InitIsArray = true;
	yylhsminor.yy299 = var;
}
#line 5515 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-3].minor);
  yy_destructor(yypParser,65,&yymsp[-2].minor);
  yy_destructor(yypParser,66,&yymsp[0].minor);
  yymsp[-5].minor.yy299 = yylhsminor.yy299;
        break;
      case 331: /* var_init ::= IDENTIFIER EQ LBRACE error RBRACE */
{  yy_destructor(yypParser,54,&yymsp[-4].minor);
#line 2118 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{ 
	yymsp[-4].minor.yy299 = NULL;
}
#line 5527 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-3].minor);
  yy_destructor(yypParser,65,&yymsp[-2].minor);
  yy_destructor(yypParser,66,&yymsp[0].minor);
}
        break;
      case 332: /* variable_list_with_init ::= variable_list_with_init COMMA var_init */
#line 2126 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
	AppendTreeNodeSibling(yymsp[-2].minor.yy299, yymsp[0].minor.yy299);
	yymsp[-2].minor.yy299 = yymsp[-2].minor.yy299; /*X-overwrites-A*/
}
#line 5539 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 333: /* translation_unit ::= translation_unit EOF */
#line 178 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
}
#line 5546 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,48,&yymsp[0].minor);
        break;
      case 335: /* opt_semicolon ::= SEMICOLON */
{  yy_destructor(yypParser,49,&yymsp[0].minor);
#line 191 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
}
#line 5554 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
}
        break;
      case 337: /* opt_comma ::= COMMA */
{  yy_destructor(yypParser,50,&yymsp[0].minor);
#line 194 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
}
#line 5562 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
}
        break;
      case 343: /* state_flow ::= state_flow_type scanner_mode SEMICOLON */
#line 638 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
}
#line 5569 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 353: /* primary ::= LPAREN error RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-2].minor);
#line 1317 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
{
}
#line 5577 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      default:
      /* (334) opt_semicolon ::= */ yytestcase(yyruleno==334);
      /* (336) opt_comma ::= */ yytestcase(yyruleno==336);
      /* (338) opt_expr ::= expr */ yytestcase(yyruleno==338);
      /* (339) opt_struct_body ::= struct_body */ yytestcase(yyruleno==339);
      /* (340) struct_body ::= struct_member */ yytestcase(yyruleno==340);
      /* (341) enum_list ::= enumerator */ yytestcase(yyruleno==341);
      /* (342) opt_enum_list ::= enum_list opt_comma */ yytestcase(yyruleno==342);
      /* (344) type_name1 ::= int_type */ yytestcase(yyruleno==344);
      /* (345) type_or_array ::= type */ yytestcase(yyruleno==345);
      /* (346) type_list ::= type_or_array */ yytestcase(yyruleno==346);
      /* (347) type_list_or_void ::= type_list */ yytestcase(yyruleno==347);
      /* (348) array_size ::= array_size_expr */ yytestcase(yyruleno==348);
      /* (349) variable_list ::= variable_name */ yytestcase(yyruleno==349);
      /* (350) opt_func_body ::= function_body */ yytestcase(yyruleno==350);
      /* (351) func_params ::= func_param_list */ yytestcase(yyruleno==351);
      /* (352) func_param_list ::= func_param */ yytestcase(yyruleno==352);
      /* (354) unary_expr ::= primary */ yytestcase(yyruleno==354);
      /* (355) expr ::= unary_expr */ yytestcase(yyruleno==355);
      /* (356) expr_list ::= expr */ yytestcase(yyruleno==356);
      /* (357) func_expr_list ::= func_expr_item */ yytestcase(yyruleno==357);
      /* (358) func_expr_item ::= named_expr */ yytestcase(yyruleno==358);
      /* (359) constant ::= string_constant */ yytestcase(yyruleno==359);
      /* (360) function_body ::= compound_statement */ yytestcase(yyruleno==360);
      /* (361) statement ::= selection_statement */ yytestcase(yyruleno==361);
      /* (362) statement ::= iteration_statement */ yytestcase(yyruleno==362);
      /* (363) statement ::= jump_statement */ yytestcase(yyruleno==363);
      /* (364) variable_list_with_init ::= var_init */ yytestcase(yyruleno==364);
       break;
/********** End reduce actions ************************************************/
  };
  assert( yyruleno<sizeof(yyRuleInfo)/sizeof(yyRuleInfo[0]) );
  yygoto = yyRuleInfo[yyruleno].lhs;
  yysize = yyRuleInfo[yyruleno].nrhs;
  yyact = yy_find_reduce_action(yymsp[-yysize].stateno,(YYCODETYPE)yygoto);
  if( yyact <= YY_MAX_SHIFTREDUCE ){
    if( yyact>YY_MAX_SHIFT ){
      yyact += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
    }
    yymsp -= yysize-1;
    yypParser->yytos = yymsp;
    yymsp->stateno = (YYACTIONTYPE)yyact;
    yymsp->major = (YYCODETYPE)yygoto;
    yyTraceShift(yypParser, yyact);
  }else{
    assert( yyact == YY_ACCEPT_ACTION );
    yypParser->yytos -= yysize;
    yy_accept(yypParser);
  }
}

/*
** The following code executes when the parse fails
*/
#ifndef YYNOERRORRECOVERY
static void yy_parse_failed(
  yyParser *yypParser           /* The parser */
){
  ZCCParseARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sFail!\n",yyTracePrompt);
    fflush(yyTraceFILE);
  }
#endif
  while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser fails */
/************ Begin %parse_failure code ***************************************/
#line 148 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
 /**failed = true;*/ 
#line 5652 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
/************ End %parse_failure code *****************************************/
  ZCCParseARG_STORE; /* Suppress warning about unused %extra_argument variable */
}
#endif /* YYNOERRORRECOVERY */

/*
** The following code executes when a syntax error first occurs.
*/
static void yy_syntax_error(
  yyParser *yypParser,           /* The parser */
  int yymajor,                   /* The major type of the error token */
  ZCCParseTOKENTYPE yyminor         /* The minor type of the error token */
){
  ZCCParseARG_FETCH;
#define TOKEN yyminor
/************ Begin %syntax_error code ****************************************/
#line 121 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"

	FString unexpected, expecting;

	int i;
	int stateno = yypParser->yytos->stateno;

	unexpected << "Unexpected " << ZCCTokenName(yymajor);

	// Determine all the terminals that the parser would have accepted at this point
	// (see yy_find_shift_action). This list can get quite long. Is it worthwhile to
	// print it when not debugging the grammar, or would that be too confusing to
	// the average user?
	if (stateno < YY_SHIFT_MAX && (i = yy_shift_ofst[stateno])!=YY_SHIFT_USE_DFLT)
	{
		for (int j = 1; j < YYERRORSYMBOL; ++j)
		{
			int k = i + j;
			if (k >= 0 && k < YY_ACTTAB_COUNT && yy_lookahead[k] == j)
			{
				expecting << (expecting.IsEmpty() ? "Expecting " : " or ") << ZCCTokenName(j);
			}
		}
	}
	stat->sc->ScriptMessage("%s\n%s\n", unexpected.GetChars(), expecting.GetChars());
	FScriptPosition::ErrorCounter++;
#line 5695 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
/************ End %syntax_error code ******************************************/
  ZCCParseARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/*
** The following is executed when the parser accepts
*/
static void yy_accept(
  yyParser *yypParser           /* The parser */
){
  ZCCParseARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sAccept!\n",yyTracePrompt);
    fflush(yyTraceFILE);
  }
#endif
#ifndef YYNOERRORRECOVERY
  yypParser->yyerrcnt = -1;
#endif
#if 0
  assert( yypParser->yytos==yypParser->yystack );
#else
  while (yypParser->yytos>yypParser->yystack) yy_pop_parser_stack(yypParser);
#endif
  /* Here code is inserted which will be executed whenever the
  ** parser accepts */
/*********** Begin %parse_accept code *****************************************/
#line 147 "/builddir/build/BUILD/gzdoom-g4.3.2/src/scripting/zscript/zcc-parse.lemon"
 DPrintf(DMSG_SPAMMY, "Input accepted\n"); 
#line 5726 "/builddir/build/BUILD/gzdoom-g4.3.2/src/zcc-parse.c"
/*********** End %parse_accept code *******************************************/
  ZCCParseARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/* The main parser program.
** The first argument is a pointer to a structure obtained from
** "ZCCParseAlloc" which describes the current state of the parser.
** The second argument is the major token number.  The third is
** the minor token.  The fourth optional argument is whatever the
** user wants (and specified in the grammar) and is available for
** use by the action routines.
**
** Inputs:
** <ul>
** <li> A pointer to the parser (an opaque structure.)
** <li> The major token number.
** <li> The minor token number.
** <li> An option argument of a grammar-specified type.
** </ul>
**
** Outputs:
** None.
*/
void ZCCParse(
  void *yyp,                   /* The parser */
  int yymajor,                 /* The major token code number */
  ZCCParseTOKENTYPE yyminor       /* The value for the token */
  ZCCParseARG_PDECL               /* Optional %extra_argument parameter */
){
  YYMINORTYPE yyminorunion;
  unsigned int yyact;   /* The parser action. */
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  int yyendofinput;     /* True if we are at the end of input */
#endif
#ifdef YYERRORSYMBOL
  int yyerrorhit = 0;   /* True if yymajor has invoked an error */
#endif
  yyParser *yypParser;  /* The parser */

  yypParser = (yyParser*)yyp;
  assert( yypParser->yytos!=0 );
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  yyendofinput = (yymajor==0);
#endif
  ZCCParseARG_STORE;

#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sInput '%s'\n",yyTracePrompt,yyTokenName[yymajor]);
    fflush(yyTraceFILE);
  }
#endif

  do{
    yyact = yy_find_shift_action(yypParser,(YYCODETYPE)yymajor);
    if( yyact <= YY_MAX_SHIFTREDUCE ){
      yy_shift(yypParser,yyact,yymajor,yyminor);
#ifndef YYNOERRORRECOVERY
      yypParser->yyerrcnt--;
#endif
      yymajor = YYNOCODE;
    }else if( yyact <= YY_MAX_REDUCE ){
      yy_reduce(yypParser,yyact-YY_MIN_REDUCE);
    }else{
      assert( yyact == YY_ERROR_ACTION );
      yyminorunion.yy0 = yyminor;
#ifdef YYERRORSYMBOL
      int yymx;
#endif
#ifndef NDEBUG
      if( yyTraceFILE ){
        fprintf(yyTraceFILE,"%sSyntax Error!\n",yyTracePrompt);
        fflush(yyTraceFILE);
      }
#endif
#ifdef YYERRORSYMBOL
      /* A syntax error has occurred.
      ** The response to an error depends upon whether or not the
      ** grammar defines an error token "ERROR".  
      **
      ** This is what we do if the grammar does define ERROR:
      **
      **  * Call the %syntax_error function.
      **
      **  * Begin popping the stack until we enter a state where
      **    it is legal to shift the error symbol, then shift
      **    the error symbol.
      **
      **  * Set the error count to three.
      **
      **  * Begin accepting and shifting new tokens.  No new error
      **    processing will occur until three tokens have been
      **    shifted successfully.
      **
      */
      if( yypParser->yyerrcnt<0 ){
        yy_syntax_error(yypParser,yymajor,yyminor);
      }
      yymx = yypParser->yytos->major;
      if( yymx==YYERRORSYMBOL || yyerrorhit ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE,"%sDiscard input token %s\n",
             yyTracePrompt,yyTokenName[yymajor]);
          fflush(yyTraceFILE);
        }
#endif
        yy_destructor(yypParser, (YYCODETYPE)yymajor, &yyminorunion);
        yymajor = YYNOCODE;
      }else{
        while( yypParser->yytos >= yypParser->yystack
            && yymx != YYERRORSYMBOL
            && (yyact = yy_find_reduce_action(
                        yypParser->yytos->stateno,
                        YYERRORSYMBOL)) >= YY_MIN_REDUCE
        ){
          yy_pop_parser_stack(yypParser);
        }
        if( yypParser->yytos < yypParser->yystack || yymajor==0 ){
          yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
          yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
          yypParser->yyerrcnt = -1;
#endif
          yymajor = YYNOCODE;
        }else if( yymx!=YYERRORSYMBOL ){
          yy_shift(yypParser,yyact,YYERRORSYMBOL,yyminor);
        }
      }
      yypParser->yyerrcnt = 3;
      yyerrorhit = 1;
#elif defined(YYNOERRORRECOVERY)
      /* If the YYNOERRORRECOVERY macro is defined, then do not attempt to
      ** do any kind of error recovery.  Instead, simply invoke the syntax
      ** error routine and continue going as if nothing had happened.
      **
      ** Applications can set this macro (for example inside %include) if
      ** they intend to abandon the parse upon the first syntax error seen.
      */
      yy_syntax_error(yypParser,yymajor, yyminor);
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      yymajor = YYNOCODE;
      
#else  /* YYERRORSYMBOL is not defined */
      /* This is what we do if the grammar does not define ERROR:
      **
      **  * Report an error message, and throw away the input token.
      **
      **  * If the input token is $, then fail the parse.
      **
      ** As before, subsequent error messages are suppressed until
      ** three input tokens have been successfully shifted.
      */
      if( yypParser->yyerrcnt<=0 ){
        yy_syntax_error(yypParser,yymajor, yyminor);
      }
      yypParser->yyerrcnt = 3;
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      if( yyendofinput ){
        yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
        yypParser->yyerrcnt = -1;
#endif
      }
      yymajor = YYNOCODE;
#endif
    }
  }while( yymajor!=YYNOCODE && yypParser->yytos>yypParser->yystack );
#ifndef NDEBUG
  if( yyTraceFILE ){
    yyStackEntry *i;
    char cDiv = '[';
    fprintf(yyTraceFILE,"%sReturn. Stack=",yyTracePrompt);
    for(i=&yypParser->yystack[1]; i<=yypParser->yytos; i++){
      fprintf(yyTraceFILE,"%c%s", cDiv, yyTokenName[i->major]);
      cDiv = ' ';
    }
    fprintf(yyTraceFILE,"]\n");
    fflush(yyTraceFILE);
  }
#endif
  return;
}
